/****************************************************************************
** Meta object code from reading C++ file 'managemediaplayercontrol.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/managemediaplayercontrol.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'managemediaplayercontrol.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24ManageMediaPlayerControlE_t {};
} // unnamed namespace

template <> constexpr inline auto ManageMediaPlayerControl::qt_create_metaobjectdata<qt_meta_tag_ZN24ManageMediaPlayerControlE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ManageMediaPlayerControl",
        "QML.Element",
        "auto",
        "playControlEnabledChanged",
        "",
        "skipBackwardControlEnabledChanged",
        "skipForwardControlEnabledChanged",
        "musicPlayingChanged",
        "previousTrackChanged",
        "currentTrackChanged",
        "nextTrackChanged",
        "playerPausedOrStopped",
        "playerPlaying",
        "setPreviousTrack",
        "QPersistentModelIndex",
        "previousTrack",
        "setCurrentTrack",
        "currentTrack",
        "setNextTrack",
        "nextTrack",
        "playControlEnabled",
        "skipBackwardControlEnabled",
        "skipForwardControlEnabled",
        "musicPlaying"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'playControlEnabledChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'skipBackwardControlEnabledChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'skipForwardControlEnabledChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'musicPlayingChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previousTrackChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentTrackChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nextTrackChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'playerPausedOrStopped'
        QtMocHelpers::SlotData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'playerPlaying'
        QtMocHelpers::SlotData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setPreviousTrack'
        QtMocHelpers::SlotData<void(const QPersistentModelIndex &)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'setCurrentTrack'
        QtMocHelpers::SlotData<void(const QPersistentModelIndex &)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 17 },
        }}),
        // Slot 'setNextTrack'
        QtMocHelpers::SlotData<void(const QPersistentModelIndex &)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'playControlEnabled'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'skipBackwardControlEnabled'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'skipForwardControlEnabled'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'musicPlaying'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'previousTrack'
        QtMocHelpers::PropertyData<QPersistentModelIndex>(15, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'currentTrack'
        QtMocHelpers::PropertyData<QPersistentModelIndex>(17, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'nextTrack'
        QtMocHelpers::PropertyData<QPersistentModelIndex>(19, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ManageMediaPlayerControl, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ManageMediaPlayerControl::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24ManageMediaPlayerControlE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24ManageMediaPlayerControlE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24ManageMediaPlayerControlE_t>.metaTypes,
    nullptr
} };

void ManageMediaPlayerControl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ManageMediaPlayerControl *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->playControlEnabledChanged(); break;
        case 1: _t->skipBackwardControlEnabledChanged(); break;
        case 2: _t->skipForwardControlEnabledChanged(); break;
        case 3: _t->musicPlayingChanged(); break;
        case 4: _t->previousTrackChanged(); break;
        case 5: _t->currentTrackChanged(); break;
        case 6: _t->nextTrackChanged(); break;
        case 7: _t->playerPausedOrStopped(); break;
        case 8: _t->playerPlaying(); break;
        case 9: _t->setPreviousTrack((*reinterpret_cast<std::add_pointer_t<QPersistentModelIndex>>(_a[1]))); break;
        case 10: _t->setCurrentTrack((*reinterpret_cast<std::add_pointer_t<QPersistentModelIndex>>(_a[1]))); break;
        case 11: _t->setNextTrack((*reinterpret_cast<std::add_pointer_t<QPersistentModelIndex>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ManageMediaPlayerControl::*)()>(_a, &ManageMediaPlayerControl::playControlEnabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageMediaPlayerControl::*)()>(_a, &ManageMediaPlayerControl::skipBackwardControlEnabledChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageMediaPlayerControl::*)()>(_a, &ManageMediaPlayerControl::skipForwardControlEnabledChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageMediaPlayerControl::*)()>(_a, &ManageMediaPlayerControl::musicPlayingChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageMediaPlayerControl::*)()>(_a, &ManageMediaPlayerControl::previousTrackChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageMediaPlayerControl::*)()>(_a, &ManageMediaPlayerControl::currentTrackChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageMediaPlayerControl::*)()>(_a, &ManageMediaPlayerControl::nextTrackChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->playControlEnabled(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->skipBackwardControlEnabled(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->skipForwardControlEnabled(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->musicPlaying(); break;
        case 4: *reinterpret_cast<QPersistentModelIndex*>(_v) = _t->previousTrack(); break;
        case 5: *reinterpret_cast<QPersistentModelIndex*>(_v) = _t->currentTrack(); break;
        case 6: *reinterpret_cast<QPersistentModelIndex*>(_v) = _t->nextTrack(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 4: _t->setPreviousTrack(*reinterpret_cast<QPersistentModelIndex*>(_v)); break;
        case 5: _t->setCurrentTrack(*reinterpret_cast<QPersistentModelIndex*>(_v)); break;
        case 6: _t->setNextTrack(*reinterpret_cast<QPersistentModelIndex*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ManageMediaPlayerControl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ManageMediaPlayerControl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24ManageMediaPlayerControlE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ManageMediaPlayerControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void ManageMediaPlayerControl::playControlEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ManageMediaPlayerControl::skipBackwardControlEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ManageMediaPlayerControl::skipForwardControlEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ManageMediaPlayerControl::musicPlayingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ManageMediaPlayerControl::previousTrackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ManageMediaPlayerControl::currentTrackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ManageMediaPlayerControl::nextTrackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
