/****************************************************************************
** Meta object code from reading C++ file 'filebrowsermodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/models/filebrowsermodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filebrowsermodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16FileBrowserModelE_t {};
} // unnamed namespace

template <> constexpr inline auto FileBrowserModel::qt_create_metaobjectdata<qt_meta_tag_ZN16FileBrowserModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FileBrowserModel",
        "QML.Element",
        "auto",
        "isBusyChanged",
        "",
        "initialize",
        "MusicListenersManager*",
        "manager",
        "DatabaseInterface*",
        "database",
        "ElisaUtils::PlayListEntryType",
        "modelType",
        "ElisaUtils::FilterType",
        "filter",
        "genre",
        "artist",
        "databaseId",
        "QUrl",
        "pathFilter",
        "initializeByData",
        "DataTypes::DataType",
        "dataFilter",
        "isBusy"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'isBusyChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'initialize'
        QtMocHelpers::SlotData<void(MusicListenersManager *, DatabaseInterface *, ElisaUtils::PlayListEntryType, ElisaUtils::FilterType, const QString &, const QString &, qulonglong, const QUrl &)>(5, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 }, { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 },
            { QMetaType::QString, 14 }, { QMetaType::QString, 15 }, { QMetaType::ULongLong, 16 }, { 0x80000000 | 17, 18 },
        }}),
        // Slot 'initializeByData'
        QtMocHelpers::SlotData<void(MusicListenersManager *, DatabaseInterface *, ElisaUtils::PlayListEntryType, ElisaUtils::FilterType, const DataTypes::DataType &)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 8, 9 }, { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 },
            { 0x80000000 | 20, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isBusy'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<FileBrowserModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject FileBrowserModel::staticMetaObject = { {
    QMetaObject::SuperData::link<KDirModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16FileBrowserModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16FileBrowserModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16FileBrowserModelE_t>.metaTypes,
    nullptr
} };

void FileBrowserModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileBrowserModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->isBusyChanged(); break;
        case 1: _t->initialize((*reinterpret_cast<std::add_pointer_t<MusicListenersManager*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<DatabaseInterface*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::FilterType>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[8]))); break;
        case 2: _t->initializeByData((*reinterpret_cast<std::add_pointer_t<MusicListenersManager*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<DatabaseInterface*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::FilterType>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<DataTypes::DataType>>(_a[5]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DatabaseInterface* >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MusicListenersManager* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DatabaseInterface* >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MusicListenersManager* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FileBrowserModel::*)()>(_a, &FileBrowserModel::isBusyChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isBusy(); break;
        default: break;
        }
    }
}

const QMetaObject *FileBrowserModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FileBrowserModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16FileBrowserModelE_t>.strings))
        return static_cast<void*>(this);
    return KDirModel::qt_metacast(_clname);
}

int FileBrowserModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDirModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void FileBrowserModel::isBusyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
