/****************************************************************************
** Meta object code from reading C++ file 'viewmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/viewmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'viewmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11ViewManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto ViewManager::qt_create_metaobjectdata<qt_meta_tag_ZN11ViewManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ViewManager",
        "QML.Element",
        "auto",
        "openGridView",
        "",
        "ViewConfigurationData*",
        "configurationData",
        "openTrackView",
        "switchContextView",
        "expectedDepth",
        "mainTitle",
        "QUrl",
        "imageUrl",
        "popOneView",
        "viewIndexChanged",
        "initialIndexChanged",
        "viewsDataChanged",
        "initialFilesViewPathChanged",
        "openView",
        "viewIndex",
        "openChildView",
        "DataTypes::MusicDataType",
        "fullData",
        "openAlbumView",
        "title",
        "artist",
        "databaseId",
        "albumCoverUrl",
        "openArtistView",
        "openTracksView",
        "openNowPlaying",
        "goBack",
        "setViewsData",
        "ViewsListData*",
        "viewsData",
        "sortOrderChanged",
        "Qt::SortOrder",
        "sortOrder",
        "sortRoleChanged",
        "sortRole",
        "setViewStyle",
        "ViewStyle",
        "viewStyle",
        "setInitialIndex",
        "newIndex",
        "setInitialFilesViewPath",
        "initialPath",
        "openInitialView",
        "initialIndex",
        "initialFilesViewPath",
        "AlbumCardinality",
        "SingleAlbum",
        "MultipleAlbum",
        "AlbumViewStyle",
        "NoDiscHeaders",
        "DiscHeaders",
        "DelegateUseSecondaryText",
        "DelegateWithSecondaryText",
        "DelegateWithoutSecondaryText",
        "ViewCanBeRated",
        "ViewShowRating",
        "ViewHideRating",
        "ViewPresentationType",
        "ContextView",
        "GridView",
        "TrackView",
        "UnknownViewPresentation",
        "ModelType",
        "GenericDataModel",
        "FileBrowserModel",
        "UnknownModelType",
        "ListStyle",
        "GridStyle"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'openGridView'
        QtMocHelpers::SignalData<void(ViewConfigurationData *)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'openTrackView'
        QtMocHelpers::SignalData<void(ViewConfigurationData *)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'switchContextView'
        QtMocHelpers::SignalData<void(int, const QString &, const QUrl &)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 }, { QMetaType::QString, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Signal 'popOneView'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'viewIndexChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'initialIndexChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'viewsDataChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'initialFilesViewPathChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openView'
        QtMocHelpers::SlotData<void(int)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'openChildView'
        QtMocHelpers::SlotData<void(const DataTypes::MusicDataType &)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'openAlbumView'
        QtMocHelpers::SlotData<void(const QString &, const QString &, qulonglong, const QUrl &)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 }, { QMetaType::QString, 25 }, { QMetaType::ULongLong, 26 }, { 0x80000000 | 11, 27 },
        }}),
        // Slot 'openArtistView'
        QtMocHelpers::SlotData<void(const QString &)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'openTracksView'
        QtMocHelpers::SlotData<void(const QString &)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 24 },
        }}),
        // Slot 'openNowPlaying'
        QtMocHelpers::SlotData<void()>(30, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'goBack'
        QtMocHelpers::SlotData<void()>(31, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setViewsData'
        QtMocHelpers::SlotData<void(ViewsListData *)>(32, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Slot 'sortOrderChanged'
        QtMocHelpers::SlotData<void(Qt::SortOrder)>(35, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Slot 'sortRoleChanged'
        QtMocHelpers::SlotData<void(int)>(38, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 39 },
        }}),
        // Slot 'setViewStyle'
        QtMocHelpers::SlotData<void(const ViewStyle)>(40, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 41, 42 },
        }}),
        // Slot 'setInitialIndex'
        QtMocHelpers::SlotData<void(int)>(43, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 44 },
        }}),
        // Slot 'setInitialFilesViewPath'
        QtMocHelpers::SlotData<void(const QString &)>(45, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 46 },
        }}),
        // Slot 'openInitialView'
        QtMocHelpers::SlotData<void()>(47, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'viewIndex'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags, 4),
        // property 'initialIndex'
        QtMocHelpers::PropertyData<int>(48, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'initialFilesViewPath'
        QtMocHelpers::PropertyData<QString>(49, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'viewsData'
        QtMocHelpers::PropertyData<ViewsListData*>(34, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'AlbumCardinality'
        QtMocHelpers::EnumData<enum AlbumCardinality>(50, 50, QMC::EnumFlags{}).add({
            {   51, AlbumCardinality::SingleAlbum },
            {   52, AlbumCardinality::MultipleAlbum },
        }),
        // enum 'AlbumViewStyle'
        QtMocHelpers::EnumData<enum AlbumViewStyle>(53, 53, QMC::EnumFlags{}).add({
            {   54, AlbumViewStyle::NoDiscHeaders },
            {   55, AlbumViewStyle::DiscHeaders },
        }),
        // enum 'DelegateUseSecondaryText'
        QtMocHelpers::EnumData<enum DelegateUseSecondaryText>(56, 56, QMC::EnumFlags{}).add({
            {   57, DelegateUseSecondaryText::DelegateWithSecondaryText },
            {   58, DelegateUseSecondaryText::DelegateWithoutSecondaryText },
        }),
        // enum 'ViewCanBeRated'
        QtMocHelpers::EnumData<enum ViewCanBeRated>(59, 59, QMC::EnumFlags{}).add({
            {   60, ViewCanBeRated::ViewShowRating },
            {   61, ViewCanBeRated::ViewHideRating },
        }),
        // enum 'ViewPresentationType'
        QtMocHelpers::EnumData<enum ViewPresentationType>(62, 62, QMC::EnumFlags{}).add({
            {   63, ViewPresentationType::ContextView },
            {   64, ViewPresentationType::GridView },
            {   65, ViewPresentationType::TrackView },
            {   66, ViewPresentationType::UnknownViewPresentation },
        }),
        // enum 'ModelType'
        QtMocHelpers::EnumData<enum ModelType>(67, 67, QMC::EnumFlags{}).add({
            {   68, ModelType::GenericDataModel },
            {   69, ModelType::FileBrowserModel },
            {   70, ModelType::UnknownModelType },
        }),
        // enum 'ViewStyle'
        QtMocHelpers::EnumData<enum ViewStyle>(41, 41, QMC::EnumFlags{}).add({
            {   71, ViewStyle::ListStyle },
            {   72, ViewStyle::GridStyle },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ViewManager, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ViewManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ViewManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ViewManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11ViewManagerE_t>.metaTypes,
    nullptr
} };

void ViewManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ViewManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->openGridView((*reinterpret_cast<std::add_pointer_t<ViewConfigurationData*>>(_a[1]))); break;
        case 1: _t->openTrackView((*reinterpret_cast<std::add_pointer_t<ViewConfigurationData*>>(_a[1]))); break;
        case 2: _t->switchContextView((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3]))); break;
        case 3: _t->popOneView(); break;
        case 4: _t->viewIndexChanged(); break;
        case 5: _t->initialIndexChanged(); break;
        case 6: _t->viewsDataChanged(); break;
        case 7: _t->initialFilesViewPathChanged(); break;
        case 8: _t->openView((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->openChildView((*reinterpret_cast<std::add_pointer_t<DataTypes::MusicDataType>>(_a[1]))); break;
        case 10: _t->openAlbumView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[4]))); break;
        case 11: _t->openArtistView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->openTracksView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->openNowPlaying(); break;
        case 14: _t->goBack(); break;
        case 15: _t->setViewsData((*reinterpret_cast<std::add_pointer_t<ViewsListData*>>(_a[1]))); break;
        case 16: _t->sortOrderChanged((*reinterpret_cast<std::add_pointer_t<Qt::SortOrder>>(_a[1]))); break;
        case 17: _t->sortRoleChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->setViewStyle((*reinterpret_cast<std::add_pointer_t<enum ViewStyle>>(_a[1]))); break;
        case 19: _t->setInitialIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->setInitialFilesViewPath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->openInitialView(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::MusicDataType >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ViewManager::*)(ViewConfigurationData * )>(_a, &ViewManager::openGridView, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewManager::*)(ViewConfigurationData * )>(_a, &ViewManager::openTrackView, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewManager::*)(int , const QString & , const QUrl & )>(_a, &ViewManager::switchContextView, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewManager::*)()>(_a, &ViewManager::popOneView, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewManager::*)()>(_a, &ViewManager::viewIndexChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewManager::*)()>(_a, &ViewManager::initialIndexChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewManager::*)()>(_a, &ViewManager::viewsDataChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewManager::*)()>(_a, &ViewManager::initialFilesViewPathChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->viewIndex(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->initialIndex(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->initialFilesViewPath(); break;
        case 3: *reinterpret_cast<ViewsListData**>(_v) = _t->viewsData(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setInitialIndex(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setInitialFilesViewPath(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setViewsData(*reinterpret_cast<ViewsListData**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ViewManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ViewManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ViewManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ViewManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void ViewManager::openGridView(ViewConfigurationData * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ViewManager::openTrackView(ViewConfigurationData * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ViewManager::switchContextView(int _t1, const QString & _t2, const QUrl & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void ViewManager::popOneView()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ViewManager::viewIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ViewManager::initialIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ViewManager::viewsDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ViewManager::initialFilesViewPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
