/****************************************************************************
** Meta object code from reading C++ file 'elisaconfigurationdialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/localFileConfiguration/elisaconfigurationdialog.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'elisaconfigurationdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24ElisaConfigurationDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto ElisaConfigurationDialog::qt_create_metaobjectdata<qt_meta_tag_ZN24ElisaConfigurationDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ElisaConfigurationDialog",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "rootPathChanged",
        "",
        "rootPath",
        "isDirtyChanged",
        "showNowPlayingBackgroundChanged",
        "showProgressInTaskBarChanged",
        "showSystemTrayIconChanged",
        "alwaysUseAbsolutePlaylistPathsChanged",
        "embeddedViewChanged",
        "initialViewIndexChanged",
        "initialFilesViewPathChanged",
        "playAtStartupChanged",
        "scanAtStartupChanged",
        "useFavoriteStyleRatingsChanged",
        "setRootPath",
        "save",
        "cancel",
        "setShowNowPlayingBackground",
        "showNowPlayingBackground",
        "setShowProgressInTaskBar",
        "showProgressInTaskBar",
        "setShowSystemTrayIcon",
        "showSystemTrayIcon",
        "setAlwaysUseAbsolutePlaylistPaths",
        "alwaysUseAbsolutePlaylistPaths",
        "setEmbeddedView",
        "ElisaUtils::PlayListEntryType",
        "embeddedView",
        "setInitialViewIndex",
        "initialViewIndex",
        "setInitialFilesViewPath",
        "path",
        "setPlayAtStartup",
        "playAtStartup",
        "setScanAtStartup",
        "scanAtStartup",
        "setUseFavoriteStyleRatings",
        "useFavoriteStyleRatings",
        "configChanged",
        "removeMusicLocation",
        "location",
        "initialFilesViewPath",
        "isDirty"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'rootPathChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 7 },
        }}),
        // Signal 'isDirtyChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showNowPlayingBackgroundChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showProgressInTaskBarChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showSystemTrayIconChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alwaysUseAbsolutePlaylistPathsChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'embeddedViewChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'initialViewIndexChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'initialFilesViewPathChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playAtStartupChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scanAtStartupChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'useFavoriteStyleRatingsChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setRootPath'
        QtMocHelpers::SlotData<void(const QStringList &)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 7 },
        }}),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cancel'
        QtMocHelpers::SlotData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setShowNowPlayingBackground'
        QtMocHelpers::SlotData<void(bool)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'setShowProgressInTaskBar'
        QtMocHelpers::SlotData<void(bool)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'setShowSystemTrayIcon'
        QtMocHelpers::SlotData<void(bool)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'setAlwaysUseAbsolutePlaylistPaths'
        QtMocHelpers::SlotData<void(bool)>(28, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Slot 'setEmbeddedView'
        QtMocHelpers::SlotData<void(ElisaUtils::PlayListEntryType)>(30, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Slot 'setInitialViewIndex'
        QtMocHelpers::SlotData<void(int)>(33, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'setInitialFilesViewPath'
        QtMocHelpers::SlotData<void(const QString &)>(35, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 36 },
        }}),
        // Slot 'setPlayAtStartup'
        QtMocHelpers::SlotData<void(bool)>(37, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Slot 'setScanAtStartup'
        QtMocHelpers::SlotData<void(bool)>(39, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 40 },
        }}),
        // Slot 'setUseFavoriteStyleRatings'
        QtMocHelpers::SlotData<void(bool)>(41, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
        // Slot 'configChanged'
        QtMocHelpers::SlotData<void()>(43, 6, QMC::AccessPrivate, QMetaType::Void),
        // Method 'removeMusicLocation'
        QtMocHelpers::MethodData<void(const QString &)>(44, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 45 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'rootPath'
        QtMocHelpers::PropertyData<QStringList>(7, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'alwaysUseAbsolutePlaylistPaths'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'showNowPlayingBackground'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'showProgressInTaskBar'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'showSystemTrayIcon'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'embeddedView'
        QtMocHelpers::PropertyData<ElisaUtils::PlayListEntryType>(32, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'initialViewIndex'
        QtMocHelpers::PropertyData<int>(34, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'initialFilesViewPath'
        QtMocHelpers::PropertyData<QString>(46, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isDirty'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
        // property 'playAtStartup'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'scanAtStartup'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'useFavoriteStyleRatings'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<ElisaConfigurationDialog, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN24ElisaConfigurationDialogE[] = {
    QMetaObject::SuperData::link<ElisaUtils::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject ElisaConfigurationDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24ElisaConfigurationDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24ElisaConfigurationDialogE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN24ElisaConfigurationDialogE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24ElisaConfigurationDialogE_t>.metaTypes,
    nullptr
} };

void ElisaConfigurationDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ElisaConfigurationDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->rootPathChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 1: _t->isDirtyChanged(); break;
        case 2: _t->showNowPlayingBackgroundChanged(); break;
        case 3: _t->showProgressInTaskBarChanged(); break;
        case 4: _t->showSystemTrayIconChanged(); break;
        case 5: _t->alwaysUseAbsolutePlaylistPathsChanged(); break;
        case 6: _t->embeddedViewChanged(); break;
        case 7: _t->initialViewIndexChanged(); break;
        case 8: _t->initialFilesViewPathChanged(); break;
        case 9: _t->playAtStartupChanged(); break;
        case 10: _t->scanAtStartupChanged(); break;
        case 11: _t->useFavoriteStyleRatingsChanged(); break;
        case 12: _t->setRootPath((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 13: _t->save(); break;
        case 14: _t->cancel(); break;
        case 15: _t->setShowNowPlayingBackground((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->setShowProgressInTaskBar((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->setShowSystemTrayIcon((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->setAlwaysUseAbsolutePlaylistPaths((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->setEmbeddedView((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1]))); break;
        case 20: _t->setInitialViewIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->setInitialFilesViewPath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->setPlayAtStartup((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->setScanAtStartup((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: _t->setUseFavoriteStyleRatings((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->configChanged(); break;
        case 26: _t->removeMusicLocation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ElisaConfigurationDialog::*)(const QStringList & )>(_a, &ElisaConfigurationDialog::rootPathChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfigurationDialog::*)()>(_a, &ElisaConfigurationDialog::isDirtyChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfigurationDialog::*)()>(_a, &ElisaConfigurationDialog::showNowPlayingBackgroundChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfigurationDialog::*)()>(_a, &ElisaConfigurationDialog::showProgressInTaskBarChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfigurationDialog::*)()>(_a, &ElisaConfigurationDialog::showSystemTrayIconChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfigurationDialog::*)()>(_a, &ElisaConfigurationDialog::alwaysUseAbsolutePlaylistPathsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfigurationDialog::*)()>(_a, &ElisaConfigurationDialog::embeddedViewChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfigurationDialog::*)()>(_a, &ElisaConfigurationDialog::initialViewIndexChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfigurationDialog::*)()>(_a, &ElisaConfigurationDialog::initialFilesViewPathChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfigurationDialog::*)()>(_a, &ElisaConfigurationDialog::playAtStartupChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfigurationDialog::*)()>(_a, &ElisaConfigurationDialog::scanAtStartupChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfigurationDialog::*)()>(_a, &ElisaConfigurationDialog::useFavoriteStyleRatingsChanged, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->rootPath(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->alwaysUseAbsolutePlaylistPaths(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->showNowPlayingBackground(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->showProgressInTaskBar(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->showSystemTrayIcon(); break;
        case 5: *reinterpret_cast<ElisaUtils::PlayListEntryType*>(_v) = _t->embeddedView(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->initialViewIndex(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->initialFilesViewPath(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->isDirty(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->playAtStartup(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->scanAtStartup(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->useFavoriteStyleRatings(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setRootPath(*reinterpret_cast<QStringList*>(_v)); break;
        case 1: _t->setAlwaysUseAbsolutePlaylistPaths(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setShowNowPlayingBackground(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setShowProgressInTaskBar(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setShowSystemTrayIcon(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setEmbeddedView(*reinterpret_cast<ElisaUtils::PlayListEntryType*>(_v)); break;
        case 6: _t->setInitialViewIndex(*reinterpret_cast<int*>(_v)); break;
        case 7: _t->setInitialFilesViewPath(*reinterpret_cast<QString*>(_v)); break;
        case 9: _t->setPlayAtStartup(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setScanAtStartup(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setUseFavoriteStyleRatings(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ElisaConfigurationDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ElisaConfigurationDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24ElisaConfigurationDialogE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ElisaConfigurationDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 27;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void ElisaConfigurationDialog::rootPathChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ElisaConfigurationDialog::isDirtyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ElisaConfigurationDialog::showNowPlayingBackgroundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ElisaConfigurationDialog::showProgressInTaskBarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ElisaConfigurationDialog::showSystemTrayIconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ElisaConfigurationDialog::alwaysUseAbsolutePlaylistPathsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ElisaConfigurationDialog::embeddedViewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ElisaConfigurationDialog::initialViewIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ElisaConfigurationDialog::initialFilesViewPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ElisaConfigurationDialog::playAtStartupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void ElisaConfigurationDialog::scanAtStartupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void ElisaConfigurationDialog::useFavoriteStyleRatingsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
