// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "powerManagementLogging.h"


Q_LOGGING_CATEGORY(orgKdeElisaPowerManagement, "org.kde.elisa.powermanagement", QtInfoMsg)

