/****************************************************************************
** Meta object code from reading C++ file 'mpris2.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/mpris2/mpris2.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mpris2.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Mpris2E_t {};
} // unnamed namespace

template <> constexpr inline auto Mpris2::qt_create_metaobjectdata<qt_meta_tag_ZN6Mpris2E_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Mpris2",
        "QML.Element",
        "auto",
        "raisePlayer",
        "",
        "playerNameChanged",
        "playListModelChanged",
        "audioPlayerManagerChanged",
        "manageMediaPlayerControlChanged",
        "headerBarManagerChanged",
        "audioPlayerChanged",
        "showProgressOnTaskBarChanged",
        "setPlayerName",
        "playerName",
        "setPlayListModel",
        "MediaPlayListProxyModel*",
        "playListModel",
        "setAudioPlayerManager",
        "ManageAudioPlayer*",
        "audioPlayerManager",
        "setManageMediaPlayerControl",
        "ManageMediaPlayerControl*",
        "manageMediaPlayerControl",
        "setHeaderBarManager",
        "ManageHeaderBar*",
        "headerBarManager",
        "setAudioPlayer",
        "AudioWrapper*",
        "audioPlayer",
        "setShowProgressOnTaskBar",
        "value",
        "showProgressOnTaskBar"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'raisePlayer'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playerNameChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playListModelChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audioPlayerManagerChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'manageMediaPlayerControlChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'headerBarManagerChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audioPlayerChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showProgressOnTaskBarChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setPlayerName'
        QtMocHelpers::SlotData<void(const QString &)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'setPlayListModel'
        QtMocHelpers::SlotData<void(MediaPlayListProxyModel *)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'setAudioPlayerManager'
        QtMocHelpers::SlotData<void(ManageAudioPlayer *)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Slot 'setManageMediaPlayerControl'
        QtMocHelpers::SlotData<void(ManageMediaPlayerControl *)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'setHeaderBarManager'
        QtMocHelpers::SlotData<void(ManageHeaderBar *)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'setAudioPlayer'
        QtMocHelpers::SlotData<void(AudioWrapper *)>(26, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'setShowProgressOnTaskBar'
        QtMocHelpers::SlotData<void(bool)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'playerName'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'playListModel'
        QtMocHelpers::PropertyData<MediaPlayListProxyModel*>(16, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'audioPlayerManager'
        QtMocHelpers::PropertyData<ManageAudioPlayer*>(19, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'manageMediaPlayerControl'
        QtMocHelpers::PropertyData<ManageMediaPlayerControl*>(22, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'headerBarManager'
        QtMocHelpers::PropertyData<ManageHeaderBar*>(25, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'audioPlayer'
        QtMocHelpers::PropertyData<AudioWrapper*>(28, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'showProgressOnTaskBar'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Mpris2, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Mpris2::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Mpris2E_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Mpris2E_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Mpris2E_t>.metaTypes,
    nullptr
} };

void Mpris2::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Mpris2 *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->raisePlayer(); break;
        case 1: _t->playerNameChanged(); break;
        case 2: _t->playListModelChanged(); break;
        case 3: _t->audioPlayerManagerChanged(); break;
        case 4: _t->manageMediaPlayerControlChanged(); break;
        case 5: _t->headerBarManagerChanged(); break;
        case 6: _t->audioPlayerChanged(); break;
        case 7: _t->showProgressOnTaskBarChanged(); break;
        case 8: _t->setPlayerName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->setPlayListModel((*reinterpret_cast<std::add_pointer_t<MediaPlayListProxyModel*>>(_a[1]))); break;
        case 10: _t->setAudioPlayerManager((*reinterpret_cast<std::add_pointer_t<ManageAudioPlayer*>>(_a[1]))); break;
        case 11: _t->setManageMediaPlayerControl((*reinterpret_cast<std::add_pointer_t<ManageMediaPlayerControl*>>(_a[1]))); break;
        case 12: _t->setHeaderBarManager((*reinterpret_cast<std::add_pointer_t<ManageHeaderBar*>>(_a[1]))); break;
        case 13: _t->setAudioPlayer((*reinterpret_cast<std::add_pointer_t<AudioWrapper*>>(_a[1]))); break;
        case 14: _t->setShowProgressOnTaskBar((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ManageAudioPlayer* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ManageMediaPlayerControl* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ManageHeaderBar* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Mpris2::*)()>(_a, &Mpris2::raisePlayer, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mpris2::*)()>(_a, &Mpris2::playerNameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mpris2::*)()>(_a, &Mpris2::playListModelChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mpris2::*)()>(_a, &Mpris2::audioPlayerManagerChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mpris2::*)()>(_a, &Mpris2::manageMediaPlayerControlChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mpris2::*)()>(_a, &Mpris2::headerBarManagerChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mpris2::*)()>(_a, &Mpris2::audioPlayerChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Mpris2::*)()>(_a, &Mpris2::showProgressOnTaskBarChanged, 7))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ManageAudioPlayer* >(); break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ManageHeaderBar* >(); break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ManageMediaPlayerControl* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->playerName(); break;
        case 1: *reinterpret_cast<MediaPlayListProxyModel**>(_v) = _t->playListModel(); break;
        case 2: *reinterpret_cast<ManageAudioPlayer**>(_v) = _t->audioPlayerManager(); break;
        case 3: *reinterpret_cast<ManageMediaPlayerControl**>(_v) = _t->manageMediaPlayerControl(); break;
        case 4: *reinterpret_cast<ManageHeaderBar**>(_v) = _t->headerBarManager(); break;
        case 5: *reinterpret_cast<AudioWrapper**>(_v) = _t->audioPlayer(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->showProgressOnTaskBar(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPlayerName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setPlayListModel(*reinterpret_cast<MediaPlayListProxyModel**>(_v)); break;
        case 2: _t->setAudioPlayerManager(*reinterpret_cast<ManageAudioPlayer**>(_v)); break;
        case 3: _t->setManageMediaPlayerControl(*reinterpret_cast<ManageMediaPlayerControl**>(_v)); break;
        case 4: _t->setHeaderBarManager(*reinterpret_cast<ManageHeaderBar**>(_v)); break;
        case 5: _t->setAudioPlayer(*reinterpret_cast<AudioWrapper**>(_v)); break;
        case 6: _t->setShowProgressOnTaskBar(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Mpris2::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Mpris2::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Mpris2E_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Mpris2::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void Mpris2::raisePlayer()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Mpris2::playerNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Mpris2::playListModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Mpris2::audioPlayerManagerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Mpris2::manageMediaPlayerControlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Mpris2::headerBarManagerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Mpris2::audioPlayerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Mpris2::showProgressOnTaskBarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
