/****************************************************************************
** Meta object code from reading C++ file 'viewconfigurationdata.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/viewconfigurationdata.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'viewconfigurationdata.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21ViewConfigurationDataE_t {};
} // unnamed namespace

template <> constexpr inline auto ViewConfigurationData::qt_create_metaobjectdata<qt_meta_tag_ZN21ViewConfigurationDataE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ViewConfigurationData",
        "QML.Element",
        "auto",
        "filterType",
        "ElisaUtils::FilterType",
        "expectedDepth",
        "mainTitle",
        "secondaryTitle",
        "imageUrl",
        "QUrl",
        "dataType",
        "ElisaUtils::PlayListEntryType",
        "model",
        "QAbstractItemModel*",
        "associatedProxyModel",
        "QAbstractProxyModel*",
        "viewDefaultIcon",
        "dataFilter",
        "DataTypes::DataType",
        "viewShowRating",
        "ViewManager::ViewCanBeRated",
        "viewDelegateDisplaySecondaryText",
        "ViewManager::DelegateUseSecondaryText",
        "sortRole",
        "sortRoles",
        "QList<int>",
        "sortRoleNames",
        "sortOrder",
        "Qt::SortOrder",
        "sortOrderNames",
        "displaySingleAlbum",
        "ViewManager::AlbumCardinality",
        "showDiscHeaders",
        "ViewManager::AlbumViewStyle",
        "viewStyle",
        "ViewManager::ViewStyle"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'filterType'
        QtMocHelpers::PropertyData<ElisaUtils::FilterType>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'expectedDepth'
        QtMocHelpers::PropertyData<int>(5, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mainTitle'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'secondaryTitle'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'imageUrl'
        QtMocHelpers::PropertyData<QUrl>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'dataType'
        QtMocHelpers::PropertyData<ElisaUtils::PlayListEntryType>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'model'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'associatedProxyModel'
        QtMocHelpers::PropertyData<QAbstractProxyModel*>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'viewDefaultIcon'
        QtMocHelpers::PropertyData<QUrl>(16, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'dataFilter'
        QtMocHelpers::PropertyData<DataTypes::DataType>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'viewShowRating'
        QtMocHelpers::PropertyData<ViewManager::ViewCanBeRated>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'viewDelegateDisplaySecondaryText'
        QtMocHelpers::PropertyData<ViewManager::DelegateUseSecondaryText>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'sortRole'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sortRoles'
        QtMocHelpers::PropertyData<QList<int>>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'sortRoleNames'
        QtMocHelpers::PropertyData<QList<QString>>(26, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sortOrder'
        QtMocHelpers::PropertyData<Qt::SortOrder>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'sortOrderNames'
        QtMocHelpers::PropertyData<QList<QString>>(29, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'displaySingleAlbum'
        QtMocHelpers::PropertyData<ViewManager::AlbumCardinality>(30, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'showDiscHeaders'
        QtMocHelpers::PropertyData<ViewManager::AlbumViewStyle>(32, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'viewStyle'
        QtMocHelpers::PropertyData<ViewManager::ViewStyle>(34, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ViewConfigurationData, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN21ViewConfigurationDataE[] = {
    QMetaObject::SuperData::link<ElisaUtils::staticMetaObject>(),
    QMetaObject::SuperData::link<DataTypes::staticMetaObject>(),
    QMetaObject::SuperData::link<ViewManager::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject ViewConfigurationData::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ViewConfigurationDataE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ViewConfigurationDataE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN21ViewConfigurationDataE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21ViewConfigurationDataE_t>.metaTypes,
    nullptr
} };

void ViewConfigurationData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ViewConfigurationData *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
        case 7:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractProxyModel* >(); break;
        case 13:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<int> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<ElisaUtils::FilterType*>(_v) = _t->filterType(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->expectedDepth(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->mainTitle(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->secondaryTitle(); break;
        case 4: *reinterpret_cast<QUrl*>(_v) = _t->imageUrl(); break;
        case 5: *reinterpret_cast<ElisaUtils::PlayListEntryType*>(_v) = _t->dataType(); break;
        case 6: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->model(); break;
        case 7: *reinterpret_cast<QAbstractProxyModel**>(_v) = _t->associatedProxyModel(); break;
        case 8: *reinterpret_cast<QUrl*>(_v) = _t->viewDefaultIcon(); break;
        case 9: *reinterpret_cast<DataTypes::DataType*>(_v) = _t->dataFilter(); break;
        case 10: *reinterpret_cast<ViewManager::ViewCanBeRated*>(_v) = _t->viewShowRating(); break;
        case 11: *reinterpret_cast<ViewManager::DelegateUseSecondaryText*>(_v) = _t->viewDelegateDisplaySecondaryText(); break;
        case 12: *reinterpret_cast<int*>(_v) = _t->sortRole(); break;
        case 13: *reinterpret_cast<QList<int>*>(_v) = _t->sortRoles(); break;
        case 14: *reinterpret_cast<QList<QString>*>(_v) = _t->sortRoleNames(); break;
        case 15: *reinterpret_cast<Qt::SortOrder*>(_v) = _t->sortOrder(); break;
        case 16: *reinterpret_cast<QList<QString>*>(_v) = _t->sortOrderNames(); break;
        case 17: *reinterpret_cast<ViewManager::AlbumCardinality*>(_v) = _t->displaySingleAlbum(); break;
        case 18: *reinterpret_cast<ViewManager::AlbumViewStyle*>(_v) = _t->showDiscHeaders(); break;
        case 19: *reinterpret_cast<ViewManager::ViewStyle*>(_v) = _t->viewStyle(); break;
        default: break;
        }
    }
}

const QMetaObject *ViewConfigurationData::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ViewConfigurationData::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ViewConfigurationDataE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ViewConfigurationData::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}
QT_WARNING_POP
