/****************************************************************************
** Meta object code from reading C++ file 'abstractfilelistener.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/abstractfile/abstractfilelistener.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractfilelistener.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20AbstractFileListenerE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractFileListener::qt_create_metaobjectdata<qt_meta_tag_ZN20AbstractFileListenerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractFileListener",
        "databaseInterfaceChanged",
        "",
        "newTrackFile",
        "DataTypes::TrackDataType",
        "newTrack",
        "indexingStarted",
        "indexingFinished",
        "configurationChanged",
        "clearDatabase",
        "setDatabaseInterface",
        "DatabaseInterface*",
        "databaseInterface",
        "applicationAboutToQuit",
        "quitListener",
        "setAllRootPaths",
        "allRootPaths"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'databaseInterfaceChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newTrackFile'
        QtMocHelpers::SignalData<void(const DataTypes::TrackDataType &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'indexingStarted'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'indexingFinished'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'configurationChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clearDatabase'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setDatabaseInterface'
        QtMocHelpers::SlotData<void(DatabaseInterface *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'applicationAboutToQuit'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'quitListener'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setAllRootPaths'
        QtMocHelpers::SlotData<void(const QStringList &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'databaseInterface'
        QtMocHelpers::PropertyData<DatabaseInterface*>(12, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractFileListener, qt_meta_tag_ZN20AbstractFileListenerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AbstractFileListener::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20AbstractFileListenerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20AbstractFileListenerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20AbstractFileListenerE_t>.metaTypes,
    nullptr
} };

void AbstractFileListener::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractFileListener *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->databaseInterfaceChanged(); break;
        case 1: _t->newTrackFile((*reinterpret_cast<std::add_pointer_t<DataTypes::TrackDataType>>(_a[1]))); break;
        case 2: _t->indexingStarted(); break;
        case 3: _t->indexingFinished(); break;
        case 4: _t->configurationChanged(); break;
        case 5: _t->clearDatabase(); break;
        case 6: _t->setDatabaseInterface((*reinterpret_cast<std::add_pointer_t<DatabaseInterface*>>(_a[1]))); break;
        case 7: _t->applicationAboutToQuit(); break;
        case 8: _t->quitListener(); break;
        case 9: _t->setAllRootPaths((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::TrackDataType >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractFileListener::*)()>(_a, &AbstractFileListener::databaseInterfaceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractFileListener::*)(const DataTypes::TrackDataType & )>(_a, &AbstractFileListener::newTrackFile, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractFileListener::*)()>(_a, &AbstractFileListener::indexingStarted, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractFileListener::*)()>(_a, &AbstractFileListener::indexingFinished, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractFileListener::*)()>(_a, &AbstractFileListener::configurationChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractFileListener::*)()>(_a, &AbstractFileListener::clearDatabase, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<DatabaseInterface**>(_v) = _t->databaseInterface(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDatabaseInterface(*reinterpret_cast<DatabaseInterface**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AbstractFileListener::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractFileListener::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20AbstractFileListenerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AbstractFileListener::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void AbstractFileListener::databaseInterfaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AbstractFileListener::newTrackFile(const DataTypes::TrackDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AbstractFileListener::indexingStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AbstractFileListener::indexingFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AbstractFileListener::configurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AbstractFileListener::clearDatabase()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
