/****************************************************************************
** Meta object code from reading C++ file 'datatypes.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/datatypes.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'datatypes.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9DataTypesE_t {};
} // unnamed namespace

template <> constexpr inline auto DataTypes::qt_create_metaobjectdata<qt_meta_tag_ZN9DataTypesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DataTypes",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "ColumnsRoles",
        "TitleRole",
        "SecondaryTextRole",
        "ImageUrlRole",
        "ShadowForImageRole",
        "ChildModelRole",
        "DurationRole",
        "StringDurationRole",
        "ArtistRole",
        "AllArtistsRole",
        "HighestTrackRating",
        "AlbumRole",
        "AlbumArtistRole",
        "IsValidAlbumArtistRole",
        "TrackNumberRole",
        "DiscNumberRole",
        "RatingRole",
        "GenreRole",
        "LyricistRole",
        "ComposerRole",
        "CommentRole",
        "YearRole",
        "ChannelsRole",
        "BitRateRole",
        "SampleRateRole",
        "ResourceRole",
        "IdRole",
        "ParentIdRole",
        "DatabaseIdRole",
        "IsSingleDiscAlbumRole",
        "ContainerDataRole",
        "IsPartialDataRole",
        "AlbumIdRole",
        "HasEmbeddedCover",
        "FileModificationTime",
        "FirstPlayDate",
        "LastPlayDate",
        "PlayCounter",
        "ElementTypeRole",
        "LyricsRole",
        "FullDataRole",
        "IsDirectoryRole",
        "IsPlayListRole",
        "FilePathRole",
        "HasChildrenRole",
        "MultipleImageUrlsRole",
        "LyricsLocationRole",
        "TracksCountRole"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ColumnsRoles'
        QtMocHelpers::EnumData<enum ColumnsRoles>(7, 7, QMC::EnumFlags{}).add({
            {    8, ColumnsRoles::TitleRole },
            {    9, ColumnsRoles::SecondaryTextRole },
            {   10, ColumnsRoles::ImageUrlRole },
            {   11, ColumnsRoles::ShadowForImageRole },
            {   12, ColumnsRoles::ChildModelRole },
            {   13, ColumnsRoles::DurationRole },
            {   14, ColumnsRoles::StringDurationRole },
            {   15, ColumnsRoles::ArtistRole },
            {   16, ColumnsRoles::AllArtistsRole },
            {   17, ColumnsRoles::HighestTrackRating },
            {   18, ColumnsRoles::AlbumRole },
            {   19, ColumnsRoles::AlbumArtistRole },
            {   20, ColumnsRoles::IsValidAlbumArtistRole },
            {   21, ColumnsRoles::TrackNumberRole },
            {   22, ColumnsRoles::DiscNumberRole },
            {   23, ColumnsRoles::RatingRole },
            {   24, ColumnsRoles::GenreRole },
            {   25, ColumnsRoles::LyricistRole },
            {   26, ColumnsRoles::ComposerRole },
            {   27, ColumnsRoles::CommentRole },
            {   28, ColumnsRoles::YearRole },
            {   29, ColumnsRoles::ChannelsRole },
            {   30, ColumnsRoles::BitRateRole },
            {   31, ColumnsRoles::SampleRateRole },
            {   32, ColumnsRoles::ResourceRole },
            {   33, ColumnsRoles::IdRole },
            {   34, ColumnsRoles::ParentIdRole },
            {   35, ColumnsRoles::DatabaseIdRole },
            {   36, ColumnsRoles::IsSingleDiscAlbumRole },
            {   37, ColumnsRoles::ContainerDataRole },
            {   38, ColumnsRoles::IsPartialDataRole },
            {   39, ColumnsRoles::AlbumIdRole },
            {   40, ColumnsRoles::HasEmbeddedCover },
            {   41, ColumnsRoles::FileModificationTime },
            {   42, ColumnsRoles::FirstPlayDate },
            {   43, ColumnsRoles::LastPlayDate },
            {   44, ColumnsRoles::PlayCounter },
            {   45, ColumnsRoles::ElementTypeRole },
            {   46, ColumnsRoles::LyricsRole },
            {   47, ColumnsRoles::FullDataRole },
            {   48, ColumnsRoles::IsDirectoryRole },
            {   49, ColumnsRoles::IsPlayListRole },
            {   50, ColumnsRoles::FilePathRole },
            {   51, ColumnsRoles::HasChildrenRole },
            {   52, ColumnsRoles::MultipleImageUrlsRole },
            {   53, ColumnsRoles::LyricsLocationRole },
            {   54, ColumnsRoles::TracksCountRole },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DataTypes, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DataTypes::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DataTypesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DataTypesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9DataTypesE_t>.metaTypes,
    nullptr
} };

void DataTypes::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DataTypes *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *DataTypes::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DataTypes::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DataTypesE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DataTypes::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
