/****************************************************************************
** Meta object code from reading C++ file 'filebrowserproxymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/models/filebrowserproxymodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filebrowserproxymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21FileBrowserProxyModelE_t {};
} // unnamed namespace

template <> constexpr inline auto FileBrowserProxyModel::qt_create_metaobjectdata<qt_meta_tag_ZN21FileBrowserProxyModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FileBrowserProxyModel",
        "QML.Element",
        "auto",
        "entriesToEnqueue",
        "",
        "DataTypes::EntryDataList",
        "newEntries",
        "ElisaUtils::PlayListEnqueueMode",
        "enqueueMode",
        "ElisaUtils::PlayListEnqueueTriggerPlay",
        "triggerPlay",
        "filterTextChanged",
        "filterText",
        "filterRatingChanged",
        "sortedAscendingChanged",
        "playListChanged",
        "enqueueAll",
        "enqueue",
        "DataTypes::MusicDataType",
        "newEntry",
        "newEntryTitle",
        "setFilterText",
        "setFilterRating",
        "filterRating",
        "setPlayList",
        "MediaPlayListProxyModel*",
        "playList",
        "sortModel",
        "Qt::SortOrder",
        "order",
        "listRecursiveResult",
        "KJob*",
        "job",
        "listRecursiveNewEntries",
        "KIO::Job*",
        "KIO::UDSEntryList",
        "list",
        "sortedAscending"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'entriesToEnqueue'
        QtMocHelpers::SignalData<void(const DataTypes::EntryDataList &, ElisaUtils::PlayListEnqueueMode, ElisaUtils::PlayListEnqueueTriggerPlay)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Signal 'filterTextChanged'
        QtMocHelpers::SignalData<void(const QString &)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Signal 'filterRatingChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sortedAscendingChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playListChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'enqueueAll'
        QtMocHelpers::SlotData<void(ElisaUtils::PlayListEnqueueMode, ElisaUtils::PlayListEnqueueTriggerPlay)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'enqueue'
        QtMocHelpers::SlotData<void(const DataTypes::MusicDataType &, const QString &, ElisaUtils::PlayListEnqueueMode, ElisaUtils::PlayListEnqueueTriggerPlay)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { QMetaType::QString, 20 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'setFilterText'
        QtMocHelpers::SlotData<void(const QString &)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'setFilterRating'
        QtMocHelpers::SlotData<void(int)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'setPlayList'
        QtMocHelpers::SlotData<void(MediaPlayListProxyModel *)>(24, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'sortModel'
        QtMocHelpers::SlotData<void(Qt::SortOrder)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'listRecursiveResult'
        QtMocHelpers::SlotData<void(KJob *)>(30, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Slot 'listRecursiveNewEntries'
        QtMocHelpers::SlotData<void(KIO::Job *, const KIO::UDSEntryList &)>(33, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 34, 32 }, { 0x80000000 | 35, 36 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'filterText'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'filterRating'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'sortedAscending'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'playList'
        QtMocHelpers::PropertyData<MediaPlayListProxyModel*>(26, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<FileBrowserProxyModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject FileBrowserProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<KDirSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21FileBrowserProxyModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21FileBrowserProxyModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21FileBrowserProxyModelE_t>.metaTypes,
    nullptr
} };

void FileBrowserProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FileBrowserProxyModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->entriesToEnqueue((*reinterpret_cast<std::add_pointer_t<DataTypes::EntryDataList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEnqueueMode>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEnqueueTriggerPlay>>(_a[3]))); break;
        case 1: _t->filterTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->filterRatingChanged(); break;
        case 3: _t->sortedAscendingChanged(); break;
        case 4: _t->playListChanged(); break;
        case 5: _t->enqueueAll((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEnqueueMode>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEnqueueTriggerPlay>>(_a[2]))); break;
        case 6: _t->enqueue((*reinterpret_cast<std::add_pointer_t<DataTypes::MusicDataType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEnqueueMode>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEnqueueTriggerPlay>>(_a[4]))); break;
        case 7: _t->setFilterText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->setFilterRating((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->setPlayList((*reinterpret_cast<std::add_pointer_t<MediaPlayListProxyModel*>>(_a[1]))); break;
        case 10: _t->sortModel((*reinterpret_cast<std::add_pointer_t<Qt::SortOrder>>(_a[1]))); break;
        case 11: _t->listRecursiveResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 12: _t->listRecursiveNewEntries((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KIO::UDSEntryList>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::EntryDataList >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::MusicDataType >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIO::Job* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FileBrowserProxyModel::*)(const DataTypes::EntryDataList & , ElisaUtils::PlayListEnqueueMode , ElisaUtils::PlayListEnqueueTriggerPlay )>(_a, &FileBrowserProxyModel::entriesToEnqueue, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileBrowserProxyModel::*)(const QString & )>(_a, &FileBrowserProxyModel::filterTextChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileBrowserProxyModel::*)()>(_a, &FileBrowserProxyModel::filterRatingChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileBrowserProxyModel::*)()>(_a, &FileBrowserProxyModel::sortedAscendingChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FileBrowserProxyModel::*)()>(_a, &FileBrowserProxyModel::playListChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->filterText(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->filterRating(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->sortedAscending(); break;
        case 3: *reinterpret_cast<MediaPlayListProxyModel**>(_v) = _t->playList(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFilterText(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setFilterRating(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setPlayList(*reinterpret_cast<MediaPlayListProxyModel**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *FileBrowserProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FileBrowserProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21FileBrowserProxyModelE_t>.strings))
        return static_cast<void*>(this);
    return KDirSortFilterProxyModel::qt_metacast(_clname);
}

int FileBrowserProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDirSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void FileBrowserProxyModel::entriesToEnqueue(const DataTypes::EntryDataList & _t1, ElisaUtils::PlayListEnqueueMode _t2, ElisaUtils::PlayListEnqueueTriggerPlay _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void FileBrowserProxyModel::filterTextChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void FileBrowserProxyModel::filterRatingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void FileBrowserProxyModel::sortedAscendingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void FileBrowserProxyModel::playListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
