/****************************************************************************
** Meta object code from reading C++ file 'audiowrapper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/audiowrapper.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'audiowrapper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12AudioWrapperE_t {};
} // unnamed namespace

template <> constexpr inline auto AudioWrapper::qt_create_metaobjectdata<qt_meta_tag_ZN12AudioWrapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AudioWrapper",
        "QML.Element",
        "auto",
        "mutedChanged",
        "",
        "muted",
        "volumeChanged",
        "sourceChanged",
        "statusChanged",
        "QMediaPlayer::MediaStatus",
        "status",
        "playbackStateChanged",
        "QMediaPlayer::PlaybackState",
        "state",
        "errorChanged",
        "QMediaPlayer::Error",
        "error",
        "durationChanged",
        "duration",
        "positionChanged",
        "position",
        "currentPlayingForRadiosChanged",
        "title",
        "artistOrStation",
        "seekableChanged",
        "seekable",
        "playing",
        "paused",
        "stopped",
        "setMuted",
        "setVolume",
        "volume",
        "setSource",
        "QUrl",
        "source",
        "setPosition",
        "saveUndoPosition",
        "restoreUndoPosition",
        "play",
        "pause",
        "stop",
        "seek",
        "mediaStatusChanged",
        "playerStateChanged",
        "playerMutedChanged",
        "playerVolumeChanged",
        "playbackState"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'mutedChanged'
        QtMocHelpers::SignalData<void(bool)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Signal 'volumeChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(QMediaPlayer::MediaStatus)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'playbackStateChanged'
        QtMocHelpers::SignalData<void(QMediaPlayer::PlaybackState)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'errorChanged'
        QtMocHelpers::SignalData<void(QMediaPlayer::Error)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'durationChanged'
        QtMocHelpers::SignalData<void(qint64)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 18 },
        }}),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(qint64)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 20 },
        }}),
        // Signal 'currentPlayingForRadiosChanged'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 }, { QMetaType::QString, 23 },
        }}),
        // Signal 'seekableChanged'
        QtMocHelpers::SignalData<void(bool)>(24, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Signal 'playing'
        QtMocHelpers::SignalData<void()>(26, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paused'
        QtMocHelpers::SignalData<void()>(27, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stopped'
        QtMocHelpers::SignalData<void()>(28, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setMuted'
        QtMocHelpers::SlotData<void(bool)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setVolume'
        QtMocHelpers::SlotData<void(qreal)>(30, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 31 },
        }}),
        // Slot 'setSource'
        QtMocHelpers::SlotData<void(const QUrl &)>(32, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Slot 'setPosition'
        QtMocHelpers::SlotData<void(qint64)>(35, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 20 },
        }}),
        // Slot 'saveUndoPosition'
        QtMocHelpers::SlotData<void(qint64)>(36, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 20 },
        }}),
        // Slot 'restoreUndoPosition'
        QtMocHelpers::SlotData<void()>(37, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'play'
        QtMocHelpers::SlotData<void()>(38, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pause'
        QtMocHelpers::SlotData<void()>(39, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(40, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'seek'
        QtMocHelpers::SlotData<void(qint64)>(41, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 20 },
        }}),
        // Slot 'mediaStatusChanged'
        QtMocHelpers::SlotData<void()>(42, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'playerStateChanged'
        QtMocHelpers::SlotData<void()>(43, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'playerMutedChanged'
        QtMocHelpers::SlotData<void()>(44, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'playerVolumeChanged'
        QtMocHelpers::SlotData<void()>(45, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'muted'
        QtMocHelpers::PropertyData<bool>(5, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'volume'
        QtMocHelpers::PropertyData<qreal>(31, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'source'
        QtMocHelpers::PropertyData<QUrl>(34, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'status'
        QtMocHelpers::PropertyData<QMediaPlayer::MediaStatus>(10, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'playbackState'
        QtMocHelpers::PropertyData<QMediaPlayer::PlaybackState>(46, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'error'
        QtMocHelpers::PropertyData<QMediaPlayer::Error>(16, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'duration'
        QtMocHelpers::PropertyData<qint64>(18, QMetaType::LongLong, QMC::DefaultPropertyFlags, 6),
        // property 'position'
        QtMocHelpers::PropertyData<qint64>(20, QMetaType::LongLong, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'seekable'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags, 9),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<AudioWrapper, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN12AudioWrapperE[] = {
    QMetaObject::SuperData::link<QMediaPlayer::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject AudioWrapper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12AudioWrapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12AudioWrapperE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN12AudioWrapperE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12AudioWrapperE_t>.metaTypes,
    nullptr
} };

void AudioWrapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AudioWrapper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->mutedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->volumeChanged(); break;
        case 2: _t->sourceChanged(); break;
        case 3: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<QMediaPlayer::MediaStatus>>(_a[1]))); break;
        case 4: _t->playbackStateChanged((*reinterpret_cast<std::add_pointer_t<QMediaPlayer::PlaybackState>>(_a[1]))); break;
        case 5: _t->errorChanged((*reinterpret_cast<std::add_pointer_t<QMediaPlayer::Error>>(_a[1]))); break;
        case 6: _t->durationChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 7: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 8: _t->currentPlayingForRadiosChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: _t->seekableChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->playing(); break;
        case 11: _t->paused(); break;
        case 12: _t->stopped(); break;
        case 13: _t->setMuted((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->setVolume((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 15: _t->setSource((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 16: _t->setPosition((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 17: _t->saveUndoPosition((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 18: _t->restoreUndoPosition(); break;
        case 19: _t->play(); break;
        case 20: _t->pause(); break;
        case 21: _t->stop(); break;
        case 22: _t->seek((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 23: _t->mediaStatusChanged(); break;
        case 24: _t->playerStateChanged(); break;
        case 25: _t->playerMutedChanged(); break;
        case 26: _t->playerVolumeChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AudioWrapper::*)(bool )>(_a, &AudioWrapper::mutedChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioWrapper::*)()>(_a, &AudioWrapper::volumeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioWrapper::*)()>(_a, &AudioWrapper::sourceChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioWrapper::*)(QMediaPlayer::MediaStatus )>(_a, &AudioWrapper::statusChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioWrapper::*)(QMediaPlayer::PlaybackState )>(_a, &AudioWrapper::playbackStateChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioWrapper::*)(QMediaPlayer::Error )>(_a, &AudioWrapper::errorChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioWrapper::*)(qint64 )>(_a, &AudioWrapper::durationChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioWrapper::*)(qint64 )>(_a, &AudioWrapper::positionChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioWrapper::*)(const QString & , const QString & )>(_a, &AudioWrapper::currentPlayingForRadiosChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioWrapper::*)(bool )>(_a, &AudioWrapper::seekableChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioWrapper::*)()>(_a, &AudioWrapper::playing, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioWrapper::*)()>(_a, &AudioWrapper::paused, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (AudioWrapper::*)()>(_a, &AudioWrapper::stopped, 12))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->muted(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->volume(); break;
        case 2: *reinterpret_cast<QUrl*>(_v) = _t->source(); break;
        case 3: *reinterpret_cast<QMediaPlayer::MediaStatus*>(_v) = _t->status(); break;
        case 4: *reinterpret_cast<QMediaPlayer::PlaybackState*>(_v) = _t->playbackState(); break;
        case 5: *reinterpret_cast<QMediaPlayer::Error*>(_v) = _t->error(); break;
        case 6: *reinterpret_cast<qint64*>(_v) = _t->duration(); break;
        case 7: *reinterpret_cast<qint64*>(_v) = _t->position(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->seekable(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMuted(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setVolume(*reinterpret_cast<qreal*>(_v)); break;
        case 2: _t->setSource(*reinterpret_cast<QUrl*>(_v)); break;
        case 7: _t->setPosition(*reinterpret_cast<qint64*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AudioWrapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AudioWrapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12AudioWrapperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AudioWrapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 27;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void AudioWrapper::mutedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AudioWrapper::volumeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AudioWrapper::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AudioWrapper::statusChanged(QMediaPlayer::MediaStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void AudioWrapper::playbackStateChanged(QMediaPlayer::PlaybackState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void AudioWrapper::errorChanged(QMediaPlayer::Error _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void AudioWrapper::durationChanged(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void AudioWrapper::positionChanged(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void AudioWrapper::currentPlayingForRadiosChanged(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void AudioWrapper::seekableChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void AudioWrapper::playing()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void AudioWrapper::paused()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void AudioWrapper::stopped()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}
QT_WARNING_POP
