/****************************************************************************
** Meta object code from reading C++ file 'modeldataloader.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/modeldataloader.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'modeldataloader.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15ModelDataLoaderE_t {};
} // unnamed namespace

template <> constexpr inline auto ModelDataLoader::qt_create_metaobjectdata<qt_meta_tag_ZN15ModelDataLoaderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ModelDataLoader",
        "allAlbumsData",
        "",
        "ModelDataLoader::ListAlbumDataType",
        "allData",
        "allArtistsData",
        "ModelDataLoader::ListArtistDataType",
        "allGenresData",
        "ModelDataLoader::ListGenreDataType",
        "allTracksData",
        "ModelDataLoader::ListTrackDataType",
        "allRadiosData",
        "ModelDataLoader::ListRadioDataType",
        "radiosData",
        "radioAdded",
        "ModelDataLoader::TrackDataType",
        "radioModified",
        "allTrackData",
        "allRadioData",
        "tracksAdded",
        "newData",
        "trackModified",
        "modifiedTrack",
        "trackRemoved",
        "removedTrackId",
        "genresAdded",
        "genreRemoved",
        "removedDatabaseId",
        "artistsAdded",
        "artistRemoved",
        "albumsAdded",
        "albumRemoved",
        "albumModified",
        "ModelDataLoader::AlbumDataType",
        "modifiedAlbum",
        "saveTrackModified",
        "trackDataType",
        "removeRadio",
        "radioId",
        "radioRemoved",
        "clearedDatabase",
        "loadData",
        "ElisaUtils::PlayListEntryType",
        "dataType",
        "loadDataByAlbumId",
        "databaseId",
        "loadDataByGenre",
        "genre",
        "loadDataByArtist",
        "artist",
        "loadDataByGenreAndArtist",
        "loadDataByDatabaseIdAndUrl",
        "QUrl",
        "url",
        "loadDataByUrl",
        "loadRecentlyPlayedData",
        "loadFrequentlyPlayedData",
        "updateFileMetaData",
        "DataTypes::TrackDataType",
        "updateSingleFileMetaData",
        "DataTypes::ColumnsRoles",
        "role",
        "QVariant",
        "data",
        "trackHasBeenModified",
        "databaseTracksAdded",
        "databaseArtistsAdded",
        "databaseAlbumsAdded"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'allAlbumsData'
        QtMocHelpers::SignalData<void(const ModelDataLoader::ListAlbumDataType &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'allArtistsData'
        QtMocHelpers::SignalData<void(const ModelDataLoader::ListArtistDataType &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 4 },
        }}),
        // Signal 'allGenresData'
        QtMocHelpers::SignalData<void(const ModelDataLoader::ListGenreDataType &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 4 },
        }}),
        // Signal 'allTracksData'
        QtMocHelpers::SignalData<void(const ModelDataLoader::ListTrackDataType &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 4 },
        }}),
        // Signal 'allRadiosData'
        QtMocHelpers::SignalData<void(const ModelDataLoader::ListRadioDataType &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'radioAdded'
        QtMocHelpers::SignalData<void(const ModelDataLoader::TrackDataType &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 13 },
        }}),
        // Signal 'radioModified'
        QtMocHelpers::SignalData<void(const ModelDataLoader::TrackDataType &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 13 },
        }}),
        // Signal 'allTrackData'
        QtMocHelpers::SignalData<void(const ModelDataLoader::TrackDataType &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 4 },
        }}),
        // Signal 'allRadioData'
        QtMocHelpers::SignalData<void(const ModelDataLoader::TrackDataType &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 4 },
        }}),
        // Signal 'tracksAdded'
        QtMocHelpers::SignalData<void(const ModelDataLoader::ListTrackDataType &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 20 },
        }}),
        // Signal 'trackModified'
        QtMocHelpers::SignalData<void(const ModelDataLoader::TrackDataType &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 22 },
        }}),
        // Signal 'trackRemoved'
        QtMocHelpers::SignalData<void(qulonglong)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 24 },
        }}),
        // Signal 'genresAdded'
        QtMocHelpers::SignalData<void(const ModelDataLoader::ListGenreDataType &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 20 },
        }}),
        // Signal 'genreRemoved'
        QtMocHelpers::SignalData<void(qulonglong)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 27 },
        }}),
        // Signal 'artistsAdded'
        QtMocHelpers::SignalData<void(const ModelDataLoader::ListArtistDataType &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 20 },
        }}),
        // Signal 'artistRemoved'
        QtMocHelpers::SignalData<void(qulonglong)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 27 },
        }}),
        // Signal 'albumsAdded'
        QtMocHelpers::SignalData<void(const ModelDataLoader::ListAlbumDataType &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 20 },
        }}),
        // Signal 'albumRemoved'
        QtMocHelpers::SignalData<void(qulonglong)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 27 },
        }}),
        // Signal 'albumModified'
        QtMocHelpers::SignalData<void(const ModelDataLoader::AlbumDataType &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Signal 'saveTrackModified'
        QtMocHelpers::SignalData<void(const ModelDataLoader::ListTrackDataType &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 36 },
        }}),
        // Signal 'removeRadio'
        QtMocHelpers::SignalData<void(qulonglong)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 38 },
        }}),
        // Signal 'radioRemoved'
        QtMocHelpers::SignalData<void(qulonglong)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 38 },
        }}),
        // Signal 'clearedDatabase'
        QtMocHelpers::SignalData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadData'
        QtMocHelpers::SlotData<void(ElisaUtils::PlayListEntryType)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 42, 43 },
        }}),
        // Slot 'loadDataByAlbumId'
        QtMocHelpers::SlotData<void(ElisaUtils::PlayListEntryType, qulonglong)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 42, 43 }, { QMetaType::ULongLong, 45 },
        }}),
        // Slot 'loadDataByGenre'
        QtMocHelpers::SlotData<void(ElisaUtils::PlayListEntryType, const QString &)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 42, 43 }, { QMetaType::QString, 47 },
        }}),
        // Slot 'loadDataByArtist'
        QtMocHelpers::SlotData<void(ElisaUtils::PlayListEntryType, const QString &)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 42, 43 }, { QMetaType::QString, 49 },
        }}),
        // Slot 'loadDataByGenreAndArtist'
        QtMocHelpers::SlotData<void(ElisaUtils::PlayListEntryType, const QString &, const QString &)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 42, 43 }, { QMetaType::QString, 47 }, { QMetaType::QString, 49 },
        }}),
        // Slot 'loadDataByDatabaseIdAndUrl'
        QtMocHelpers::SlotData<void(ElisaUtils::PlayListEntryType, qulonglong, const QUrl &)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 42, 43 }, { QMetaType::ULongLong, 45 }, { 0x80000000 | 52, 53 },
        }}),
        // Slot 'loadDataByUrl'
        QtMocHelpers::SlotData<void(ElisaUtils::PlayListEntryType, const QUrl &)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 42, 43 }, { 0x80000000 | 52, 53 },
        }}),
        // Slot 'loadRecentlyPlayedData'
        QtMocHelpers::SlotData<void(ElisaUtils::PlayListEntryType)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 42, 43 },
        }}),
        // Slot 'loadFrequentlyPlayedData'
        QtMocHelpers::SlotData<void(ElisaUtils::PlayListEntryType)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 42, 43 },
        }}),
        // Slot 'updateFileMetaData'
        QtMocHelpers::SlotData<void(const DataTypes::TrackDataType &, const QUrl &)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 58, 36 }, { 0x80000000 | 52, 53 },
        }}),
        // Slot 'updateSingleFileMetaData'
        QtMocHelpers::SlotData<void(const QUrl &, DataTypes::ColumnsRoles, const QVariant &)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 52, 53 }, { 0x80000000 | 60, 61 }, { 0x80000000 | 62, 63 },
        }}),
        // Slot 'trackHasBeenModified'
        QtMocHelpers::SlotData<void(ModelDataLoader::ListTrackDataType)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 36 },
        }}),
        // Slot 'databaseTracksAdded'
        QtMocHelpers::SlotData<void(const ModelDataLoader::ListTrackDataType &)>(65, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 20 },
        }}),
        // Slot 'databaseArtistsAdded'
        QtMocHelpers::SlotData<void(const ModelDataLoader::ListArtistDataType &)>(66, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 20 },
        }}),
        // Slot 'databaseAlbumsAdded'
        QtMocHelpers::SlotData<void(const ModelDataLoader::ListAlbumDataType &)>(67, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ModelDataLoader, qt_meta_tag_ZN15ModelDataLoaderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ModelDataLoader::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ModelDataLoaderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ModelDataLoaderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15ModelDataLoaderE_t>.metaTypes,
    nullptr
} };

void ModelDataLoader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ModelDataLoader *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->allAlbumsData((*reinterpret_cast<std::add_pointer_t<ModelDataLoader::ListAlbumDataType>>(_a[1]))); break;
        case 1: _t->allArtistsData((*reinterpret_cast<std::add_pointer_t<ModelDataLoader::ListArtistDataType>>(_a[1]))); break;
        case 2: _t->allGenresData((*reinterpret_cast<std::add_pointer_t<ModelDataLoader::ListGenreDataType>>(_a[1]))); break;
        case 3: _t->allTracksData((*reinterpret_cast<std::add_pointer_t<ModelDataLoader::ListTrackDataType>>(_a[1]))); break;
        case 4: _t->allRadiosData((*reinterpret_cast<std::add_pointer_t<ModelDataLoader::ListRadioDataType>>(_a[1]))); break;
        case 5: _t->radioAdded((*reinterpret_cast<std::add_pointer_t<ModelDataLoader::TrackDataType>>(_a[1]))); break;
        case 6: _t->radioModified((*reinterpret_cast<std::add_pointer_t<ModelDataLoader::TrackDataType>>(_a[1]))); break;
        case 7: _t->allTrackData((*reinterpret_cast<std::add_pointer_t<ModelDataLoader::TrackDataType>>(_a[1]))); break;
        case 8: _t->allRadioData((*reinterpret_cast<std::add_pointer_t<ModelDataLoader::TrackDataType>>(_a[1]))); break;
        case 9: _t->tracksAdded((*reinterpret_cast<std::add_pointer_t<ModelDataLoader::ListTrackDataType>>(_a[1]))); break;
        case 10: _t->trackModified((*reinterpret_cast<std::add_pointer_t<ModelDataLoader::TrackDataType>>(_a[1]))); break;
        case 11: _t->trackRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 12: _t->genresAdded((*reinterpret_cast<std::add_pointer_t<ModelDataLoader::ListGenreDataType>>(_a[1]))); break;
        case 13: _t->genreRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 14: _t->artistsAdded((*reinterpret_cast<std::add_pointer_t<ModelDataLoader::ListArtistDataType>>(_a[1]))); break;
        case 15: _t->artistRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 16: _t->albumsAdded((*reinterpret_cast<std::add_pointer_t<ModelDataLoader::ListAlbumDataType>>(_a[1]))); break;
        case 17: _t->albumRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 18: _t->albumModified((*reinterpret_cast<std::add_pointer_t<ModelDataLoader::AlbumDataType>>(_a[1]))); break;
        case 19: _t->saveTrackModified((*reinterpret_cast<std::add_pointer_t<ModelDataLoader::ListTrackDataType>>(_a[1]))); break;
        case 20: _t->removeRadio((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 21: _t->radioRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 22: _t->clearedDatabase(); break;
        case 23: _t->loadData((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1]))); break;
        case 24: _t->loadDataByAlbumId((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2]))); break;
        case 25: _t->loadDataByGenre((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 26: _t->loadDataByArtist((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 27: _t->loadDataByGenreAndArtist((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 28: _t->loadDataByDatabaseIdAndUrl((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3]))); break;
        case 29: _t->loadDataByUrl((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 30: _t->loadRecentlyPlayedData((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1]))); break;
        case 31: _t->loadFrequentlyPlayedData((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1]))); break;
        case 32: _t->updateFileMetaData((*reinterpret_cast<std::add_pointer_t<DataTypes::TrackDataType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 33: _t->updateSingleFileMetaData((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<DataTypes::ColumnsRoles>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3]))); break;
        case 34: _t->trackHasBeenModified((*reinterpret_cast<std::add_pointer_t<ModelDataLoader::ListTrackDataType>>(_a[1]))); break;
        case 35: _t->databaseTracksAdded((*reinterpret_cast<std::add_pointer_t<ModelDataLoader::ListTrackDataType>>(_a[1]))); break;
        case 36: _t->databaseArtistsAdded((*reinterpret_cast<std::add_pointer_t<ModelDataLoader::ListArtistDataType>>(_a[1]))); break;
        case 37: _t->databaseAlbumsAdded((*reinterpret_cast<std::add_pointer_t<ModelDataLoader::ListAlbumDataType>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::TrackDataType >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ModelDataLoader::*)(const ModelDataLoader::ListAlbumDataType & )>(_a, &ModelDataLoader::allAlbumsData, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModelDataLoader::*)(const ModelDataLoader::ListArtistDataType & )>(_a, &ModelDataLoader::allArtistsData, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModelDataLoader::*)(const ModelDataLoader::ListGenreDataType & )>(_a, &ModelDataLoader::allGenresData, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModelDataLoader::*)(const ModelDataLoader::ListTrackDataType & )>(_a, &ModelDataLoader::allTracksData, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModelDataLoader::*)(const ModelDataLoader::ListRadioDataType & )>(_a, &ModelDataLoader::allRadiosData, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModelDataLoader::*)(const ModelDataLoader::TrackDataType & )>(_a, &ModelDataLoader::radioAdded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModelDataLoader::*)(const ModelDataLoader::TrackDataType & )>(_a, &ModelDataLoader::radioModified, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModelDataLoader::*)(const ModelDataLoader::TrackDataType & )>(_a, &ModelDataLoader::allTrackData, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModelDataLoader::*)(const ModelDataLoader::TrackDataType & )>(_a, &ModelDataLoader::allRadioData, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModelDataLoader::*)(const ModelDataLoader::ListTrackDataType & )>(_a, &ModelDataLoader::tracksAdded, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModelDataLoader::*)(const ModelDataLoader::TrackDataType & )>(_a, &ModelDataLoader::trackModified, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModelDataLoader::*)(qulonglong )>(_a, &ModelDataLoader::trackRemoved, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModelDataLoader::*)(const ModelDataLoader::ListGenreDataType & )>(_a, &ModelDataLoader::genresAdded, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModelDataLoader::*)(qulonglong )>(_a, &ModelDataLoader::genreRemoved, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModelDataLoader::*)(const ModelDataLoader::ListArtistDataType & )>(_a, &ModelDataLoader::artistsAdded, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModelDataLoader::*)(qulonglong )>(_a, &ModelDataLoader::artistRemoved, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModelDataLoader::*)(const ModelDataLoader::ListAlbumDataType & )>(_a, &ModelDataLoader::albumsAdded, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModelDataLoader::*)(qulonglong )>(_a, &ModelDataLoader::albumRemoved, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModelDataLoader::*)(const ModelDataLoader::AlbumDataType & )>(_a, &ModelDataLoader::albumModified, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModelDataLoader::*)(const ModelDataLoader::ListTrackDataType & )>(_a, &ModelDataLoader::saveTrackModified, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModelDataLoader::*)(qulonglong )>(_a, &ModelDataLoader::removeRadio, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModelDataLoader::*)(qulonglong )>(_a, &ModelDataLoader::radioRemoved, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (ModelDataLoader::*)()>(_a, &ModelDataLoader::clearedDatabase, 22))
            return;
    }
}

const QMetaObject *ModelDataLoader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ModelDataLoader::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ModelDataLoaderE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ModelDataLoader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    return _id;
}

// SIGNAL 0
void ModelDataLoader::allAlbumsData(const ModelDataLoader::ListAlbumDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ModelDataLoader::allArtistsData(const ModelDataLoader::ListArtistDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ModelDataLoader::allGenresData(const ModelDataLoader::ListGenreDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ModelDataLoader::allTracksData(const ModelDataLoader::ListTrackDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ModelDataLoader::allRadiosData(const ModelDataLoader::ListRadioDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ModelDataLoader::radioAdded(const ModelDataLoader::TrackDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ModelDataLoader::radioModified(const ModelDataLoader::TrackDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ModelDataLoader::allTrackData(const ModelDataLoader::TrackDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ModelDataLoader::allRadioData(const ModelDataLoader::TrackDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void ModelDataLoader::tracksAdded(const ModelDataLoader::ListTrackDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void ModelDataLoader::trackModified(const ModelDataLoader::TrackDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void ModelDataLoader::trackRemoved(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void ModelDataLoader::genresAdded(const ModelDataLoader::ListGenreDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void ModelDataLoader::genreRemoved(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void ModelDataLoader::artistsAdded(const ModelDataLoader::ListArtistDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void ModelDataLoader::artistRemoved(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void ModelDataLoader::albumsAdded(const ModelDataLoader::ListAlbumDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void ModelDataLoader::albumRemoved(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void ModelDataLoader::albumModified(const ModelDataLoader::AlbumDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void ModelDataLoader::saveTrackModified(const ModelDataLoader::ListTrackDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void ModelDataLoader::removeRadio(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void ModelDataLoader::radioRemoved(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void ModelDataLoader::clearedDatabase()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}
QT_WARNING_POP
