/****************************************************************************
** Meta object code from reading C++ file 'elisautils.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/elisautils.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'elisautils.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10ElisaUtilsE_t {};
} // unnamed namespace

template <> constexpr inline auto ElisaUtils::qt_create_metaobjectdata<qt_meta_tag_ZN10ElisaUtilsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ElisaUtils",
        "QML.Element",
        "PlayListEnqueueMode",
        "AppendPlayList",
        "ReplacePlayList",
        "AfterCurrentTrack",
        "PlayListEnqueueTriggerPlay",
        "DoNotTriggerPlay",
        "TriggerPlay",
        "SkipReason",
        "Automatic",
        "Manual",
        "PlayListEntryType",
        "Album",
        "Artist",
        "Genre",
        "Lyricist",
        "Composer",
        "Track",
        "FileName",
        "Container",
        "Radio",
        "PlayList",
        "Unknown",
        "FilterType",
        "UnknownFilter",
        "NoFilter",
        "FilterById",
        "FilterByGenre",
        "FilterByArtist",
        "FilterByGenreAndArtist",
        "FilterByRecentlyPlayed",
        "FilterByFrequentlyPlayed",
        "FilterByPath"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'PlayListEnqueueMode'
        QtMocHelpers::EnumData<PlayListEnqueueMode>(2, 2, QMC::EnumFlags{}).add({
            {    3, PlayListEnqueueMode::AppendPlayList },
            {    4, PlayListEnqueueMode::ReplacePlayList },
            {    5, PlayListEnqueueMode::AfterCurrentTrack },
        }),
        // enum 'PlayListEnqueueTriggerPlay'
        QtMocHelpers::EnumData<PlayListEnqueueTriggerPlay>(6, 6, QMC::EnumFlags{}).add({
            {    7, PlayListEnqueueTriggerPlay::DoNotTriggerPlay },
            {    8, PlayListEnqueueTriggerPlay::TriggerPlay },
        }),
        // enum 'SkipReason'
        QtMocHelpers::EnumData<SkipReason>(9, 9, QMC::EnumFlags{}).add({
            {   10, SkipReason::Automatic },
            {   11, SkipReason::Manual },
        }),
        // enum 'PlayListEntryType'
        QtMocHelpers::EnumData<PlayListEntryType>(12, 12, QMC::EnumFlags{}).add({
            {   13, PlayListEntryType::Album },
            {   14, PlayListEntryType::Artist },
            {   15, PlayListEntryType::Genre },
            {   16, PlayListEntryType::Lyricist },
            {   17, PlayListEntryType::Composer },
            {   18, PlayListEntryType::Track },
            {   19, PlayListEntryType::FileName },
            {   20, PlayListEntryType::Container },
            {   21, PlayListEntryType::Radio },
            {   22, PlayListEntryType::PlayList },
            {   23, PlayListEntryType::Unknown },
        }),
        // enum 'FilterType'
        QtMocHelpers::EnumData<FilterType>(24, 24, QMC::EnumFlags{}).add({
            {   25, FilterType::UnknownFilter },
            {   26, FilterType::NoFilter },
            {   27, FilterType::FilterById },
            {   28, FilterType::FilterByGenre },
            {   29, FilterType::FilterByArtist },
            {   30, FilterType::FilterByGenreAndArtist },
            {   31, FilterType::FilterByRecentlyPlayed },
            {   32, FilterType::FilterByFrequentlyPlayed },
            {   33, FilterType::FilterByPath },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    0 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN10ElisaUtilsE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN10ElisaUtilsE =
    ElisaUtils::qt_create_metaobjectdata<qt_meta_tag_ZN10ElisaUtilsE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN10ElisaUtilsE =
    qt_staticMetaObjectContent_ZN10ElisaUtilsE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN10ElisaUtilsE =
    qt_staticMetaObjectContent_ZN10ElisaUtilsE.relocatingData;

Q_CONSTINIT const QMetaObject ElisaUtils::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN10ElisaUtilsE.stringdata,
    qt_staticMetaObjectStaticContent_ZN10ElisaUtilsE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN10ElisaUtilsE.metaTypes,
    nullptr
} };

QT_WARNING_POP
