/****************************************************************************
** Meta object code from reading C++ file 'trackmetadatamodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/models/trackmetadatamodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'trackmetadatamodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18TrackMetadataModelE_t {};
} // unnamed namespace

template <> constexpr inline auto TrackMetadataModel::qt_create_metaobjectdata<qt_meta_tag_ZN18TrackMetadataModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TrackMetadataModel",
        "QML.Element",
        "auto",
        "needDataByDatabaseIdAndUrl",
        "",
        "ElisaUtils::PlayListEntryType",
        "dataType",
        "databaseId",
        "QUrl",
        "url",
        "needDataByUrl",
        "fileName",
        "coverUrlChanged",
        "fileUrlChanged",
        "managerChanged",
        "lyricsChanged",
        "databaseIdChanged",
        "trackData",
        "TrackMetadataModel::TrackDataType",
        "initializeByIdAndUrl",
        "type",
        "initializeByUrl",
        "initializeForNewRadio",
        "setManager",
        "MusicListenersManager*",
        "newManager",
        "setDatabase",
        "DatabaseInterface*",
        "trackDatabase",
        "radioData",
        "radiosData",
        "lyricsValueIsReady",
        "coverUrl",
        "fileUrl",
        "manager",
        "lyrics",
        "ColumnRoles",
        "ItemNameRole",
        "ItemTypeRole",
        "HasDataRole",
        "ItemType",
        "TextEntry",
        "UrlEntry",
        "IntegerEntry",
        "RatingEntry",
        "DateEntry",
        "DurationEntry",
        "LongTextEntry"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'needDataByDatabaseIdAndUrl'
        QtMocHelpers::SignalData<void(ElisaUtils::PlayListEntryType, qulonglong, const QUrl &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::ULongLong, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'needDataByUrl'
        QtMocHelpers::SignalData<void(ElisaUtils::PlayListEntryType, const QUrl &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 8, 11 },
        }}),
        // Signal 'coverUrlChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fileUrlChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'managerChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lyricsChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'databaseIdChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'trackData'
        QtMocHelpers::SlotData<void(const TrackMetadataModel::TrackDataType &)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 17 },
        }}),
        // Slot 'initializeByIdAndUrl'
        QtMocHelpers::SlotData<void(ElisaUtils::PlayListEntryType, qulonglong, const QUrl &)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 20 }, { QMetaType::ULongLong, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Slot 'initializeByUrl'
        QtMocHelpers::SlotData<void(ElisaUtils::PlayListEntryType, const QUrl &)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 20 }, { 0x80000000 | 8, 9 },
        }}),
        // Slot 'initializeForNewRadio'
        QtMocHelpers::SlotData<void()>(22, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setManager'
        QtMocHelpers::SlotData<void(MusicListenersManager *)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'setDatabase'
        QtMocHelpers::SlotData<void(DatabaseInterface *)>(26, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'radioData'
        QtMocHelpers::SlotData<void(const TrackMetadataModel::TrackDataType &)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 30 },
        }}),
        // Slot 'lyricsValueIsReady'
        QtMocHelpers::SlotData<void()>(31, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'coverUrl'
        QtMocHelpers::PropertyData<QUrl>(32, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'fileUrl'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'databaseId'
        QtMocHelpers::PropertyData<qulonglong>(7, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 6),
        // property 'manager'
        QtMocHelpers::PropertyData<MusicListenersManager*>(34, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'lyrics'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ColumnRoles'
        QtMocHelpers::EnumData<enum ColumnRoles>(36, 36, QMC::EnumFlags{}).add({
            {   37, ColumnRoles::ItemNameRole },
            {   38, ColumnRoles::ItemTypeRole },
            {   39, ColumnRoles::HasDataRole },
        }),
        // enum 'ItemType'
        QtMocHelpers::EnumData<enum ItemType>(40, 40, QMC::EnumFlags{}).add({
            {   41, ItemType::TextEntry },
            {   42, ItemType::UrlEntry },
            {   43, ItemType::IntegerEntry },
            {   44, ItemType::RatingEntry },
            {   45, ItemType::DateEntry },
            {   46, ItemType::DurationEntry },
            {   47, ItemType::LongTextEntry },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<TrackMetadataModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TrackMetadataModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18TrackMetadataModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18TrackMetadataModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18TrackMetadataModelE_t>.metaTypes,
    nullptr
} };

void TrackMetadataModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TrackMetadataModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->needDataByDatabaseIdAndUrl((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3]))); break;
        case 1: _t->needDataByUrl((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 2: _t->coverUrlChanged(); break;
        case 3: _t->fileUrlChanged(); break;
        case 4: _t->managerChanged(); break;
        case 5: _t->lyricsChanged(); break;
        case 6: _t->databaseIdChanged(); break;
        case 7: _t->trackData((*reinterpret_cast<std::add_pointer_t<TrackMetadataModel::TrackDataType>>(_a[1]))); break;
        case 8: _t->initializeByIdAndUrl((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3]))); break;
        case 9: _t->initializeByUrl((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 10: _t->initializeForNewRadio(); break;
        case 11: _t->setManager((*reinterpret_cast<std::add_pointer_t<MusicListenersManager*>>(_a[1]))); break;
        case 12: _t->setDatabase((*reinterpret_cast<std::add_pointer_t<DatabaseInterface*>>(_a[1]))); break;
        case 13: _t->radioData((*reinterpret_cast<std::add_pointer_t<TrackMetadataModel::TrackDataType>>(_a[1]))); break;
        case 14: _t->lyricsValueIsReady(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DatabaseInterface* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TrackMetadataModel::*)(ElisaUtils::PlayListEntryType , qulonglong , const QUrl & )>(_a, &TrackMetadataModel::needDataByDatabaseIdAndUrl, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrackMetadataModel::*)(ElisaUtils::PlayListEntryType , const QUrl & )>(_a, &TrackMetadataModel::needDataByUrl, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrackMetadataModel::*)()>(_a, &TrackMetadataModel::coverUrlChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrackMetadataModel::*)()>(_a, &TrackMetadataModel::fileUrlChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrackMetadataModel::*)()>(_a, &TrackMetadataModel::managerChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrackMetadataModel::*)()>(_a, &TrackMetadataModel::lyricsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrackMetadataModel::*)()>(_a, &TrackMetadataModel::databaseIdChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QUrl*>(_v) = _t->coverUrl(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->fileUrl(); break;
        case 2: *reinterpret_cast<qulonglong*>(_v) = _t->databaseId(); break;
        case 3: *reinterpret_cast<MusicListenersManager**>(_v) = _t->manager(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->lyrics(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setManager(*reinterpret_cast<MusicListenersManager**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *TrackMetadataModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TrackMetadataModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18TrackMetadataModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int TrackMetadataModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void TrackMetadataModel::needDataByDatabaseIdAndUrl(ElisaUtils::PlayListEntryType _t1, qulonglong _t2, const QUrl & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void TrackMetadataModel::needDataByUrl(ElisaUtils::PlayListEntryType _t1, const QUrl & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void TrackMetadataModel::coverUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TrackMetadataModel::fileUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void TrackMetadataModel::managerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void TrackMetadataModel::lyricsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void TrackMetadataModel::databaseIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
