/****************************************************************************
** Meta object code from reading C++ file 'musiclistenersmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/musiclistenersmanager.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'musiclistenersmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21MusicListenersManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto MusicListenersManager::qt_create_metaobjectdata<qt_meta_tag_ZN21MusicListenersManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MusicListenersManager",
        "QML.Element",
        "auto",
        "viewDatabaseChanged",
        "",
        "applicationIsTerminating",
        "tracksListenerChanged",
        "importedTracksCountChanged",
        "elisaApplicationChanged",
        "removeTracksInError",
        "QList<QUrl>",
        "tracks",
        "displayTrackError",
        "fileName",
        "indexerBusyChanged",
        "clearDatabase",
        "clearedDatabase",
        "fileSystemIndexerActiveChanged",
        "androidIndexerActiveChanged",
        "androidIndexerAvailableChanged",
        "refreshDatabase",
        "databaseReady",
        "applicationAboutToQuit",
        "setElisaApplication",
        "ElisaApplication*",
        "elisaApplication",
        "playBackError",
        "QUrl",
        "sourceInError",
        "QMediaPlayer::Error",
        "playerError",
        "deleteElementById",
        "ElisaUtils::PlayListEntryType",
        "entryType",
        "databaseId",
        "connectModel",
        "ModelDataLoader*",
        "dataLoader",
        "scanCollection",
        "CollectionScan",
        "scantype",
        "updateSingleFileMetaData",
        "url",
        "DataTypes::ColumnsRoles",
        "role",
        "QVariant",
        "data",
        "configChanged",
        "increaseImportedTracksCount",
        "DataTypes::ListTrackDataType",
        "allTracks",
        "decreaseImportedTracksCount",
        "monitorStartingListeners",
        "monitorEndingListeners",
        "cleanedDatabase",
        "viewDatabase",
        "DatabaseInterface*",
        "importedTracksCount",
        "tracksListener",
        "TracksListener*",
        "indexerBusy",
        "fileSystemIndexerActive",
        "androidIndexerActive",
        "androidIndexerAvailable",
        "Soft",
        "Hard"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'viewDatabaseChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'applicationIsTerminating'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tracksListenerChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'importedTracksCountChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'elisaApplicationChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'removeTracksInError'
        QtMocHelpers::SignalData<void(const QList<QUrl> &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'displayTrackError'
        QtMocHelpers::SignalData<void(const QString &)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'indexerBusyChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clearDatabase'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clearedDatabase'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fileSystemIndexerActiveChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'androidIndexerActiveChanged'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'androidIndexerAvailableChanged'
        QtMocHelpers::SignalData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'refreshDatabase'
        QtMocHelpers::SignalData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'databaseReady'
        QtMocHelpers::SlotData<void()>(21, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'applicationAboutToQuit'
        QtMocHelpers::SlotData<void()>(22, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setElisaApplication'
        QtMocHelpers::SlotData<void(ElisaApplication *)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'playBackError'
        QtMocHelpers::SlotData<void(const QUrl &, QMediaPlayer::Error)>(26, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 }, { 0x80000000 | 29, 30 },
        }}),
        // Slot 'deleteElementById'
        QtMocHelpers::SlotData<void(ElisaUtils::PlayListEntryType, qulonglong)>(31, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 }, { QMetaType::ULongLong, 34 },
        }}),
        // Slot 'connectModel'
        QtMocHelpers::SlotData<void(ModelDataLoader *)>(35, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Slot 'scanCollection'
        QtMocHelpers::SlotData<void(enum CollectionScan)>(38, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 39, 40 },
        }}),
        // Slot 'updateSingleFileMetaData'
        QtMocHelpers::SlotData<void(const QUrl &, DataTypes::ColumnsRoles, const QVariant &)>(41, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 42 }, { 0x80000000 | 43, 44 }, { 0x80000000 | 45, 46 },
        }}),
        // Slot 'configChanged'
        QtMocHelpers::SlotData<void()>(47, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'increaseImportedTracksCount'
        QtMocHelpers::SlotData<void(const DataTypes::ListTrackDataType &)>(48, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 49, 50 },
        }}),
        // Slot 'decreaseImportedTracksCount'
        QtMocHelpers::SlotData<void()>(51, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'monitorStartingListeners'
        QtMocHelpers::SlotData<void()>(52, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'monitorEndingListeners'
        QtMocHelpers::SlotData<void()>(53, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cleanedDatabase'
        QtMocHelpers::SlotData<void()>(54, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'viewDatabase'
        QtMocHelpers::PropertyData<DatabaseInterface*>(55, 0x80000000 | 56, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'importedTracksCount'
        QtMocHelpers::PropertyData<int>(57, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
        // property 'elisaApplication'
        QtMocHelpers::PropertyData<ElisaApplication*>(25, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'tracksListener'
        QtMocHelpers::PropertyData<TracksListener*>(58, 0x80000000 | 59, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'indexerBusy'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
        // property 'fileSystemIndexerActive'
        QtMocHelpers::PropertyData<bool>(61, QMetaType::Bool, QMC::DefaultPropertyFlags, 10),
        // property 'androidIndexerActive'
        QtMocHelpers::PropertyData<bool>(62, QMetaType::Bool, QMC::DefaultPropertyFlags, 11),
        // property 'androidIndexerAvailable'
        QtMocHelpers::PropertyData<bool>(63, QMetaType::Bool, QMC::DefaultPropertyFlags, 12),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'CollectionScan'
        QtMocHelpers::EnumData<enum CollectionScan>(39, 39, QMC::EnumIsScoped).add({
            {   64, CollectionScan::Soft },
            {   65, CollectionScan::Hard },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<MusicListenersManager, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MusicListenersManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21MusicListenersManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21MusicListenersManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21MusicListenersManagerE_t>.metaTypes,
    nullptr
} };

void MusicListenersManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MusicListenersManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->viewDatabaseChanged(); break;
        case 1: _t->applicationIsTerminating(); break;
        case 2: _t->tracksListenerChanged(); break;
        case 3: _t->importedTracksCountChanged(); break;
        case 4: _t->elisaApplicationChanged(); break;
        case 5: _t->removeTracksInError((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 6: _t->displayTrackError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->indexerBusyChanged(); break;
        case 8: _t->clearDatabase(); break;
        case 9: _t->clearedDatabase(); break;
        case 10: _t->fileSystemIndexerActiveChanged(); break;
        case 11: _t->androidIndexerActiveChanged(); break;
        case 12: _t->androidIndexerAvailableChanged(); break;
        case 13: _t->refreshDatabase(); break;
        case 14: _t->databaseReady(); break;
        case 15: _t->applicationAboutToQuit(); break;
        case 16: _t->setElisaApplication((*reinterpret_cast<std::add_pointer_t<ElisaApplication*>>(_a[1]))); break;
        case 17: _t->playBackError((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMediaPlayer::Error>>(_a[2]))); break;
        case 18: _t->deleteElementById((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2]))); break;
        case 19: _t->connectModel((*reinterpret_cast<std::add_pointer_t<ModelDataLoader*>>(_a[1]))); break;
        case 20: _t->scanCollection((*reinterpret_cast<std::add_pointer_t<enum CollectionScan>>(_a[1]))); break;
        case 21: _t->updateSingleFileMetaData((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<DataTypes::ColumnsRoles>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3]))); break;
        case 22: _t->configChanged(); break;
        case 23: _t->increaseImportedTracksCount((*reinterpret_cast<std::add_pointer_t<DataTypes::ListTrackDataType>>(_a[1]))); break;
        case 24: _t->decreaseImportedTracksCount(); break;
        case 25: _t->monitorStartingListeners(); break;
        case 26: _t->monitorEndingListeners(); break;
        case 27: _t->cleanedDatabase(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::ListTrackDataType >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MusicListenersManager::*)()>(_a, &MusicListenersManager::viewDatabaseChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MusicListenersManager::*)()>(_a, &MusicListenersManager::applicationIsTerminating, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MusicListenersManager::*)()>(_a, &MusicListenersManager::tracksListenerChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MusicListenersManager::*)()>(_a, &MusicListenersManager::importedTracksCountChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MusicListenersManager::*)()>(_a, &MusicListenersManager::elisaApplicationChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MusicListenersManager::*)(const QList<QUrl> & )>(_a, &MusicListenersManager::removeTracksInError, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MusicListenersManager::*)(const QString & )>(_a, &MusicListenersManager::displayTrackError, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MusicListenersManager::*)()>(_a, &MusicListenersManager::indexerBusyChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MusicListenersManager::*)()>(_a, &MusicListenersManager::clearDatabase, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (MusicListenersManager::*)()>(_a, &MusicListenersManager::clearedDatabase, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (MusicListenersManager::*)()>(_a, &MusicListenersManager::fileSystemIndexerActiveChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (MusicListenersManager::*)()>(_a, &MusicListenersManager::androidIndexerActiveChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (MusicListenersManager::*)()>(_a, &MusicListenersManager::androidIndexerAvailableChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (MusicListenersManager::*)()>(_a, &MusicListenersManager::refreshDatabase, 13))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<DatabaseInterface**>(_v) = _t->viewDatabase(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->importedTracksCount(); break;
        case 2: *reinterpret_cast<ElisaApplication**>(_v) = _t->elisaApplication(); break;
        case 3: *reinterpret_cast<TracksListener**>(_v) = _t->tracksListener(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->indexerBusy(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->fileSystemIndexerActive(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->androidIndexerActive(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->androidIndexerAvailable(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setElisaApplication(*reinterpret_cast<ElisaApplication**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MusicListenersManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MusicListenersManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21MusicListenersManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int MusicListenersManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void MusicListenersManager::viewDatabaseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MusicListenersManager::applicationIsTerminating()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MusicListenersManager::tracksListenerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MusicListenersManager::importedTracksCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void MusicListenersManager::elisaApplicationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void MusicListenersManager::removeTracksInError(const QList<QUrl> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void MusicListenersManager::displayTrackError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void MusicListenersManager::indexerBusyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void MusicListenersManager::clearDatabase()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void MusicListenersManager::clearedDatabase()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void MusicListenersManager::fileSystemIndexerActiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void MusicListenersManager::androidIndexerActiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void MusicListenersManager::androidIndexerAvailableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void MusicListenersManager::refreshDatabase()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}
QT_WARNING_POP
