/****************************************************************************
** Meta object code from reading C++ file 'abstractfilelisting.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/abstractfile/abstractfilelisting.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractfilelisting.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19AbstractFileListingE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractFileListing::qt_create_metaobjectdata<qt_meta_tag_ZN19AbstractFileListingE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractFileListing",
        "tracksList",
        "",
        "DataTypes::ListTrackDataType",
        "tracks",
        "removedTracksList",
        "QList<QUrl>",
        "removedTracks",
        "modifyTracksList",
        "modifiedTracks",
        "indexingStarted",
        "indexingFinished",
        "askRestoredTracks",
        "errorWatchingFileSystemChanges",
        "setIndexedTracks",
        "QHash<QUrl,QDateTime>",
        "allTracks",
        "resetAndRefreshContent",
        "refreshContent",
        "init",
        "stop",
        "newTrackFile",
        "DataTypes::TrackDataType",
        "partialTrack",
        "setAllRootPaths",
        "allRootPaths",
        "databaseFinishedInsertingTracksList",
        "databaseFinishedRemovingTracksList",
        "directoryChanged",
        "path",
        "fileChanged",
        "modifiedFileName"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'tracksList'
        QtMocHelpers::SignalData<void(const DataTypes::ListTrackDataType &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'removedTracksList'
        QtMocHelpers::SignalData<void(const QList<QUrl> &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'modifyTracksList'
        QtMocHelpers::SignalData<void(const DataTypes::ListTrackDataType &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 9 },
        }}),
        // Signal 'indexingStarted'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'indexingFinished'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'askRestoredTracks'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorWatchingFileSystemChanges'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setIndexedTracks'
        QtMocHelpers::SlotData<void(const QHash<QUrl,QDateTime> &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'resetAndRefreshContent'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'refreshContent'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'init'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'newTrackFile'
        QtMocHelpers::SlotData<void(const DataTypes::TrackDataType &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'setAllRootPaths'
        QtMocHelpers::SlotData<void(const QStringList &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 25 },
        }}),
        // Slot 'databaseFinishedInsertingTracksList'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'databaseFinishedRemovingTracksList'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'directoryChanged'
        QtMocHelpers::SlotData<void(const QString &)>(28, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 29 },
        }}),
        // Slot 'fileChanged'
        QtMocHelpers::SlotData<void(const QString &)>(30, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractFileListing, qt_meta_tag_ZN19AbstractFileListingE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AbstractFileListing::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AbstractFileListingE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AbstractFileListingE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19AbstractFileListingE_t>.metaTypes,
    nullptr
} };

void AbstractFileListing::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractFileListing *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->tracksList((*reinterpret_cast<std::add_pointer_t<DataTypes::ListTrackDataType>>(_a[1]))); break;
        case 1: _t->removedTracksList((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 2: _t->modifyTracksList((*reinterpret_cast<std::add_pointer_t<DataTypes::ListTrackDataType>>(_a[1]))); break;
        case 3: _t->indexingStarted(); break;
        case 4: _t->indexingFinished(); break;
        case 5: _t->askRestoredTracks(); break;
        case 6: _t->errorWatchingFileSystemChanges(); break;
        case 7: _t->setIndexedTracks((*reinterpret_cast<std::add_pointer_t<QHash<QUrl,QDateTime>>>(_a[1]))); break;
        case 8: _t->resetAndRefreshContent(); break;
        case 9: _t->refreshContent(); break;
        case 10: _t->init(); break;
        case 11: _t->stop(); break;
        case 12: _t->newTrackFile((*reinterpret_cast<std::add_pointer_t<DataTypes::TrackDataType>>(_a[1]))); break;
        case 13: _t->setAllRootPaths((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 14: _t->databaseFinishedInsertingTracksList(); break;
        case 15: _t->databaseFinishedRemovingTracksList(); break;
        case 16: _t->directoryChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->fileChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::ListTrackDataType >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::ListTrackDataType >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::TrackDataType >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractFileListing::*)(const DataTypes::ListTrackDataType & )>(_a, &AbstractFileListing::tracksList, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractFileListing::*)(const QList<QUrl> & )>(_a, &AbstractFileListing::removedTracksList, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractFileListing::*)(const DataTypes::ListTrackDataType & )>(_a, &AbstractFileListing::modifyTracksList, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractFileListing::*)()>(_a, &AbstractFileListing::indexingStarted, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractFileListing::*)()>(_a, &AbstractFileListing::indexingFinished, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractFileListing::*)()>(_a, &AbstractFileListing::askRestoredTracks, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractFileListing::*)()>(_a, &AbstractFileListing::errorWatchingFileSystemChanges, 6))
            return;
    }
}

const QMetaObject *AbstractFileListing::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractFileListing::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AbstractFileListingE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AbstractFileListing::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void AbstractFileListing::tracksList(const DataTypes::ListTrackDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AbstractFileListing::removedTracksList(const QList<QUrl> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AbstractFileListing::modifyTracksList(const DataTypes::ListTrackDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void AbstractFileListing::indexingStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AbstractFileListing::indexingFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AbstractFileListing::askRestoredTracks()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void AbstractFileListing::errorWatchingFileSystemChanges()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
