/****************************************************************************
** Meta object code from reading C++ file 'manageheaderbar.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/manageheaderbar.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'manageheaderbar.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15ManageHeaderBarE_t {};
} // unnamed namespace

template <> constexpr inline auto ManageHeaderBar::qt_create_metaobjectdata<qt_meta_tag_ZN15ManageHeaderBarE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ManageHeaderBar",
        "QML.Element",
        "auto",
        "currentTrackChanged",
        "",
        "artistRoleChanged",
        "titleRoleChanged",
        "albumRoleChanged",
        "albumArtistRoleChanged",
        "fileNameRoleChanged",
        "imageRoleChanged",
        "databaseIdRoleChanged",
        "trackTypeRoleChanged",
        "albumIdRoleChanged",
        "isValidRoleChanged",
        "artistChanged",
        "titleChanged",
        "albumChanged",
        "albumArtistChanged",
        "fileUrlChanged",
        "imageChanged",
        "databaseIdChanged",
        "albumIdChanged",
        "trackTypeChanged",
        "isValidChanged",
        "setCurrentTrack",
        "QPersistentModelIndex",
        "currentTrack",
        "updateCurrentTrackData",
        "setArtistRole",
        "value",
        "setTitleRole",
        "setAlbumRole",
        "setAlbumArtistRole",
        "setFileNameRole",
        "setImageRole",
        "setDatabaseIdRole",
        "databaseIdRole",
        "setTrackTypeRole",
        "trackTypeRole",
        "setAlbumIdRole",
        "albumIdRole",
        "setIsValidRole",
        "isValidRole",
        "artistRole",
        "titleRole",
        "albumRole",
        "albumArtistRole",
        "fileNameRole",
        "imageRole",
        "artist",
        "QVariant",
        "title",
        "album",
        "albumArtist",
        "fileUrl",
        "QUrl",
        "image",
        "databaseId",
        "trackType",
        "ElisaUtils::PlayListEntryType",
        "albumId",
        "isValid"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentTrackChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'artistRoleChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleRoleChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'albumRoleChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'albumArtistRoleChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fileNameRoleChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imageRoleChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'databaseIdRoleChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trackTypeRoleChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'albumIdRoleChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isValidRoleChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'artistChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'albumChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'albumArtistChanged'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fileUrlChanged'
        QtMocHelpers::SignalData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imageChanged'
        QtMocHelpers::SignalData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'databaseIdChanged'
        QtMocHelpers::SignalData<void()>(21, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'albumIdChanged'
        QtMocHelpers::SignalData<void()>(22, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trackTypeChanged'
        QtMocHelpers::SignalData<void()>(23, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isValidChanged'
        QtMocHelpers::SignalData<void()>(24, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setCurrentTrack'
        QtMocHelpers::SlotData<void(const QPersistentModelIndex &)>(25, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'updateCurrentTrackData'
        QtMocHelpers::SlotData<void()>(28, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setArtistRole'
        QtMocHelpers::SlotData<void(int)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 30 },
        }}),
        // Slot 'setTitleRole'
        QtMocHelpers::SlotData<void(int)>(31, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 30 },
        }}),
        // Slot 'setAlbumRole'
        QtMocHelpers::SlotData<void(int)>(32, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 30 },
        }}),
        // Slot 'setAlbumArtistRole'
        QtMocHelpers::SlotData<void(int)>(33, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 30 },
        }}),
        // Slot 'setFileNameRole'
        QtMocHelpers::SlotData<void(int)>(34, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 30 },
        }}),
        // Slot 'setImageRole'
        QtMocHelpers::SlotData<void(int)>(35, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 30 },
        }}),
        // Slot 'setDatabaseIdRole'
        QtMocHelpers::SlotData<void(int)>(36, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 37 },
        }}),
        // Slot 'setTrackTypeRole'
        QtMocHelpers::SlotData<void(int)>(38, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 39 },
        }}),
        // Slot 'setAlbumIdRole'
        QtMocHelpers::SlotData<void(int)>(40, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 41 },
        }}),
        // Slot 'setIsValidRole'
        QtMocHelpers::SlotData<void(int)>(42, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 43 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'currentTrack'
        QtMocHelpers::PropertyData<QPersistentModelIndex>(27, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'artistRole'
        QtMocHelpers::PropertyData<int>(44, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'titleRole'
        QtMocHelpers::PropertyData<int>(45, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'albumRole'
        QtMocHelpers::PropertyData<int>(46, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'albumArtistRole'
        QtMocHelpers::PropertyData<int>(47, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'fileNameRole'
        QtMocHelpers::PropertyData<int>(48, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'imageRole'
        QtMocHelpers::PropertyData<int>(49, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'databaseIdRole'
        QtMocHelpers::PropertyData<int>(37, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'trackTypeRole'
        QtMocHelpers::PropertyData<int>(39, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'albumIdRole'
        QtMocHelpers::PropertyData<int>(41, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isValidRole'
        QtMocHelpers::PropertyData<int>(43, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'artist'
        QtMocHelpers::PropertyData<QVariant>(50, 0x80000000 | 51, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 11),
        // property 'title'
        QtMocHelpers::PropertyData<QVariant>(52, 0x80000000 | 51, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 12),
        // property 'album'
        QtMocHelpers::PropertyData<QVariant>(53, 0x80000000 | 51, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 13),
        // property 'albumArtist'
        QtMocHelpers::PropertyData<QVariant>(54, 0x80000000 | 51, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 14),
        // property 'fileUrl'
        QtMocHelpers::PropertyData<QUrl>(55, 0x80000000 | 56, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 15),
        // property 'image'
        QtMocHelpers::PropertyData<QUrl>(57, 0x80000000 | 56, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 16),
        // property 'databaseId'
        QtMocHelpers::PropertyData<qulonglong>(58, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 17),
        // property 'trackType'
        QtMocHelpers::PropertyData<ElisaUtils::PlayListEntryType>(59, 0x80000000 | 60, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 19),
        // property 'albumId'
        QtMocHelpers::PropertyData<qulonglong>(61, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 18),
        // property 'isValid'
        QtMocHelpers::PropertyData<bool>(62, QMetaType::Bool, QMC::DefaultPropertyFlags, 20),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ManageHeaderBar, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN15ManageHeaderBarE[] = {
    QMetaObject::SuperData::link<ElisaUtils::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject ManageHeaderBar::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ManageHeaderBarE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ManageHeaderBarE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN15ManageHeaderBarE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15ManageHeaderBarE_t>.metaTypes,
    nullptr
} };

void ManageHeaderBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ManageHeaderBar *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentTrackChanged(); break;
        case 1: _t->artistRoleChanged(); break;
        case 2: _t->titleRoleChanged(); break;
        case 3: _t->albumRoleChanged(); break;
        case 4: _t->albumArtistRoleChanged(); break;
        case 5: _t->fileNameRoleChanged(); break;
        case 6: _t->imageRoleChanged(); break;
        case 7: _t->databaseIdRoleChanged(); break;
        case 8: _t->trackTypeRoleChanged(); break;
        case 9: _t->albumIdRoleChanged(); break;
        case 10: _t->isValidRoleChanged(); break;
        case 11: _t->artistChanged(); break;
        case 12: _t->titleChanged(); break;
        case 13: _t->albumChanged(); break;
        case 14: _t->albumArtistChanged(); break;
        case 15: _t->fileUrlChanged(); break;
        case 16: _t->imageChanged(); break;
        case 17: _t->databaseIdChanged(); break;
        case 18: _t->albumIdChanged(); break;
        case 19: _t->trackTypeChanged(); break;
        case 20: _t->isValidChanged(); break;
        case 21: _t->setCurrentTrack((*reinterpret_cast<std::add_pointer_t<QPersistentModelIndex>>(_a[1]))); break;
        case 22: _t->updateCurrentTrackData(); break;
        case 23: _t->setArtistRole((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 24: _t->setTitleRole((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 25: _t->setAlbumRole((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->setAlbumArtistRole((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 27: _t->setFileNameRole((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: _t->setImageRole((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 29: _t->setDatabaseIdRole((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 30: _t->setTrackTypeRole((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 31: _t->setAlbumIdRole((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 32: _t->setIsValidRole((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ManageHeaderBar::*)()>(_a, &ManageHeaderBar::currentTrackChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageHeaderBar::*)()>(_a, &ManageHeaderBar::artistRoleChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageHeaderBar::*)()>(_a, &ManageHeaderBar::titleRoleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageHeaderBar::*)()>(_a, &ManageHeaderBar::albumRoleChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageHeaderBar::*)()>(_a, &ManageHeaderBar::albumArtistRoleChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageHeaderBar::*)()>(_a, &ManageHeaderBar::fileNameRoleChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageHeaderBar::*)()>(_a, &ManageHeaderBar::imageRoleChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageHeaderBar::*)()>(_a, &ManageHeaderBar::databaseIdRoleChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageHeaderBar::*)()>(_a, &ManageHeaderBar::trackTypeRoleChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageHeaderBar::*)()>(_a, &ManageHeaderBar::albumIdRoleChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageHeaderBar::*)()>(_a, &ManageHeaderBar::isValidRoleChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageHeaderBar::*)()>(_a, &ManageHeaderBar::artistChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageHeaderBar::*)()>(_a, &ManageHeaderBar::titleChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageHeaderBar::*)()>(_a, &ManageHeaderBar::albumChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageHeaderBar::*)()>(_a, &ManageHeaderBar::albumArtistChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageHeaderBar::*)()>(_a, &ManageHeaderBar::fileUrlChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageHeaderBar::*)()>(_a, &ManageHeaderBar::imageChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageHeaderBar::*)()>(_a, &ManageHeaderBar::databaseIdChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageHeaderBar::*)()>(_a, &ManageHeaderBar::albumIdChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageHeaderBar::*)()>(_a, &ManageHeaderBar::trackTypeChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageHeaderBar::*)()>(_a, &ManageHeaderBar::isValidChanged, 20))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QPersistentModelIndex*>(_v) = _t->currentTrack(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->artistRole(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->titleRole(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->albumRole(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->albumArtistRole(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->fileNameRole(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->imageRole(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->databaseIdRole(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->trackTypeRole(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->albumIdRole(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->isValidRole(); break;
        case 11: *reinterpret_cast<QVariant*>(_v) = _t->artist(); break;
        case 12: *reinterpret_cast<QVariant*>(_v) = _t->title(); break;
        case 13: *reinterpret_cast<QVariant*>(_v) = _t->album(); break;
        case 14: *reinterpret_cast<QVariant*>(_v) = _t->albumArtist(); break;
        case 15: *reinterpret_cast<QUrl*>(_v) = _t->fileUrl(); break;
        case 16: *reinterpret_cast<QUrl*>(_v) = _t->image(); break;
        case 17: *reinterpret_cast<qulonglong*>(_v) = _t->databaseId(); break;
        case 18: *reinterpret_cast<ElisaUtils::PlayListEntryType*>(_v) = _t->trackType(); break;
        case 19: *reinterpret_cast<qulonglong*>(_v) = _t->albumId(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->isValid(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCurrentTrack(*reinterpret_cast<QPersistentModelIndex*>(_v)); break;
        case 1: _t->setArtistRole(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setTitleRole(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setAlbumRole(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setAlbumArtistRole(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setFileNameRole(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setImageRole(*reinterpret_cast<int*>(_v)); break;
        case 7: _t->setDatabaseIdRole(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setTrackTypeRole(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setAlbumIdRole(*reinterpret_cast<int*>(_v)); break;
        case 10: _t->setIsValidRole(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ManageHeaderBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ManageHeaderBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ManageHeaderBarE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ManageHeaderBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 33)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 33;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void ManageHeaderBar::currentTrackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ManageHeaderBar::artistRoleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ManageHeaderBar::titleRoleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ManageHeaderBar::albumRoleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ManageHeaderBar::albumArtistRoleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ManageHeaderBar::fileNameRoleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ManageHeaderBar::imageRoleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ManageHeaderBar::databaseIdRoleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ManageHeaderBar::trackTypeRoleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ManageHeaderBar::albumIdRoleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void ManageHeaderBar::isValidRoleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void ManageHeaderBar::artistChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void ManageHeaderBar::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void ManageHeaderBar::albumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void ManageHeaderBar::albumArtistChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void ManageHeaderBar::fileUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void ManageHeaderBar::imageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void ManageHeaderBar::databaseIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void ManageHeaderBar::albumIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void ManageHeaderBar::trackTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void ManageHeaderBar::isValidChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}
QT_WARNING_POP
