/****************************************************************************
** Meta object code from reading C++ file 'datamodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/models/datamodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'datamodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9DataModelE_t {};
} // unnamed namespace

template <> constexpr inline auto DataModel::qt_create_metaobjectdata<qt_meta_tag_ZN9DataModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DataModel",
        "QML.Element",
        "auto",
        "titleChanged",
        "",
        "authorChanged",
        "needData",
        "ElisaUtils::PlayListEntryType",
        "dataType",
        "needDataById",
        "databaseId",
        "needDataByGenre",
        "genre",
        "needDataByArtist",
        "artist",
        "needDataByGenreAndArtist",
        "needRecentlyPlayedData",
        "needFrequentlyPlayedData",
        "isBusyChanged",
        "tracksAdded",
        "DataModel::ListTrackDataType",
        "newData",
        "radiosAdded",
        "DataModel::ListRadioDataType",
        "trackModified",
        "DataModel::TrackDataType",
        "modifiedTrack",
        "trackRemoved",
        "removedTrackId",
        "radioRemoved",
        "removedRadioId",
        "genresAdded",
        "DataModel::ListGenreDataType",
        "genreRemoved",
        "removedDatabaseId",
        "artistsAdded",
        "DataModel::ListArtistDataType",
        "artistRemoved",
        "albumsAdded",
        "DataModel::ListAlbumDataType",
        "albumRemoved",
        "albumModified",
        "DataModel::AlbumDataType",
        "modifiedAlbum",
        "initialize",
        "MusicListenersManager*",
        "manager",
        "DatabaseInterface*",
        "database",
        "modelType",
        "ElisaUtils::FilterType",
        "filter",
        "QUrl",
        "pathFilter",
        "initializeByData",
        "DataTypes::DataType",
        "dataFilter",
        "cleanedDatabase",
        "title",
        "author",
        "isBusy"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'authorChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'needData'
        QtMocHelpers::SignalData<void(ElisaUtils::PlayListEntryType)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'needDataById'
        QtMocHelpers::SignalData<void(ElisaUtils::PlayListEntryType, qulonglong)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::ULongLong, 10 },
        }}),
        // Signal 'needDataByGenre'
        QtMocHelpers::SignalData<void(ElisaUtils::PlayListEntryType, const QString &)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::QString, 12 },
        }}),
        // Signal 'needDataByArtist'
        QtMocHelpers::SignalData<void(ElisaUtils::PlayListEntryType, const QString &)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::QString, 14 },
        }}),
        // Signal 'needDataByGenreAndArtist'
        QtMocHelpers::SignalData<void(ElisaUtils::PlayListEntryType, const QString &, const QString &)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::QString, 12 }, { QMetaType::QString, 14 },
        }}),
        // Signal 'needRecentlyPlayedData'
        QtMocHelpers::SignalData<void(ElisaUtils::PlayListEntryType)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'needFrequentlyPlayedData'
        QtMocHelpers::SignalData<void(ElisaUtils::PlayListEntryType)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'isBusyChanged'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'tracksAdded'
        QtMocHelpers::SlotData<void(DataModel::ListTrackDataType)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'radiosAdded'
        QtMocHelpers::SlotData<void(DataModel::ListRadioDataType)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 21 },
        }}),
        // Slot 'trackModified'
        QtMocHelpers::SlotData<void(const DataModel::TrackDataType &)>(24, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'trackRemoved'
        QtMocHelpers::SlotData<void(qulonglong)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 28 },
        }}),
        // Slot 'radioRemoved'
        QtMocHelpers::SlotData<void(qulonglong)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 30 },
        }}),
        // Slot 'genresAdded'
        QtMocHelpers::SlotData<void(DataModel::ListGenreDataType)>(31, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 21 },
        }}),
        // Slot 'genreRemoved'
        QtMocHelpers::SlotData<void(qulonglong)>(33, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 34 },
        }}),
        // Slot 'artistsAdded'
        QtMocHelpers::SlotData<void(DataModel::ListArtistDataType)>(35, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 21 },
        }}),
        // Slot 'artistRemoved'
        QtMocHelpers::SlotData<void(qulonglong)>(37, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 34 },
        }}),
        // Slot 'albumsAdded'
        QtMocHelpers::SlotData<void(DataModel::ListAlbumDataType)>(38, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 39, 21 },
        }}),
        // Slot 'albumRemoved'
        QtMocHelpers::SlotData<void(qulonglong)>(40, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 34 },
        }}),
        // Slot 'albumModified'
        QtMocHelpers::SlotData<void(const DataModel::AlbumDataType &)>(41, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 42, 43 },
        }}),
        // Slot 'initialize'
        QtMocHelpers::SlotData<void(MusicListenersManager *, DatabaseInterface *, ElisaUtils::PlayListEntryType, ElisaUtils::FilterType, const QString &, const QString &, qulonglong, const QUrl &)>(44, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 45, 46 }, { 0x80000000 | 47, 48 }, { 0x80000000 | 7, 49 }, { 0x80000000 | 50, 51 },
            { QMetaType::QString, 12 }, { QMetaType::QString, 14 }, { QMetaType::ULongLong, 10 }, { 0x80000000 | 52, 53 },
        }}),
        // Slot 'initializeByData'
        QtMocHelpers::SlotData<void(MusicListenersManager *, DatabaseInterface *, ElisaUtils::PlayListEntryType, ElisaUtils::FilterType, const DataTypes::DataType &)>(54, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 45, 46 }, { 0x80000000 | 47, 48 }, { 0x80000000 | 7, 49 }, { 0x80000000 | 50, 51 },
            { 0x80000000 | 55, 56 },
        }}),
        // Slot 'cleanedDatabase'
        QtMocHelpers::SlotData<void()>(57, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'title'
        QtMocHelpers::PropertyData<QString>(58, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'author'
        QtMocHelpers::PropertyData<QString>(59, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'isBusy'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags, 9),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DataModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DataModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DataModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DataModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9DataModelE_t>.metaTypes,
    nullptr
} };

void DataModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DataModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->titleChanged(); break;
        case 1: _t->authorChanged(); break;
        case 2: _t->needData((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1]))); break;
        case 3: _t->needDataById((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2]))); break;
        case 4: _t->needDataByGenre((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->needDataByArtist((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->needDataByGenreAndArtist((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 7: _t->needRecentlyPlayedData((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1]))); break;
        case 8: _t->needFrequentlyPlayedData((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1]))); break;
        case 9: _t->isBusyChanged(); break;
        case 10: _t->tracksAdded((*reinterpret_cast<std::add_pointer_t<DataModel::ListTrackDataType>>(_a[1]))); break;
        case 11: _t->radiosAdded((*reinterpret_cast<std::add_pointer_t<DataModel::ListRadioDataType>>(_a[1]))); break;
        case 12: _t->trackModified((*reinterpret_cast<std::add_pointer_t<DataModel::TrackDataType>>(_a[1]))); break;
        case 13: _t->trackRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 14: _t->radioRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 15: _t->genresAdded((*reinterpret_cast<std::add_pointer_t<DataModel::ListGenreDataType>>(_a[1]))); break;
        case 16: _t->genreRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 17: _t->artistsAdded((*reinterpret_cast<std::add_pointer_t<DataModel::ListArtistDataType>>(_a[1]))); break;
        case 18: _t->artistRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 19: _t->albumsAdded((*reinterpret_cast<std::add_pointer_t<DataModel::ListAlbumDataType>>(_a[1]))); break;
        case 20: _t->albumRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 21: _t->albumModified((*reinterpret_cast<std::add_pointer_t<DataModel::AlbumDataType>>(_a[1]))); break;
        case 22: _t->initialize((*reinterpret_cast<std::add_pointer_t<MusicListenersManager*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<DatabaseInterface*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::FilterType>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[8]))); break;
        case 23: _t->initializeByData((*reinterpret_cast<std::add_pointer_t<MusicListenersManager*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<DatabaseInterface*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::FilterType>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<DataTypes::DataType>>(_a[5]))); break;
        case 24: _t->cleanedDatabase(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DataModel::*)()>(_a, &DataModel::titleChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataModel::*)()>(_a, &DataModel::authorChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataModel::*)(ElisaUtils::PlayListEntryType )>(_a, &DataModel::needData, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataModel::*)(ElisaUtils::PlayListEntryType , qulonglong )>(_a, &DataModel::needDataById, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataModel::*)(ElisaUtils::PlayListEntryType , const QString & )>(_a, &DataModel::needDataByGenre, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataModel::*)(ElisaUtils::PlayListEntryType , const QString & )>(_a, &DataModel::needDataByArtist, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataModel::*)(ElisaUtils::PlayListEntryType , const QString & , const QString & )>(_a, &DataModel::needDataByGenreAndArtist, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataModel::*)(ElisaUtils::PlayListEntryType )>(_a, &DataModel::needRecentlyPlayedData, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataModel::*)(ElisaUtils::PlayListEntryType )>(_a, &DataModel::needFrequentlyPlayedData, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataModel::*)()>(_a, &DataModel::isBusyChanged, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->author(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isBusy(); break;
        default: break;
        }
    }
}

const QMetaObject *DataModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DataModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9DataModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int DataModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 25;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void DataModel::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DataModel::authorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DataModel::needData(ElisaUtils::PlayListEntryType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DataModel::needDataById(ElisaUtils::PlayListEntryType _t1, qulonglong _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void DataModel::needDataByGenre(ElisaUtils::PlayListEntryType _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void DataModel::needDataByArtist(ElisaUtils::PlayListEntryType _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void DataModel::needDataByGenreAndArtist(ElisaUtils::PlayListEntryType _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}

// SIGNAL 7
void DataModel::needRecentlyPlayedData(ElisaUtils::PlayListEntryType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void DataModel::needFrequentlyPlayedData(ElisaUtils::PlayListEntryType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void DataModel::isBusyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
