/****************************************************************************
** Meta object code from reading C++ file 'mediaplaylistproxymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/mediaplaylistproxymodel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mediaplaylistproxymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23MediaPlayListProxyModelE_t {};
} // unnamed namespace

template <> constexpr inline auto MediaPlayListProxyModel::qt_create_metaobjectdata<qt_meta_tag_ZN23MediaPlayListProxyModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MediaPlayListProxyModel",
        "QML.Element",
        "auto",
        "previousTrackChanged",
        "",
        "QPersistentModelIndex",
        "previousTrack",
        "currentTrackChanged",
        "currentTrack",
        "nextTrackChanged",
        "nextTrack",
        "previousTrackDataChanged",
        "currentTrackDataChanged",
        "nextTrackDataChanged",
        "repeatModeChanged",
        "shuffleModeChanged",
        "totalTracksDurationChanged",
        "remainingTracksDurationChanged",
        "remainingTracksChanged",
        "ensurePlay",
        "requestPlay",
        "currentTrackRowChanged",
        "radioCountChanged",
        "tracksCountChanged",
        "playListFinished",
        "playListLoaded",
        "playListLoadFailed",
        "persistentStateChanged",
        "clearPlayListPlayer",
        "undoClearPlayListPlayer",
        "displayUndoNotification",
        "hideUndoNotification",
        "seek",
        "position",
        "partiallyLoadedChanged",
        "canOpenLoadedPlaylistChanged",
        "enqueue",
        "QUrl",
        "entryUrl",
        "ElisaUtils::PlayListEnqueueMode",
        "enqueueMode",
        "ElisaUtils::PlayListEnqueueTriggerPlay",
        "triggerPlay",
        "DataTypes::MusicDataType",
        "newEntry",
        "newEntryTitle",
        "DataTypes::EntryDataList",
        "newEntries",
        "setRepeatMode",
        "Repeat",
        "value",
        "setShuffleMode",
        "Shuffle",
        "trackInError",
        "sourceInError",
        "QMediaPlayer::Error",
        "playerError",
        "skipNextTrack",
        "ElisaUtils::SkipReason",
        "reason",
        "skipPreviousTrack",
        "switchTo",
        "row",
        "removeSelection",
        "QList<int>",
        "selection",
        "removeRow",
        "moveRow",
        "from",
        "to",
        "clearPlayList",
        "undoClearPlayList",
        "savePlayList",
        "fileName",
        "loadPlayList",
        "setPersistentState",
        "QVariantMap",
        "persistentState",
        "openLoadedPlayList",
        "resetPartiallyLoaded",
        "indexForTrackUrl",
        "url",
        "switchToTrackUrl",
        "sourceRowsAboutToBeInserted",
        "QModelIndex",
        "parent",
        "start",
        "end",
        "sourceRowsInserted",
        "sourceRowsAboutToBeRemoved",
        "sourceRowsRemoved",
        "sourceRowsAboutToBeMoved",
        "destParent",
        "destRow",
        "sourceRowsMoved",
        "sourceDataChanged",
        "topLeft",
        "bottomRight",
        "roles",
        "sourceHeaderDataChanged",
        "Qt::Orientation",
        "orientation",
        "first",
        "last",
        "sourceLayoutAboutToBeChanged",
        "sourceLayoutChanged",
        "sourceModelAboutToBeReset",
        "sourceModelReset",
        "repeatMode",
        "shuffleMode",
        "totalTracksDuration",
        "remainingTracksDuration",
        "remainingTracks",
        "currentTrackRow",
        "radioCount",
        "tracksCount",
        "partiallyLoaded",
        "canOpenLoadedPlaylist",
        "None",
        "One",
        "Playlist",
        "NoShuffle",
        "Track",
        "Album"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'previousTrackChanged'
        QtMocHelpers::SignalData<void(const QPersistentModelIndex &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'currentTrackChanged'
        QtMocHelpers::SignalData<void(const QPersistentModelIndex &)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 8 },
        }}),
        // Signal 'nextTrackChanged'
        QtMocHelpers::SignalData<void(const QPersistentModelIndex &)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 10 },
        }}),
        // Signal 'previousTrackDataChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentTrackDataChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nextTrackDataChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'repeatModeChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shuffleModeChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'totalTracksDurationChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'remainingTracksDurationChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'remainingTracksChanged'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ensurePlay'
        QtMocHelpers::SignalData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestPlay'
        QtMocHelpers::SignalData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentTrackRowChanged'
        QtMocHelpers::SignalData<void()>(21, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'radioCountChanged'
        QtMocHelpers::SignalData<void()>(22, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tracksCountChanged'
        QtMocHelpers::SignalData<void()>(23, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playListFinished'
        QtMocHelpers::SignalData<void()>(24, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playListLoaded'
        QtMocHelpers::SignalData<void()>(25, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playListLoadFailed'
        QtMocHelpers::SignalData<void()>(26, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'persistentStateChanged'
        QtMocHelpers::SignalData<void()>(27, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clearPlayListPlayer'
        QtMocHelpers::SignalData<void()>(28, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'undoClearPlayListPlayer'
        QtMocHelpers::SignalData<void()>(29, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'displayUndoNotification'
        QtMocHelpers::SignalData<void()>(30, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hideUndoNotification'
        QtMocHelpers::SignalData<void()>(31, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'seek'
        QtMocHelpers::SignalData<void(qint64)>(32, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 33 },
        }}),
        // Signal 'partiallyLoadedChanged'
        QtMocHelpers::SignalData<void()>(34, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canOpenLoadedPlaylistChanged'
        QtMocHelpers::SignalData<void()>(35, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'enqueue'
        QtMocHelpers::SlotData<void(const QUrl &, ElisaUtils::PlayListEnqueueMode, ElisaUtils::PlayListEnqueueTriggerPlay)>(36, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 37, 38 }, { 0x80000000 | 39, 40 }, { 0x80000000 | 41, 42 },
        }}),
        // Slot 'enqueue'
        QtMocHelpers::SlotData<void(const DataTypes::MusicDataType &, const QString &, ElisaUtils::PlayListEnqueueMode, ElisaUtils::PlayListEnqueueTriggerPlay)>(36, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 43, 44 }, { QMetaType::QString, 45 }, { 0x80000000 | 39, 40 }, { 0x80000000 | 41, 42 },
        }}),
        // Slot 'enqueue'
        QtMocHelpers::SlotData<void(const DataTypes::EntryDataList &, ElisaUtils::PlayListEnqueueMode, ElisaUtils::PlayListEnqueueTriggerPlay)>(36, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 46, 47 }, { 0x80000000 | 39, 40 }, { 0x80000000 | 41, 42 },
        }}),
        // Slot 'setRepeatMode'
        QtMocHelpers::SlotData<void(enum Repeat)>(48, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 49, 50 },
        }}),
        // Slot 'setShuffleMode'
        QtMocHelpers::SlotData<void(enum Shuffle)>(51, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 52, 50 },
        }}),
        // Slot 'trackInError'
        QtMocHelpers::SlotData<void(const QUrl &, QMediaPlayer::Error)>(53, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 37, 54 }, { 0x80000000 | 55, 56 },
        }}),
        // Slot 'skipNextTrack'
        QtMocHelpers::SlotData<void(ElisaUtils::SkipReason)>(57, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 58, 59 },
        }}),
        // Slot 'skipNextTrack'
        QtMocHelpers::SlotData<void()>(57, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'skipPreviousTrack'
        QtMocHelpers::SlotData<void(qint64)>(60, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 33 },
        }}),
        // Slot 'switchTo'
        QtMocHelpers::SlotData<void(int)>(61, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 62 },
        }}),
        // Slot 'removeSelection'
        QtMocHelpers::SlotData<void(QList<int>)>(63, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 64, 65 },
        }}),
        // Slot 'removeRow'
        QtMocHelpers::SlotData<void(int)>(66, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 62 },
        }}),
        // Slot 'moveRow'
        QtMocHelpers::SlotData<void(int, int)>(67, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 68 }, { QMetaType::Int, 69 },
        }}),
        // Slot 'clearPlayList'
        QtMocHelpers::SlotData<void()>(70, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'undoClearPlayList'
        QtMocHelpers::SlotData<void()>(71, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'savePlayList'
        QtMocHelpers::SlotData<bool(const QUrl &)>(72, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 37, 73 },
        }}),
        // Slot 'loadPlayList'
        QtMocHelpers::SlotData<void(const QUrl &)>(74, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 37, 73 },
        }}),
        // Slot 'loadPlayList'
        QtMocHelpers::SlotData<void(const QUrl &, ElisaUtils::PlayListEnqueueMode, ElisaUtils::PlayListEnqueueTriggerPlay)>(74, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 37, 73 }, { 0x80000000 | 39, 40 }, { 0x80000000 | 41, 42 },
        }}),
        // Slot 'setPersistentState'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(75, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 76, 77 },
        }}),
        // Slot 'openLoadedPlayList'
        QtMocHelpers::SlotData<void()>(78, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resetPartiallyLoaded'
        QtMocHelpers::SlotData<void()>(79, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'indexForTrackUrl'
        QtMocHelpers::SlotData<int(const QUrl &)>(80, 4, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 37, 81 },
        }}),
        // Slot 'switchToTrackUrl'
        QtMocHelpers::SlotData<void(const QUrl &, ElisaUtils::PlayListEnqueueTriggerPlay)>(82, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 37, 81 }, { 0x80000000 | 41, 42 },
        }}),
        // Slot 'sourceRowsAboutToBeInserted'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(83, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 84, 85 }, { QMetaType::Int, 86 }, { QMetaType::Int, 87 },
        }}),
        // Slot 'sourceRowsInserted'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(88, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 84, 85 }, { QMetaType::Int, 86 }, { QMetaType::Int, 87 },
        }}),
        // Slot 'sourceRowsAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(89, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 84, 85 }, { QMetaType::Int, 86 }, { QMetaType::Int, 87 },
        }}),
        // Slot 'sourceRowsRemoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(90, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 84, 85 }, { QMetaType::Int, 86 }, { QMetaType::Int, 87 },
        }}),
        // Slot 'sourceRowsAboutToBeMoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int, const QModelIndex &, int)>(91, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 84, 85 }, { QMetaType::Int, 86 }, { QMetaType::Int, 87 }, { 0x80000000 | 84, 92 },
            { QMetaType::Int, 93 },
        }}),
        // Slot 'sourceRowsMoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int, const QModelIndex &, int)>(94, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 84, 85 }, { QMetaType::Int, 86 }, { QMetaType::Int, 87 }, { 0x80000000 | 84, 92 },
            { QMetaType::Int, 93 },
        }}),
        // Slot 'sourceDataChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &, const QList<int> &)>(95, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 84, 96 }, { 0x80000000 | 84, 97 }, { 0x80000000 | 64, 98 },
        }}),
        // Slot 'sourceHeaderDataChanged'
        QtMocHelpers::SlotData<void(Qt::Orientation, int, int)>(99, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 100, 101 }, { QMetaType::Int, 102 }, { QMetaType::Int, 103 },
        }}),
        // Slot 'sourceLayoutAboutToBeChanged'
        QtMocHelpers::SlotData<void()>(104, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sourceLayoutChanged'
        QtMocHelpers::SlotData<void()>(105, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sourceModelAboutToBeReset'
        QtMocHelpers::SlotData<void()>(106, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sourceModelReset'
        QtMocHelpers::SlotData<void()>(107, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'persistentState'
        QtMocHelpers::PropertyData<QVariantMap>(77, 0x80000000 | 76, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 19),
        // property 'previousTrack'
        QtMocHelpers::PropertyData<QPersistentModelIndex>(6, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'currentTrack'
        QtMocHelpers::PropertyData<QPersistentModelIndex>(8, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'nextTrack'
        QtMocHelpers::PropertyData<QPersistentModelIndex>(10, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'repeatMode'
        QtMocHelpers::PropertyData<enum Repeat>(108, 0x80000000 | 49, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'shuffleMode'
        QtMocHelpers::PropertyData<enum Shuffle>(109, 0x80000000 | 52, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'totalTracksDuration'
        QtMocHelpers::PropertyData<int>(110, QMetaType::Int, QMC::DefaultPropertyFlags, 8),
        // property 'remainingTracksDuration'
        QtMocHelpers::PropertyData<int>(111, QMetaType::Int, QMC::DefaultPropertyFlags, 9),
        // property 'remainingTracks'
        QtMocHelpers::PropertyData<int>(112, QMetaType::Int, QMC::DefaultPropertyFlags, 10),
        // property 'currentTrackRow'
        QtMocHelpers::PropertyData<int>(113, QMetaType::Int, QMC::DefaultPropertyFlags, 13),
        // property 'radioCount'
        QtMocHelpers::PropertyData<int>(114, QMetaType::Int, QMC::DefaultPropertyFlags, 14),
        // property 'tracksCount'
        QtMocHelpers::PropertyData<int>(115, QMetaType::Int, QMC::DefaultPropertyFlags, 15),
        // property 'partiallyLoaded'
        QtMocHelpers::PropertyData<bool>(116, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Resettable, 25),
        // property 'canOpenLoadedPlaylist'
        QtMocHelpers::PropertyData<bool>(117, QMetaType::Bool, QMC::DefaultPropertyFlags, 26),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Repeat'
        QtMocHelpers::EnumData<enum Repeat>(49, 49, QMC::EnumFlags{}).add({
            {  118, Repeat::None },
            {  119, Repeat::One },
            {  120, Repeat::Playlist },
        }),
        // enum 'Shuffle'
        QtMocHelpers::EnumData<enum Shuffle>(52, 52, QMC::EnumFlags{}).add({
            {  121, Shuffle::NoShuffle },
            {  122, Shuffle::Track },
            {  123, Shuffle::Album },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<MediaPlayListProxyModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MediaPlayListProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23MediaPlayListProxyModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23MediaPlayListProxyModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23MediaPlayListProxyModelE_t>.metaTypes,
    nullptr
} };

void MediaPlayListProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MediaPlayListProxyModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->previousTrackChanged((*reinterpret_cast<std::add_pointer_t<QPersistentModelIndex>>(_a[1]))); break;
        case 1: _t->currentTrackChanged((*reinterpret_cast<std::add_pointer_t<QPersistentModelIndex>>(_a[1]))); break;
        case 2: _t->nextTrackChanged((*reinterpret_cast<std::add_pointer_t<QPersistentModelIndex>>(_a[1]))); break;
        case 3: _t->previousTrackDataChanged(); break;
        case 4: _t->currentTrackDataChanged(); break;
        case 5: _t->nextTrackDataChanged(); break;
        case 6: _t->repeatModeChanged(); break;
        case 7: _t->shuffleModeChanged(); break;
        case 8: _t->totalTracksDurationChanged(); break;
        case 9: _t->remainingTracksDurationChanged(); break;
        case 10: _t->remainingTracksChanged(); break;
        case 11: _t->ensurePlay(); break;
        case 12: _t->requestPlay(); break;
        case 13: _t->currentTrackRowChanged(); break;
        case 14: _t->radioCountChanged(); break;
        case 15: _t->tracksCountChanged(); break;
        case 16: _t->playListFinished(); break;
        case 17: _t->playListLoaded(); break;
        case 18: _t->playListLoadFailed(); break;
        case 19: _t->persistentStateChanged(); break;
        case 20: _t->clearPlayListPlayer(); break;
        case 21: _t->undoClearPlayListPlayer(); break;
        case 22: _t->displayUndoNotification(); break;
        case 23: _t->hideUndoNotification(); break;
        case 24: _t->seek((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 25: _t->partiallyLoadedChanged(); break;
        case 26: _t->canOpenLoadedPlaylistChanged(); break;
        case 27: _t->enqueue((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEnqueueMode>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEnqueueTriggerPlay>>(_a[3]))); break;
        case 28: _t->enqueue((*reinterpret_cast<std::add_pointer_t<DataTypes::MusicDataType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEnqueueMode>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEnqueueTriggerPlay>>(_a[4]))); break;
        case 29: _t->enqueue((*reinterpret_cast<std::add_pointer_t<DataTypes::EntryDataList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEnqueueMode>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEnqueueTriggerPlay>>(_a[3]))); break;
        case 30: _t->setRepeatMode((*reinterpret_cast<std::add_pointer_t<enum Repeat>>(_a[1]))); break;
        case 31: _t->setShuffleMode((*reinterpret_cast<std::add_pointer_t<enum Shuffle>>(_a[1]))); break;
        case 32: _t->trackInError((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMediaPlayer::Error>>(_a[2]))); break;
        case 33: _t->skipNextTrack((*reinterpret_cast<std::add_pointer_t<ElisaUtils::SkipReason>>(_a[1]))); break;
        case 34: _t->skipNextTrack(); break;
        case 35: _t->skipPreviousTrack((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 36: _t->switchTo((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 37: _t->removeSelection((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1]))); break;
        case 38: _t->removeRow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 39: _t->moveRow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 40: _t->clearPlayList(); break;
        case 41: _t->undoClearPlayList(); break;
        case 42: { bool _r = _t->savePlayList((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 43: _t->loadPlayList((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 44: _t->loadPlayList((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEnqueueMode>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEnqueueTriggerPlay>>(_a[3]))); break;
        case 45: _t->setPersistentState((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 46: _t->openLoadedPlayList(); break;
        case 47: _t->resetPartiallyLoaded(); break;
        case 48: { int _r = _t->indexForTrackUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 49: _t->switchToTrackUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEnqueueTriggerPlay>>(_a[2]))); break;
        case 50: _t->sourceRowsAboutToBeInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 51: _t->sourceRowsInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 52: _t->sourceRowsAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 53: _t->sourceRowsRemoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 54: _t->sourceRowsAboutToBeMoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 55: _t->sourceRowsMoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 56: _t->sourceDataChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[3]))); break;
        case 57: _t->sourceHeaderDataChanged((*reinterpret_cast<std::add_pointer_t<Qt::Orientation>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 58: _t->sourceLayoutAboutToBeChanged(); break;
        case 59: _t->sourceLayoutChanged(); break;
        case 60: _t->sourceModelAboutToBeReset(); break;
        case 61: _t->sourceModelReset(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::MusicDataType >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::EntryDataList >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 56:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)(const QPersistentModelIndex & )>(_a, &MediaPlayListProxyModel::previousTrackChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)(const QPersistentModelIndex & )>(_a, &MediaPlayListProxyModel::currentTrackChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)(const QPersistentModelIndex & )>(_a, &MediaPlayListProxyModel::nextTrackChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)()>(_a, &MediaPlayListProxyModel::previousTrackDataChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)()>(_a, &MediaPlayListProxyModel::currentTrackDataChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)()>(_a, &MediaPlayListProxyModel::nextTrackDataChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)()>(_a, &MediaPlayListProxyModel::repeatModeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)()>(_a, &MediaPlayListProxyModel::shuffleModeChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)()>(_a, &MediaPlayListProxyModel::totalTracksDurationChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)()>(_a, &MediaPlayListProxyModel::remainingTracksDurationChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)()>(_a, &MediaPlayListProxyModel::remainingTracksChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)()>(_a, &MediaPlayListProxyModel::ensurePlay, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)()>(_a, &MediaPlayListProxyModel::requestPlay, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)()>(_a, &MediaPlayListProxyModel::currentTrackRowChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)()>(_a, &MediaPlayListProxyModel::radioCountChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)()>(_a, &MediaPlayListProxyModel::tracksCountChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)()>(_a, &MediaPlayListProxyModel::playListFinished, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)()>(_a, &MediaPlayListProxyModel::playListLoaded, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)()>(_a, &MediaPlayListProxyModel::playListLoadFailed, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)()>(_a, &MediaPlayListProxyModel::persistentStateChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)()>(_a, &MediaPlayListProxyModel::clearPlayListPlayer, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)()>(_a, &MediaPlayListProxyModel::undoClearPlayListPlayer, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)()>(_a, &MediaPlayListProxyModel::displayUndoNotification, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)()>(_a, &MediaPlayListProxyModel::hideUndoNotification, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)(qint64 )>(_a, &MediaPlayListProxyModel::seek, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)()>(_a, &MediaPlayListProxyModel::partiallyLoadedChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (MediaPlayListProxyModel::*)()>(_a, &MediaPlayListProxyModel::canOpenLoadedPlaylistChanged, 26))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVariantMap*>(_v) = _t->persistentState(); break;
        case 1: *reinterpret_cast<QPersistentModelIndex*>(_v) = _t->previousTrack(); break;
        case 2: *reinterpret_cast<QPersistentModelIndex*>(_v) = _t->currentTrack(); break;
        case 3: *reinterpret_cast<QPersistentModelIndex*>(_v) = _t->nextTrack(); break;
        case 4: *reinterpret_cast<enum Repeat*>(_v) = _t->repeatMode(); break;
        case 5: *reinterpret_cast<enum Shuffle*>(_v) = _t->shuffleMode(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->totalTracksDuration(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->remainingTracksDuration(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->remainingTracks(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->currentTrackRow(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->radioCount(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->tracksCount(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->partiallyLoaded(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->canOpenLoadedPlaylist(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPersistentState(*reinterpret_cast<QVariantMap*>(_v)); break;
        case 4: _t->setRepeatMode(*reinterpret_cast<enum Repeat*>(_v)); break;
        case 5: _t->setShuffleMode(*reinterpret_cast<enum Shuffle*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 12: _t->resetPartiallyLoaded(); break;
        default: break;
        }
    }
}

const QMetaObject *MediaPlayListProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MediaPlayListProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23MediaPlayListProxyModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractProxyModel::qt_metacast(_clname);
}

int MediaPlayListProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 62)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 62;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 62)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 62;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void MediaPlayListProxyModel::previousTrackChanged(const QPersistentModelIndex & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void MediaPlayListProxyModel::currentTrackChanged(const QPersistentModelIndex & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void MediaPlayListProxyModel::nextTrackChanged(const QPersistentModelIndex & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void MediaPlayListProxyModel::previousTrackDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void MediaPlayListProxyModel::currentTrackDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void MediaPlayListProxyModel::nextTrackDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void MediaPlayListProxyModel::repeatModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void MediaPlayListProxyModel::shuffleModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void MediaPlayListProxyModel::totalTracksDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void MediaPlayListProxyModel::remainingTracksDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void MediaPlayListProxyModel::remainingTracksChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void MediaPlayListProxyModel::ensurePlay()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void MediaPlayListProxyModel::requestPlay()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void MediaPlayListProxyModel::currentTrackRowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void MediaPlayListProxyModel::radioCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void MediaPlayListProxyModel::tracksCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void MediaPlayListProxyModel::playListFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void MediaPlayListProxyModel::playListLoaded()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void MediaPlayListProxyModel::playListLoadFailed()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void MediaPlayListProxyModel::persistentStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void MediaPlayListProxyModel::clearPlayListPlayer()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void MediaPlayListProxyModel::undoClearPlayListPlayer()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void MediaPlayListProxyModel::displayUndoNotification()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void MediaPlayListProxyModel::hideUndoNotification()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void MediaPlayListProxyModel::seek(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void MediaPlayListProxyModel::partiallyLoadedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void MediaPlayListProxyModel::canOpenLoadedPlaylistChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}
QT_WARNING_POP
