/****************************************************************************
** Meta object code from reading C++ file 'viewslistdata.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/viewslistdata.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'viewslistdata.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13ViewsListDataE_t {};
} // unnamed namespace

template <> constexpr inline auto ViewsListData::qt_create_metaobjectdata<qt_meta_tag_ZN13ViewsListDataE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ViewsListData",
        "QML.Element",
        "auto",
        "embeddedCategoryChanged",
        "",
        "managerChanged",
        "databaseChanged",
        "needData",
        "ElisaUtils::PlayListEntryType",
        "dataType",
        "dataAboutToBeAdded",
        "startIndex",
        "endIndex",
        "dataAdded",
        "dataAboutToBeRemoved",
        "dataRemoved",
        "dataModified",
        "index",
        "dataAboutToBeReset",
        "dataReset",
        "setEmbeddedCategory",
        "aEmbeddedView",
        "setManager",
        "MusicListenersManager*",
        "aManager",
        "setDatabase",
        "DatabaseInterface*",
        "aDatabase",
        "genresAdded",
        "DataTypes::ListGenreDataType",
        "newData",
        "artistsAdded",
        "DataTypes::ListArtistDataType",
        "albumsAdded",
        "DataTypes::ListAlbumDataType",
        "albumModified",
        "DataTypes::AlbumDataType",
        "modifiedAlbum",
        "databaseEntryRemoved",
        "removedDatabaseId",
        "entryType",
        "cleanedDatabase",
        "embeddedCategory",
        "manager",
        "database"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'embeddedCategoryChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'managerChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'databaseChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'needData'
        QtMocHelpers::SignalData<void(ElisaUtils::PlayListEntryType)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'dataAboutToBeAdded'
        QtMocHelpers::SignalData<void(int, int)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { QMetaType::Int, 12 },
        }}),
        // Signal 'dataAdded'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dataAboutToBeRemoved'
        QtMocHelpers::SignalData<void(int, int)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { QMetaType::Int, 12 },
        }}),
        // Signal 'dataRemoved'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dataModified'
        QtMocHelpers::SignalData<void(int)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Signal 'dataAboutToBeReset'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dataReset'
        QtMocHelpers::SignalData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setEmbeddedCategory'
        QtMocHelpers::SlotData<void(ElisaUtils::PlayListEntryType)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 21 },
        }}),
        // Slot 'setManager'
        QtMocHelpers::SlotData<void(MusicListenersManager *)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'setDatabase'
        QtMocHelpers::SlotData<void(DatabaseInterface *)>(25, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'genresAdded'
        QtMocHelpers::SlotData<void(const DataTypes::ListGenreDataType &)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'artistsAdded'
        QtMocHelpers::SlotData<void(const DataTypes::ListArtistDataType &)>(31, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 30 },
        }}),
        // Slot 'albumsAdded'
        QtMocHelpers::SlotData<void(const DataTypes::ListAlbumDataType &)>(33, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 30 },
        }}),
        // Slot 'albumModified'
        QtMocHelpers::SlotData<void(const DataTypes::AlbumDataType &)>(35, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Slot 'databaseEntryRemoved'
        QtMocHelpers::SlotData<void(qulonglong, ElisaUtils::PlayListEntryType)>(38, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 39 }, { 0x80000000 | 8, 40 },
        }}),
        // Slot 'cleanedDatabase'
        QtMocHelpers::SlotData<void()>(41, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'embeddedCategory'
        QtMocHelpers::PropertyData<ElisaUtils::PlayListEntryType>(42, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'manager'
        QtMocHelpers::PropertyData<MusicListenersManager*>(43, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'database'
        QtMocHelpers::PropertyData<DatabaseInterface*>(44, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ViewsListData, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN13ViewsListDataE[] = {
    QMetaObject::SuperData::link<ElisaUtils::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject ViewsListData::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ViewsListDataE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ViewsListDataE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN13ViewsListDataE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ViewsListDataE_t>.metaTypes,
    nullptr
} };

void ViewsListData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ViewsListData *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->embeddedCategoryChanged(); break;
        case 1: _t->managerChanged(); break;
        case 2: _t->databaseChanged(); break;
        case 3: _t->needData((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1]))); break;
        case 4: _t->dataAboutToBeAdded((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->dataAdded(); break;
        case 6: _t->dataAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 7: _t->dataRemoved(); break;
        case 8: _t->dataModified((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->dataAboutToBeReset(); break;
        case 10: _t->dataReset(); break;
        case 11: _t->setEmbeddedCategory((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1]))); break;
        case 12: _t->setManager((*reinterpret_cast<std::add_pointer_t<MusicListenersManager*>>(_a[1]))); break;
        case 13: _t->setDatabase((*reinterpret_cast<std::add_pointer_t<DatabaseInterface*>>(_a[1]))); break;
        case 14: _t->genresAdded((*reinterpret_cast<std::add_pointer_t<DataTypes::ListGenreDataType>>(_a[1]))); break;
        case 15: _t->artistsAdded((*reinterpret_cast<std::add_pointer_t<DataTypes::ListArtistDataType>>(_a[1]))); break;
        case 16: _t->albumsAdded((*reinterpret_cast<std::add_pointer_t<DataTypes::ListAlbumDataType>>(_a[1]))); break;
        case 17: _t->albumModified((*reinterpret_cast<std::add_pointer_t<DataTypes::AlbumDataType>>(_a[1]))); break;
        case 18: _t->databaseEntryRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[2]))); break;
        case 19: _t->cleanedDatabase(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::ListGenreDataType >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::ListArtistDataType >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::ListAlbumDataType >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::AlbumDataType >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ViewsListData::*)()>(_a, &ViewsListData::embeddedCategoryChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewsListData::*)()>(_a, &ViewsListData::managerChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewsListData::*)()>(_a, &ViewsListData::databaseChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewsListData::*)(ElisaUtils::PlayListEntryType )>(_a, &ViewsListData::needData, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewsListData::*)(int , int )>(_a, &ViewsListData::dataAboutToBeAdded, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewsListData::*)()>(_a, &ViewsListData::dataAdded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewsListData::*)(int , int )>(_a, &ViewsListData::dataAboutToBeRemoved, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewsListData::*)()>(_a, &ViewsListData::dataRemoved, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewsListData::*)(int )>(_a, &ViewsListData::dataModified, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewsListData::*)()>(_a, &ViewsListData::dataAboutToBeReset, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ViewsListData::*)()>(_a, &ViewsListData::dataReset, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<ElisaUtils::PlayListEntryType*>(_v) = _t->embeddedCategory(); break;
        case 1: *reinterpret_cast<MusicListenersManager**>(_v) = _t->manager(); break;
        case 2: *reinterpret_cast<DatabaseInterface**>(_v) = _t->database(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setEmbeddedCategory(*reinterpret_cast<ElisaUtils::PlayListEntryType*>(_v)); break;
        case 1: _t->setManager(*reinterpret_cast<MusicListenersManager**>(_v)); break;
        case 2: _t->setDatabase(*reinterpret_cast<DatabaseInterface**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ViewsListData::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ViewsListData::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ViewsListDataE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ViewsListData::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void ViewsListData::embeddedCategoryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ViewsListData::managerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ViewsListData::databaseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ViewsListData::needData(ElisaUtils::PlayListEntryType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ViewsListData::dataAboutToBeAdded(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void ViewsListData::dataAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ViewsListData::dataAboutToBeRemoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void ViewsListData::dataRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ViewsListData::dataModified(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void ViewsListData::dataAboutToBeReset()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void ViewsListData::dataReset()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
