// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "indexersManager.h"


Q_LOGGING_CATEGORY(orgKdeElisaIndexersManager, "org.kde.elisa.indexers.manager", QtInfoMsg)

