/****************************************************************************
** Meta object code from reading C++ file 'editabletrackmetadatamodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/models/editabletrackmetadatamodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'editabletrackmetadatamodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN26EditableTrackMetadataModelE_t {};
} // unnamed namespace

template <> constexpr inline auto EditableTrackMetadataModel::qt_create_metaobjectdata<qt_meta_tag_ZN26EditableTrackMetadataModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EditableTrackMetadataModel",
        "QML.Element",
        "auto",
        "isDataValidChanged",
        "",
        "isDirtyChanged",
        "errorMessageChanged",
        "saveTrackModified",
        "DataTypes::ListTrackDataType",
        "trackDataType",
        "deleteRadioData",
        "radioId",
        "saveData",
        "resetData",
        "deleteRadio",
        "removeData",
        "index",
        "addData",
        "isDataValid",
        "errorMessage",
        "isDirty",
        "EditableColumnRoles",
        "ReadOnlyRole",
        "RemovableFieldRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'isDataValidChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isDirtyChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorMessageChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'saveTrackModified'
        QtMocHelpers::SignalData<void(const DataTypes::ListTrackDataType &)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'deleteRadioData'
        QtMocHelpers::SignalData<void(qulonglong)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 11 },
        }}),
        // Slot 'saveData'
        QtMocHelpers::SlotData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resetData'
        QtMocHelpers::SlotData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'deleteRadio'
        QtMocHelpers::SlotData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeData'
        QtMocHelpers::SlotData<void(int)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'addData'
        QtMocHelpers::SlotData<void(int)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isDataValid'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'errorMessage'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'isDirty'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'EditableColumnRoles'
        QtMocHelpers::EnumData<enum EditableColumnRoles>(21, 21, QMC::EnumFlags{}).add({
            {   22, EditableColumnRoles::ReadOnlyRole },
            {   23, EditableColumnRoles::RemovableFieldRole },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<EditableTrackMetadataModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject EditableTrackMetadataModel::staticMetaObject = { {
    QMetaObject::SuperData::link<TrackMetadataModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26EditableTrackMetadataModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26EditableTrackMetadataModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26EditableTrackMetadataModelE_t>.metaTypes,
    nullptr
} };

void EditableTrackMetadataModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EditableTrackMetadataModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->isDataValidChanged(); break;
        case 1: _t->isDirtyChanged(); break;
        case 2: _t->errorMessageChanged(); break;
        case 3: _t->saveTrackModified((*reinterpret_cast<std::add_pointer_t<DataTypes::ListTrackDataType>>(_a[1]))); break;
        case 4: _t->deleteRadioData((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 5: _t->saveData(); break;
        case 6: _t->resetData(); break;
        case 7: _t->deleteRadio(); break;
        case 8: _t->removeData((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->addData((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::ListTrackDataType >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EditableTrackMetadataModel::*)()>(_a, &EditableTrackMetadataModel::isDataValidChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditableTrackMetadataModel::*)()>(_a, &EditableTrackMetadataModel::isDirtyChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditableTrackMetadataModel::*)()>(_a, &EditableTrackMetadataModel::errorMessageChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditableTrackMetadataModel::*)(const DataTypes::ListTrackDataType & )>(_a, &EditableTrackMetadataModel::saveTrackModified, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (EditableTrackMetadataModel::*)(qulonglong )>(_a, &EditableTrackMetadataModel::deleteRadioData, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isDataValid(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->errorMessage(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isDirty(); break;
        default: break;
        }
    }
}

const QMetaObject *EditableTrackMetadataModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EditableTrackMetadataModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26EditableTrackMetadataModelE_t>.strings))
        return static_cast<void*>(this);
    return TrackMetadataModel::qt_metacast(_clname);
}

int EditableTrackMetadataModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TrackMetadataModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void EditableTrackMetadataModel::isDataValidChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void EditableTrackMetadataModel::isDirtyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void EditableTrackMetadataModel::errorMessageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void EditableTrackMetadataModel::saveTrackModified(const DataTypes::ListTrackDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void EditableTrackMetadataModel::deleteRadioData(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
