/****************************************************************************
** Meta object code from reading C++ file 'elisa_settings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../elisa_settings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'elisa_settings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Elisa18ElisaConfigurationE_t {};
} // unnamed namespace

template <> constexpr inline auto Elisa::ElisaConfiguration::qt_create_metaobjectdata<qt_meta_tag_ZN5Elisa18ElisaConfigurationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Elisa::ElisaConfiguration",
        "RootPathChanged",
        "",
        "ForceUsageOfFastFileSearchChanged",
        "ShowNowPlayingBackgroundChanged",
        "ShowProgressOnTaskBarChanged",
        "ShowSystemTrayIconChanged",
        "PlayAtStartupChanged",
        "ScanAtStartupChanged",
        "UseFavoriteStyleRatingsChanged",
        "AlwaysUseAbsolutePlaylistPathsChanged",
        "EmbeddedViewChanged",
        "InitialViewChanged",
        "InitialFilesViewPathChanged",
        "SortRolePreferencesChanged",
        "SortOrderPreferencesChanged",
        "ViewStylePreferencesChanged",
        "rootPath",
        "isRootPathImmutable",
        "forceUsageOfFastFileSearch",
        "isForceUsageOfFastFileSearchImmutable",
        "showNowPlayingBackground",
        "isShowNowPlayingBackgroundImmutable",
        "showProgressOnTaskBar",
        "isShowProgressOnTaskBarImmutable",
        "showSystemTrayIcon",
        "isShowSystemTrayIconImmutable",
        "playAtStartup",
        "isPlayAtStartupImmutable",
        "scanAtStartup",
        "isScanAtStartupImmutable",
        "useFavoriteStyleRatings",
        "isUseFavoriteStyleRatingsImmutable",
        "alwaysUseAbsolutePlaylistPaths",
        "isAlwaysUseAbsolutePlaylistPathsImmutable",
        "embeddedView",
        "isEmbeddedViewImmutable",
        "initialView",
        "isInitialViewImmutable",
        "initialFilesViewPath",
        "isInitialFilesViewPathImmutable",
        "sortRolePreferences",
        "isSortRolePreferencesImmutable",
        "sortOrderPreferences",
        "isSortOrderPreferencesImmutable",
        "viewStylePreferences",
        "isViewStylePreferencesImmutable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'RootPathChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ForceUsageOfFastFileSearchChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowNowPlayingBackgroundChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowProgressOnTaskBarChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ShowSystemTrayIconChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'PlayAtStartupChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ScanAtStartupChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'UseFavoriteStyleRatingsChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'AlwaysUseAbsolutePlaylistPathsChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'EmbeddedViewChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'InitialViewChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'InitialFilesViewPathChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SortRolePreferencesChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SortOrderPreferencesChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ViewStylePreferencesChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'rootPath'
        QtMocHelpers::PropertyData<QStringList>(17, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isRootPathImmutable'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'forceUsageOfFastFileSearch'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isForceUsageOfFastFileSearchImmutable'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showNowPlayingBackground'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isShowNowPlayingBackgroundImmutable'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showProgressOnTaskBar'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isShowProgressOnTaskBarImmutable'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showSystemTrayIcon'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isShowSystemTrayIconImmutable'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'playAtStartup'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isPlayAtStartupImmutable'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'scanAtStartup'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isScanAtStartupImmutable'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'useFavoriteStyleRatings'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isUseFavoriteStyleRatingsImmutable'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alwaysUseAbsolutePlaylistPaths'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isAlwaysUseAbsolutePlaylistPathsImmutable'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'embeddedView'
        QtMocHelpers::PropertyData<int>(35, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isEmbeddedViewImmutable'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'initialView'
        QtMocHelpers::PropertyData<int>(37, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isInitialViewImmutable'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'initialFilesViewPath'
        QtMocHelpers::PropertyData<QString>(39, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isInitialFilesViewPathImmutable'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sortRolePreferences'
        QtMocHelpers::PropertyData<QStringList>(41, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isSortRolePreferencesImmutable'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sortOrderPreferences'
        QtMocHelpers::PropertyData<QStringList>(43, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isSortOrderPreferencesImmutable'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'viewStylePreferences'
        QtMocHelpers::PropertyData<QStringList>(45, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isViewStylePreferencesImmutable'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ElisaConfiguration, qt_meta_tag_ZN5Elisa18ElisaConfigurationE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Elisa::ElisaConfiguration::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Elisa18ElisaConfigurationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Elisa18ElisaConfigurationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Elisa18ElisaConfigurationE_t>.metaTypes,
    nullptr
} };

void Elisa::ElisaConfiguration::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ElisaConfiguration *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->RootPathChanged(); break;
        case 1: _t->ForceUsageOfFastFileSearchChanged(); break;
        case 2: _t->ShowNowPlayingBackgroundChanged(); break;
        case 3: _t->ShowProgressOnTaskBarChanged(); break;
        case 4: _t->ShowSystemTrayIconChanged(); break;
        case 5: _t->PlayAtStartupChanged(); break;
        case 6: _t->ScanAtStartupChanged(); break;
        case 7: _t->UseFavoriteStyleRatingsChanged(); break;
        case 8: _t->AlwaysUseAbsolutePlaylistPathsChanged(); break;
        case 9: _t->EmbeddedViewChanged(); break;
        case 10: _t->InitialViewChanged(); break;
        case 11: _t->InitialFilesViewPathChanged(); break;
        case 12: _t->SortRolePreferencesChanged(); break;
        case 13: _t->SortOrderPreferencesChanged(); break;
        case 14: _t->ViewStylePreferencesChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ElisaConfiguration::*)()>(_a, &ElisaConfiguration::RootPathChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfiguration::*)()>(_a, &ElisaConfiguration::ForceUsageOfFastFileSearchChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfiguration::*)()>(_a, &ElisaConfiguration::ShowNowPlayingBackgroundChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfiguration::*)()>(_a, &ElisaConfiguration::ShowProgressOnTaskBarChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfiguration::*)()>(_a, &ElisaConfiguration::ShowSystemTrayIconChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfiguration::*)()>(_a, &ElisaConfiguration::PlayAtStartupChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfiguration::*)()>(_a, &ElisaConfiguration::ScanAtStartupChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfiguration::*)()>(_a, &ElisaConfiguration::UseFavoriteStyleRatingsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfiguration::*)()>(_a, &ElisaConfiguration::AlwaysUseAbsolutePlaylistPathsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfiguration::*)()>(_a, &ElisaConfiguration::EmbeddedViewChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfiguration::*)()>(_a, &ElisaConfiguration::InitialViewChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfiguration::*)()>(_a, &ElisaConfiguration::InitialFilesViewPathChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfiguration::*)()>(_a, &ElisaConfiguration::SortRolePreferencesChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfiguration::*)()>(_a, &ElisaConfiguration::SortOrderPreferencesChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaConfiguration::*)()>(_a, &ElisaConfiguration::ViewStylePreferencesChanged, 14))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->rootPath(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isRootPathImmutable(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->forceUsageOfFastFileSearch(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isForceUsageOfFastFileSearchImmutable(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->showNowPlayingBackground(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isShowNowPlayingBackgroundImmutable(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->showProgressOnTaskBar(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isShowProgressOnTaskBarImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->showSystemTrayIcon(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isShowSystemTrayIconImmutable(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->playAtStartup(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isPlayAtStartupImmutable(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->scanAtStartup(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isScanAtStartupImmutable(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->useFavoriteStyleRatings(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->isUseFavoriteStyleRatingsImmutable(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->alwaysUseAbsolutePlaylistPaths(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->isAlwaysUseAbsolutePlaylistPathsImmutable(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->embeddedView(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isEmbeddedViewImmutable(); break;
        case 20: *reinterpret_cast<int*>(_v) = _t->initialView(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->isInitialViewImmutable(); break;
        case 22: *reinterpret_cast<QString*>(_v) = _t->initialFilesViewPath(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->isInitialFilesViewPathImmutable(); break;
        case 24: *reinterpret_cast<QStringList*>(_v) = _t->sortRolePreferences(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isSortRolePreferencesImmutable(); break;
        case 26: *reinterpret_cast<QStringList*>(_v) = _t->sortOrderPreferences(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->isSortOrderPreferencesImmutable(); break;
        case 28: *reinterpret_cast<QStringList*>(_v) = _t->viewStylePreferences(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->isViewStylePreferencesImmutable(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setRootPath(*reinterpret_cast<QStringList*>(_v)); break;
        case 2: _t->setForceUsageOfFastFileSearch(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setShowNowPlayingBackground(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setShowProgressOnTaskBar(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setShowSystemTrayIcon(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setPlayAtStartup(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setScanAtStartup(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->setUseFavoriteStyleRatings(*reinterpret_cast<bool*>(_v)); break;
        case 16: _t->setAlwaysUseAbsolutePlaylistPaths(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setEmbeddedView(*reinterpret_cast<int*>(_v)); break;
        case 20: _t->setInitialView(*reinterpret_cast<int*>(_v)); break;
        case 22: _t->setInitialFilesViewPath(*reinterpret_cast<QString*>(_v)); break;
        case 24: _t->setSortRolePreferences(*reinterpret_cast<QStringList*>(_v)); break;
        case 26: _t->setSortOrderPreferences(*reinterpret_cast<QStringList*>(_v)); break;
        case 28: _t->setViewStylePreferences(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Elisa::ElisaConfiguration::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Elisa::ElisaConfiguration::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Elisa18ElisaConfigurationE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int Elisa::ElisaConfiguration::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    return _id;
}

// SIGNAL 0
void Elisa::ElisaConfiguration::RootPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Elisa::ElisaConfiguration::ForceUsageOfFastFileSearchChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Elisa::ElisaConfiguration::ShowNowPlayingBackgroundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Elisa::ElisaConfiguration::ShowProgressOnTaskBarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Elisa::ElisaConfiguration::ShowSystemTrayIconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Elisa::ElisaConfiguration::PlayAtStartupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Elisa::ElisaConfiguration::ScanAtStartupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Elisa::ElisaConfiguration::UseFavoriteStyleRatingsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Elisa::ElisaConfiguration::AlwaysUseAbsolutePlaylistPathsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Elisa::ElisaConfiguration::EmbeddedViewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Elisa::ElisaConfiguration::InitialViewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Elisa::ElisaConfiguration::InitialFilesViewPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Elisa::ElisaConfiguration::SortRolePreferencesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Elisa::ElisaConfiguration::SortOrderPreferencesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Elisa::ElisaConfiguration::ViewStylePreferencesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}
QT_WARNING_POP
