// /qt/qml/org/kde/elisa/qml/ImageWithFallback.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qhash.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <type_traits>

namespace QmlCacheGeneratedCode {
namespace _qt_qml_org_kde_elisa_qml_ImageWithFallback_qml {
QQmlPrivate::AOTLookupValidation::LookupSignatures expectedLookupSignatures()
{
    using namespace Qt::StringLiterals;
    using namespace QQmlPrivate::AOTLookupValidation;
    return {
        { Lookup{ Type{ u""_s, u"QQuickImage"_s, u""_s, IsComposite::No, IsIC::No }, u"parent"_s, u""_s }, PropertySignature{ Type{ u""_s, u"QQuickItem"_s, u""_s, IsComposite::No, IsIC::No }, 0 } },
        { Lookup{ Type{ u""_s, u"QQuickImage"_s, u""_s, IsComposite::No, IsIC::No }, u"status"_s, u""_s }, PropertySignature{ Type{ u""_s, u"QQuickImageBase::Status"_s, u""_s, IsComposite::No, IsIC::No }, 0 } },
        { Lookup{ Type{ u""_s, u"QQuickImageBase"_s, u""_s, IsComposite::No, IsIC::No }, u"source"_s, u""_s }, PropertySignature{ Type{ u""_s, u"QUrl"_s, u""_s, IsComposite::No, IsIC::No }, 1 } },
        { Lookup{ Type{ u""_s, u"QQuickItem"_s, u""_s, IsComposite::No, IsIC::No }, u"height"_s, u""_s }, PropertySignature{ Type{ u""_s, u"double"_s, u""_s, IsComposite::No, IsIC::No }, 8 } },
        { Lookup{ Type{ u""_s, u"QQuickItem"_s, u""_s, IsComposite::No, IsIC::No }, u"width"_s, u""_s }, PropertySignature{ Type{ u""_s, u"double"_s, u""_s, IsComposite::No, IsIC::No }, 7 } },
    };
}

bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu)
{
    enum ValidationState { Pending, Failed, Succeeded };
    static ValidationState state = Pending;
    if (state == Failed)
        return false;
    if (state == Succeeded)
        return true;
    const auto &expectedSignatures = expectedLookupSignatures();
    for (const auto &[lookup, expectedSignature] : expectedSignatures.asKeyValueRange()) {
        if (!QQmlPrivate::AOTLookupValidation::validateLookupSignature(engine, cu, lookup, expectedSignature)) {
            state = Failed;
            return false;
        }
    }
    state = Succeeded;
    return true;
}

extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x4f,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x78,0xc,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x9a,0x80,0xc8,0xde,
0x61,0x30,0x84,0xa1,0x45,0x4,0x88,0xde,
0x89,0xef,0xfc,0xc0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x2,0x0,0x0,
0x24,0x0,0x0,0x0,0xb0,0x4,0x0,0x0,
0x7,0x0,0x0,0x0,0xd8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf4,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0xf4,0x0,0x0,0x0,
0x1a,0x0,0x0,0x0,0xfc,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x64,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x70,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x70,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x70,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x70,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x70,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x70,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x70,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x70,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xa0,0x9,0x0,0x0,
0x70,0x1,0x0,0x0,0xc0,0x1,0x0,0x0,
0x10,0x2,0x0,0x0,0x88,0x2,0x0,0x0,
0x40,0x3,0x0,0x0,0x98,0x3,0x0,0x0,
0x40,0x4,0x0,0x0,0x90,0x4,0x0,0x0,
0xa0,0x4,0x0,0x0,0x83,0x0,0x0,0x0,
0xe0,0x1,0x0,0x0,0x83,0x0,0x0,0x0,
0xf0,0x1,0x0,0x0,0x83,0x0,0x0,0x0,
0x57,0x1,0x0,0x0,0x41,0x0,0x0,0x0,
0x43,0x0,0x0,0x0,0x3,0x2,0x0,0x0,
0x14,0x2,0x0,0x0,0x43,0x0,0x0,0x0,
0x43,0x0,0x0,0x0,0x53,0x0,0x0,0x0,
0x43,0x0,0x0,0x0,0x33,0x0,0x0,0x0,
0x54,0x1,0x0,0x0,0x93,0x0,0x0,0x0,
0x63,0x1,0x0,0x0,0x20,0x2,0x0,0x0,
0x33,0x0,0x0,0x0,0x61,0x0,0x0,0x0,
0x83,0x0,0x0,0x0,0x33,0x0,0x0,0x0,
0x50,0x0,0x0,0x0,0x41,0x0,0x0,0x0,
0x33,0x2,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x18,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x0,0x3c,0x1,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x19,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x19,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x2,0x3c,0x3,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x5c,0x0,0x0,0x0,0x15,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x3,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0x1b,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1b,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x1c,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x1d,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0xca,0x2e,0x4,0x18,
0x7,0xb4,0x5,0x0,0x0,0x18,0x8,0x42,
0x6,0x7,0x1a,0x8,0x6,0xd4,0x16,0x6,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x80,0x0,0x0,0x0,0x37,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x6,0x0,
0xff,0xff,0xff,0xff,0xc,0x0,0x0,0x0,
0x1f,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x28,0x0,0x0,0x0,
0x21,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x2b,0x0,0x0,0x0,0x22,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x2e,0x0,0x0,0x0,
0x24,0x0,0x0,0x0,0x8,0x0,0x0,0x0,
0x31,0x0,0x0,0x0,0x25,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x34,0x0,0x0,0x0,
0x27,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x2e,0x7,0x18,0x7,0x2e,0x8,0x18,0x8,
0x12,0x0,0x18,0xb,0xac,0x9,0x8,0x1,
0xb,0x6c,0x7,0x4e,0x13,0x2e,0xa,0x18,
0x8,0x12,0x0,0x6c,0x8,0x4e,0x9,0x2e,
0xb,0x18,0x9,0xe,0x6c,0x9,0x50,0x6,
0x8,0x30,0x6,0x2e,0xc,0x2,0xa,0x30,
0x6,0x2e,0xd,0x2,0x16,0x6,0x2,0x0,
0x44,0x0,0x0,0x0,0xc,0x0,0x0,0x0,
0x1b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0x2d,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2d,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0xe,0x18,0x7,
0xac,0xf,0x7,0x0,0x0,0x18,0x6,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x74,0x0,0x0,0x0,0x29,0x0,0x0,0x0,
0x1d,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x5,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0x2f,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2f,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x30,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x31,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x15,0x0,0x0,0x0,
0x32,0x0,0x0,0x0,0x6,0x0,0x0,0x0,
0x25,0x0,0x0,0x0,0x34,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0xca,0x2e,0x10,0x18,
0x7,0x2e,0x11,0x3c,0x12,0x6c,0x7,0x50,
0x18,0x2e,0x13,0x18,0x8,0x8,0x42,0x14,
0x8,0x2e,0x15,0x18,0x8,0x2e,0x16,0x3c,
0x17,0x18,0x9,0x42,0x18,0x8,0x1a,0x9,
0x6,0xd4,0x16,0x6,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0x19,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x2b,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2b,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x19,0x18,0x6,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x40,0x5,0x0,0x0,0x48,0x5,0x0,0x0,
0x60,0x5,0x0,0x0,0x70,0x5,0x0,0x0,
0x98,0x5,0x0,0x0,0xb0,0x5,0x0,0x0,
0xc8,0x5,0x0,0x0,0xe8,0x5,0x0,0x0,
0x8,0x6,0x0,0x0,0x18,0x6,0x0,0x0,
0x30,0x6,0x0,0x0,0x48,0x6,0x0,0x0,
0x68,0x6,0x0,0x0,0x80,0x6,0x0,0x0,
0xa0,0x6,0x0,0x0,0xc0,0x6,0x0,0x0,
0xe0,0x6,0x0,0x0,0x20,0x7,0x0,0x0,
0x48,0x7,0x0,0x0,0x88,0x7,0x0,0x0,
0xb0,0x7,0x0,0x0,0xf8,0x7,0x0,0x0,
0x18,0x8,0x0,0x0,0x28,0x8,0x0,0x0,
0x40,0x8,0x0,0x0,0x50,0x8,0x0,0x0,
0x80,0x8,0x0,0x0,0x90,0x8,0x0,0x0,
0xc0,0x8,0x0,0x0,0xe8,0x8,0x0,0x0,
0x30,0x9,0x0,0x0,0x40,0x9,0x0,0x0,
0x58,0x9,0x0,0x0,0x68,0x9,0x0,0x0,
0x78,0x9,0x0,0x0,0x88,0x9,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x49,0x0,0x74,0x0,
0x65,0x0,0x6d,0x0,0x0,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x61,0x0,0x67,0x0,0x65,0x0,0x57,0x0,
0x69,0x0,0x74,0x0,0x68,0x0,0x46,0x0,
0x61,0x0,0x6c,0x0,0x6c,0x0,0x62,0x0,
0x61,0x0,0x63,0x0,0x6b,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x73,0x0,0x6f,0x0,
0x75,0x0,0x72,0x0,0x63,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x66,0x0,0x61,0x0,
0x6c,0x0,0x6c,0x0,0x62,0x0,0x61,0x0,
0x63,0x0,0x6b,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x75,0x0,0x73,0x0,
0x69,0x0,0x6e,0x0,0x67,0x0,0x46,0x0,
0x61,0x0,0x6c,0x0,0x6c,0x0,0x62,0x0,
0x61,0x0,0x63,0x0,0x6b,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x73,0x0,0x6f,0x0,
0x75,0x0,0x72,0x0,0x63,0x0,0x65,0x0,
0x53,0x0,0x69,0x0,0x7a,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x61,0x0,0x67,0x0,0x65,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x73,0x0,0x74,0x0,
0x61,0x0,0x74,0x0,0x75,0x0,0x73,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x66,0x0,0x69,0x0,
0x6c,0x0,0x6c,0x0,0x4d,0x0,0x6f,0x0,
0x64,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x61,0x0,0x73,0x0,
0x79,0x0,0x6e,0x0,0x63,0x0,0x68,0x0,
0x72,0x0,0x6f,0x0,0x6e,0x0,0x6f,0x0,
0x75,0x0,0x73,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x6d,0x0,0x69,0x0,
0x70,0x0,0x6d,0x0,0x61,0x0,0x70,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x70,0x0,0x61,0x0,
0x69,0x0,0x6e,0x0,0x74,0x0,0x65,0x0,
0x64,0x0,0x57,0x0,0x69,0x0,0x64,0x0,
0x74,0x0,0x68,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x70,0x0,0x61,0x0,
0x69,0x0,0x6e,0x0,0x74,0x0,0x65,0x0,
0x64,0x0,0x48,0x0,0x65,0x0,0x69,0x0,
0x67,0x0,0x68,0x0,0x74,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x69,0x0,0x74,0x0,0x57,0x0,0x69,0x0,
0x64,0x0,0x74,0x0,0x68,0x0,0x0,0x0,
0x1c,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x69,0x0,0x6d,0x0,0x70,0x0,
0x6c,0x0,0x69,0x0,0x63,0x0,0x69,0x0,
0x74,0x0,0x57,0x0,0x69,0x0,0x64,0x0,
0x74,0x0,0x68,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x69,0x0,0x74,0x0,0x48,0x0,0x65,0x0,
0x69,0x0,0x67,0x0,0x68,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1d,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x69,0x0,0x6d,0x0,0x70,0x0,
0x6c,0x0,0x69,0x0,0x63,0x0,0x69,0x0,
0x74,0x0,0x48,0x0,0x65,0x0,0x69,0x0,
0x67,0x0,0x68,0x0,0x74,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x6f,0x0,0x6e,0x0,
0x53,0x0,0x6f,0x0,0x75,0x0,0x72,0x0,
0x63,0x0,0x65,0x0,0x43,0x0,0x68,0x0,
0x61,0x0,0x6e,0x0,0x67,0x0,0x65,0x0,
0x64,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1e,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6f,0x0,0x6e,0x0,0x53,0x0,
0x6f,0x0,0x75,0x0,0x72,0x0,0x63,0x0,
0x65,0x0,0x43,0x0,0x68,0x0,0x61,0x0,
0x6e,0x0,0x67,0x0,0x65,0x0,0x64,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x67,0x0,0x65,0x0,
0x74,0x0,0x49,0x0,0x6d,0x0,0x61,0x0,
0x67,0x0,0x65,0x0,0x55,0x0,0x72,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x49,0x0,0x6d,0x0,
0x61,0x0,0x67,0x0,0x65,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x61,0x0,0x6e,0x0,
0x63,0x0,0x68,0x0,0x6f,0x0,0x72,0x0,
0x73,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x66,0x0,0x69,0x0,
0x6c,0x0,0x6c,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x66,0x0,0x69,0x0,0x6c,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x63,0x0,0x61,0x0,
0x63,0x0,0x68,0x0,0x65,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x73,0x0,0x6f,0x0,0x75,0x0,
0x72,0x0,0x63,0x0,0x65,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x6f,0x0,0x6e,0x0,
0x53,0x0,0x74,0x0,0x61,0x0,0x74,0x0,
0x75,0x0,0x73,0x0,0x43,0x0,0x68,0x0,
0x61,0x0,0x6e,0x0,0x67,0x0,0x65,0x0,
0x64,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1e,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6f,0x0,0x6e,0x0,0x53,0x0,
0x74,0x0,0x61,0x0,0x74,0x0,0x75,0x0,
0x73,0x0,0x43,0x0,0x68,0x0,0x61,0x0,
0x6e,0x0,0x67,0x0,0x65,0x0,0x64,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x77,0x0,0x69,0x0,
0x64,0x0,0x74,0x0,0x68,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x68,0x0,0x65,0x0,
0x69,0x0,0x67,0x0,0x68,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x75,0x0,0x72,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x45,0x0,0x72,0x0,
0x72,0x0,0x6f,0x0,0x72,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x70,0x0,0x61,0x0,
0x72,0x0,0x65,0x0,0x6e,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x24,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x9,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x30,0x0,0x0,0x0,
0xb0,0x1,0x0,0x0,0x68,0x2,0x0,0x0,
0x2,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x1,0x0,0x3,0x0,0x54,0x0,0x0,0x0,
0x58,0x0,0x0,0x0,0x7c,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x8,0x1,0x0,0x0,
0x8,0x1,0x0,0x0,0x0,0x0,0x5,0x0,
0x8,0x1,0x0,0x0,0x0,0x0,0x0,0x0,
0x80,0x1,0x0,0x0,0xb,0x0,0x10,0x0,
0xc,0x0,0x50,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x6,0x0,0x0,0x20,
0xd,0x0,0x50,0x0,0x5,0x0,0x0,0x0,
0x6,0x0,0x0,0x20,0xe,0x0,0x50,0x0,
0x6,0x0,0x0,0x0,0x3,0x0,0x0,0x20,
0xf,0x0,0x50,0x0,0x7,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x10,0x0,0x50,0x0,0x10,0x0,0x0,0x2,
0x9,0x0,0x0,0x80,0x8,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x11,0x0,0x50,0x0,
0x11,0x0,0x50,0x2,0xa,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0xa,0x0,0x0,0x0,
0x12,0x0,0x50,0x0,0x12,0x0,0xe0,0x1,
0xb,0x0,0x0,0x0,0x8,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x13,0x0,0x50,0x0,
0x13,0x0,0x20,0x2,0xc,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0xc,0x0,0x0,0x0,
0x14,0x0,0x50,0x0,0x14,0x0,0xc0,0x1,
0xd,0x0,0x0,0x0,0x8,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x15,0x0,0x50,0x0,
0x15,0x0,0x20,0x2,0xe,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0xe,0x0,0x0,0x0,
0x16,0x0,0x50,0x0,0x16,0x0,0x30,0x2,
0x13,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1b,0x0,0x50,0x0,0x1b,0x0,0x60,0x1,
0x11,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x19,0x0,0x50,0x0,0x19,0x0,0x50,0x1,
0xf,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x18,0x0,0x50,0x0,0x18,0x0,0x40,0x1,
0x6,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xf,0x0,0x30,0x1,0xf,0x0,0x20,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x8,0x0,
0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x29,0x0,0x50,0x0,0x29,0x0,0x50,0x0,
0x16,0x0,0x0,0x0,0x8,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x4,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb4,0x0,0x0,0x0,0x29,0x0,0x50,0x0,
0x2a,0x0,0x90,0x0,0xb4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xb4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1c,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x5,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2f,0x0,0x90,0x0,
0x2f,0x0,0xa0,0x1,0x4,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2d,0x0,0x90,0x0,
0x2d,0x0,0x10,0x1,0x1a,0x0,0x0,0x0,
0x0,0x0,0x1,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2c,0x0,0x90,0x0,
0x2c,0x0,0x0,0x1,0x17,0x0,0x0,0x0,
0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2b,0x0,0x90,0x0,
0x2b,0x0,0x10,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x2b,0x0,0x90,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x6,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2b,0x0,0x10,0x1,
0x2b,0x0,0x70,0x1,0x0,0x0,0x0,0x0
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 0, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for implicitWidth at line 24, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
double v2_2;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(0, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(1, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(1, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.v2_2;
}
return;
}
 },{ 1, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for implicitHeight at line 25, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
double v2_2;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(2, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(3, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(3, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.v2_2;
}
return;
}
 },{ 2, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for onSourceChanged at line 27, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_1_v7_3, markStack);
    aotContext->mark(v2_5, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_1_v7_3 = nullptr;
QVariant v2_5;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_CreateCallContext
{
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(3);
#endif
while (!aotContext->loadContextIdLookup(4, &s.v2_1_v7_3)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(3);
#endif
aotContext->initLoadContextIdLookup(4);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_CallQmlContextPropertyLookup
{
QVariant callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult};
    return aotContext->callQmlContextPropertyLookup(5, args, 0);
};
const auto doInit = [&]() {
    aotContext->initCallQmlContextPropertyLookup(5, 3);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(9);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(9);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_5 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_5);
}
{
}
{
}
// generate_SetLookup
{
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
while (!aotContext->setObjectLookup(6, s.v2_1_v7_3, &s.v2_5)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
aotContext->initSetObjectLookupAsVariant(6, s.v2_1_v7_3);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
}
{
}
{
}
// generate_PopContext
{}
}
{
}
{
}
// generate_Ret
return;
}
 },{ 4, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<QUrl>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for source at line 45, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0_v7_2, markStack);
    aotContext->mark(v2_4, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0_v7_2 = nullptr;
QVariant v2_4;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(14, &s.v2_0_v7_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(14);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = QUrl();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
QVariant callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult};
    return aotContext->callObjectPropertyLookup(15, s.v2_0_v7_2, args, 0);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookup(15, s.v2_0_v7_2, 3);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(9);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(9);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QUrl *>(argv[0]) = QUrl();
}
return;
}
}
s.v2_4 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_4);
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    if (!s.v2_4.isValid())
        aotContext->setReturnValueUndefined();
    *static_cast<QUrl *>(argv[0]) = aotContext->engine->fromVariant<QUrl>(std::move(s.v2_4));
}
return;
}
 },{ 5, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for onStatusChanged at line 47, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_13_v8_15, markStack);
    aotContext->mark(v2_21_v8_23, markStack);
    aotContext->mark(v2_25, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_13_v8_15 = nullptr;
QObject *v2_21_v8_23 = nullptr;
QObject *v2_25 = nullptr;
QUrl v2_27;
bool v2_17;
bool v2_9;
int v2_1_v7_3;
int v2_7;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_CreateCallContext
{
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(3);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(16, &s.v2_1_v7_3)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(3);
#endif
aotContext->initLoadScopeObjectPropertyLookup(16);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_StoreReg
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(9);
#endif
while (!aotContext->getEnumLookup(18, &s.v2_7)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(9);
#endif
aotContext->initGetEnumLookup(18, []() { static const auto t = QMetaType::fromName("QQuickImageBase*"); return t; }().metaObject(), "Status", "Error");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_CmpStrictEqual
s.v2_9 = s.v2_1_v7_3 == s.v2_7;
{
}
// generate_JumpFalse
if (!s.v2_9) {
    goto label_0;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(15);
#endif
while (!aotContext->loadContextIdLookup(19, &s.v2_13_v8_15)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(15);
#endif
aotContext->initLoadContextIdLookup(19);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadTrue
s.v2_17 = true;
{
}
// generate_SetLookup
{
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(21);
#endif
while (!aotContext->setObjectLookup(20, s.v2_13_v8_15, &s.v2_17)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(21);
#endif
aotContext->initSetObjectLookup(20, s.v2_13_v8_15);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(23);
#endif
while (!aotContext->loadContextIdLookup(21, &s.v2_21_v8_23)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(23);
#endif
aotContext->initLoadContextIdLookup(21);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(27);
#endif
while (!aotContext->loadContextIdLookup(22, &s.v2_25)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(27);
#endif
aotContext->initLoadContextIdLookup(22);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(29);
#endif
while (!aotContext->getObjectLookup(23, s.v2_25, &s.v2_27)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(29);
#endif
aotContext->initGetObjectLookup(23, s.v2_25);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
{
}
// generate_SetLookup
{
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(34);
#endif
while (!aotContext->setObjectLookup(24, s.v2_21_v8_23, &s.v2_27)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(34);
#endif
aotContext->initSetObjectLookup(24, s.v2_21_v8_23);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
}
{
}
{
}
label_0:;
// generate_PopContext
{}
}
{
}
{
}
// generate_Ret
return;
}
 },{ 6, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QQuickItem*"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for fill at line 43, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(25, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadScopeObjectPropertyLookup(25);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QObject * *>(argv[0]) = nullptr;
}
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QObject * *>(argv[0]) = s.v2_0;
}
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
