/****************************************************************************
** Meta object code from reading C++ file 'abstractmediaproxymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/models/abstractmediaproxymodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractmediaproxymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23AbstractMediaProxyModelE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractMediaProxyModel::qt_create_metaobjectdata<qt_meta_tag_ZN23AbstractMediaProxyModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractMediaProxyModel",
        "filterTextChanged",
        "",
        "filterText",
        "filterRatingChanged",
        "filterRating",
        "sortedAscendingChanged",
        "dataTypeChanged",
        "playListChanged",
        "entriesToEnqueue",
        "DataTypes::EntryDataList",
        "newEntries",
        "ElisaUtils::PlayListEnqueueMode",
        "enqueueMode",
        "ElisaUtils::PlayListEnqueueTriggerPlay",
        "triggerPlay",
        "switchToTrackUrl",
        "QUrl",
        "url",
        "setFilterText",
        "setFilterRating",
        "sortModel",
        "Qt::SortOrder",
        "order",
        "setDataType",
        "ElisaUtils::PlayListEntryType",
        "dataType",
        "setPlayList",
        "MediaPlayListProxyModel*",
        "playList",
        "enqueueAll",
        "replaceAndPlayOfPlayListFromTrackUrl",
        "QModelIndex",
        "rootIndex",
        "switchTrackUrl",
        "enqueue",
        "DataTypes::MusicDataType",
        "newEntry",
        "newEntryTitle",
        "afterPlaylistEnqueue",
        "sortedAscending"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'filterTextChanged'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'filterRatingChanged'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Signal 'sortedAscendingChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dataTypeChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playListChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'entriesToEnqueue'
        QtMocHelpers::SignalData<void(const DataTypes::EntryDataList &, ElisaUtils::PlayListEnqueueMode, ElisaUtils::PlayListEnqueueTriggerPlay)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Signal 'switchToTrackUrl'
        QtMocHelpers::SignalData<void(const QUrl &, ElisaUtils::PlayListEnqueueTriggerPlay)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'setFilterText'
        QtMocHelpers::SlotData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'setFilterRating'
        QtMocHelpers::SlotData<void(int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'sortModel'
        QtMocHelpers::SlotData<void(Qt::SortOrder)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'setDataType'
        QtMocHelpers::SlotData<void(ElisaUtils::PlayListEntryType)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'setPlayList'
        QtMocHelpers::SlotData<void(MediaPlayListProxyModel *)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'enqueueAll'
        QtMocHelpers::SlotData<void(ElisaUtils::PlayListEnqueueMode, ElisaUtils::PlayListEnqueueTriggerPlay)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'replaceAndPlayOfPlayListFromTrackUrl'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QUrl &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 }, { 0x80000000 | 17, 34 },
        }}),
        // Slot 'enqueue'
        QtMocHelpers::SlotData<void(const DataTypes::MusicDataType &, const QString &, ElisaUtils::PlayListEnqueueMode, ElisaUtils::PlayListEnqueueTriggerPlay)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 }, { QMetaType::QString, 38 }, { 0x80000000 | 12, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'afterPlaylistEnqueue'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'filterText'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'filterRating'
        QtMocHelpers::PropertyData<int>(5, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'sortedAscending'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'dataType'
        QtMocHelpers::PropertyData<ElisaUtils::PlayListEntryType>(26, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'playList'
        QtMocHelpers::PropertyData<MediaPlayListProxyModel*>(29, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractMediaProxyModel, qt_meta_tag_ZN23AbstractMediaProxyModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN23AbstractMediaProxyModelE[] = {
    QMetaObject::SuperData::link<ElisaUtils::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject AbstractMediaProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AbstractMediaProxyModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AbstractMediaProxyModelE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN23AbstractMediaProxyModelE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23AbstractMediaProxyModelE_t>.metaTypes,
    nullptr
} };

void AbstractMediaProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractMediaProxyModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->filterTextChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->filterRatingChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->sortedAscendingChanged(); break;
        case 3: _t->dataTypeChanged(); break;
        case 4: _t->playListChanged(); break;
        case 5: _t->entriesToEnqueue((*reinterpret_cast<std::add_pointer_t<DataTypes::EntryDataList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEnqueueMode>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEnqueueTriggerPlay>>(_a[3]))); break;
        case 6: _t->switchToTrackUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEnqueueTriggerPlay>>(_a[2]))); break;
        case 7: _t->setFilterText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->setFilterRating((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->sortModel((*reinterpret_cast<std::add_pointer_t<Qt::SortOrder>>(_a[1]))); break;
        case 10: _t->setDataType((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1]))); break;
        case 11: _t->setPlayList((*reinterpret_cast<std::add_pointer_t<MediaPlayListProxyModel*>>(_a[1]))); break;
        case 12: _t->enqueueAll((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEnqueueMode>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEnqueueTriggerPlay>>(_a[2]))); break;
        case 13: _t->replaceAndPlayOfPlayListFromTrackUrl((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 14: _t->enqueue((*reinterpret_cast<std::add_pointer_t<DataTypes::MusicDataType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEnqueueMode>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEnqueueTriggerPlay>>(_a[4]))); break;
        case 15: _t->afterPlaylistEnqueue(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::EntryDataList >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::MusicDataType >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractMediaProxyModel::*)(const QString & )>(_a, &AbstractMediaProxyModel::filterTextChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractMediaProxyModel::*)(int )>(_a, &AbstractMediaProxyModel::filterRatingChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractMediaProxyModel::*)()>(_a, &AbstractMediaProxyModel::sortedAscendingChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractMediaProxyModel::*)()>(_a, &AbstractMediaProxyModel::dataTypeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractMediaProxyModel::*)()>(_a, &AbstractMediaProxyModel::playListChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractMediaProxyModel::*)(const DataTypes::EntryDataList & , ElisaUtils::PlayListEnqueueMode , ElisaUtils::PlayListEnqueueTriggerPlay )>(_a, &AbstractMediaProxyModel::entriesToEnqueue, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractMediaProxyModel::*)(const QUrl & , ElisaUtils::PlayListEnqueueTriggerPlay )>(_a, &AbstractMediaProxyModel::switchToTrackUrl, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->filterText(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->filterRating(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->sortedAscending(); break;
        case 3: *reinterpret_cast<ElisaUtils::PlayListEntryType*>(_v) = _t->dataType(); break;
        case 4: *reinterpret_cast<MediaPlayListProxyModel**>(_v) = _t->playList(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFilterText(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setFilterRating(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setDataType(*reinterpret_cast<ElisaUtils::PlayListEntryType*>(_v)); break;
        case 4: _t->setPlayList(*reinterpret_cast<MediaPlayListProxyModel**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *AbstractMediaProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractMediaProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AbstractMediaProxyModelE_t>.strings))
        return static_cast<void*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int AbstractMediaProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void AbstractMediaProxyModel::filterTextChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AbstractMediaProxyModel::filterRatingChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AbstractMediaProxyModel::sortedAscendingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AbstractMediaProxyModel::dataTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AbstractMediaProxyModel::playListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AbstractMediaProxyModel::entriesToEnqueue(const DataTypes::EntryDataList & _t1, ElisaUtils::PlayListEnqueueMode _t2, ElisaUtils::PlayListEnqueueTriggerPlay _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3);
}

// SIGNAL 6
void AbstractMediaProxyModel::switchToTrackUrl(const QUrl & _t1, ElisaUtils::PlayListEnqueueTriggerPlay _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}
QT_WARNING_POP
