/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<audiowrapper.h>)
#  include <audiowrapper.h>
#endif
#if __has_include(<databaseinterface.h>)
#  include <databaseinterface.h>
#endif
#if __has_include(<datamodel.h>)
#  include <datamodel.h>
#endif
#if __has_include(<datatypes.h>)
#  include <datatypes.h>
#endif
#if __has_include(<editabletrackmetadatamodel.h>)
#  include <editabletrackmetadatamodel.h>
#endif
#if __has_include(<elisaapplication.h>)
#  include <elisaapplication.h>
#endif
#if __has_include(<elisaconfigurationdialog.h>)
#  include <elisaconfigurationdialog.h>
#endif
#if __has_include(<elisautils.h>)
#  include <elisautils.h>
#endif
#if __has_include(<filebrowsermodel.h>)
#  include <filebrowsermodel.h>
#endif
#if __has_include(<filebrowserproxymodel.h>)
#  include <filebrowserproxymodel.h>
#endif
#if __has_include(<lyricsmodel.h>)
#  include <lyricsmodel.h>
#endif
#if __has_include(<manageaudioplayer.h>)
#  include <manageaudioplayer.h>
#endif
#if __has_include(<manageheaderbar.h>)
#  include <manageheaderbar.h>
#endif
#if __has_include(<managemediaplayercontrol.h>)
#  include <managemediaplayercontrol.h>
#endif
#if __has_include(<mediaplaylist.h>)
#  include <mediaplaylist.h>
#endif
#if __has_include(<mediaplaylistproxymodel.h>)
#  include <mediaplaylistproxymodel.h>
#endif
#if __has_include(<mpris2.h>)
#  include <mpris2.h>
#endif
#if __has_include(<musiclistenersmanager.h>)
#  include <musiclistenersmanager.h>
#endif
#if __has_include(<progressindicator.h>)
#  include <progressindicator.h>
#endif
#if __has_include(<qmlforeigntypes.h>)
#  include <qmlforeigntypes.h>
#endif
#if __has_include(<trackcontextmetadatamodel.h>)
#  include <trackcontextmetadatamodel.h>
#endif
#if __has_include(<trackmetadatamodel.h>)
#  include <trackmetadatamodel.h>
#endif
#if __has_include(<trackmetadataproxymodel.h>)
#  include <trackmetadataproxymodel.h>
#endif
#if __has_include(<viewconfigurationdata.h>)
#  include <viewconfigurationdata.h>
#endif
#if __has_include(<viewmanager.h>)
#  include <viewmanager.h>
#endif
#if __has_include(<viewslistdata.h>)
#  include <viewslistdata.h>
#endif
#if __has_include(<viewsmodel.h>)
#  include <viewsmodel.h>
#endif
#if __has_include(<viewsproxymodel.h>)
#  include <viewsproxymodel.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_elisa()
{
    qmlRegisterModule("org.kde.elisa", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<AudioWrapper>("org.kde.elisa", 254);
    qmlRegisterTypesAndRevisions<DataModel>("org.kde.elisa", 254);
    qmlRegisterAnonymousType<QAbstractItemModel, 254>("org.kde.elisa", 254);
    qmlRegisterTypesAndRevisions<DataTypes>("org.kde.elisa", 254);
    qmlRegisterEnum<DataTypes::ColumnsRoles>("DataTypes::ColumnsRoles");
    qmlRegisterTypesAndRevisions<DatabaseInterface>("org.kde.elisa", 254);
    qmlRegisterTypesAndRevisions<EditableTrackMetadataModel>("org.kde.elisa", 254);
    qmlRegisterEnum<EditableTrackMetadataModel::EditableColumnRoles>("EditableTrackMetadataModel::EditableColumnRoles");
    qmlRegisterTypesAndRevisions<ElisaApplication>("org.kde.elisa", 254);
    qmlRegisterTypesAndRevisions<ElisaConfigurationDialog>("org.kde.elisa", 254);
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &ElisaUtils::staticMetaObject;},
            "ElisaUtils");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&ElisaUtils::staticMetaObject, "org.kde.elisa", 254, nullptr, &ElisaUtils::staticMetaObject, nullptr);
    qmlRegisterEnum<ElisaUtils::PlayListEnqueueMode>("ElisaUtils::PlayListEnqueueMode");
    qmlRegisterEnum<ElisaUtils::PlayListEnqueueTriggerPlay>("ElisaUtils::PlayListEnqueueTriggerPlay");
    qmlRegisterEnum<ElisaUtils::SkipReason>("ElisaUtils::SkipReason");
    qmlRegisterEnum<ElisaUtils::PlayListEntryType>("ElisaUtils::PlayListEntryType");
    qmlRegisterEnum<ElisaUtils::FilterType>("ElisaUtils::FilterType");
    qmlRegisterTypesAndRevisions<FileBrowserModel>("org.kde.elisa", 254);
    qmlRegisterTypesAndRevisions<FileBrowserProxyModel>("org.kde.elisa", 254);
    qmlRegisterTypesAndRevisions<ForeignQAbstractItemModel>("org.kde.elisa", 254);
    QMetaType::fromType<ForeignQAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    qmlRegisterTypesAndRevisions<ForeignQAbstractProxyModel>("org.kde.elisa", 254);
    QMetaType::fromType<ForeignQAbstractProxyModel *>().id();
    qmlRegisterTypesAndRevisions<LyricsModel>("org.kde.elisa", 254);
    qmlRegisterTypesAndRevisions<ManageAudioPlayer>("org.kde.elisa", 254);
    qmlRegisterTypesAndRevisions<ManageHeaderBar>("org.kde.elisa", 254);
    qmlRegisterTypesAndRevisions<ManageMediaPlayerControl>("org.kde.elisa", 254);
    qmlRegisterTypesAndRevisions<MediaPlayList>("org.kde.elisa", 254);
    qmlRegisterEnum<MediaPlayList::ColumnsRoles>("MediaPlayList::ColumnsRoles");
    qmlRegisterEnum<MediaPlayList::PlayState>("MediaPlayList::PlayState");
    qmlRegisterTypesAndRevisions<MediaPlayListProxyModel>("org.kde.elisa", 254);
    qmlRegisterEnum<MediaPlayListProxyModel::Repeat>("MediaPlayListProxyModel::Repeat");
    qmlRegisterEnum<MediaPlayListProxyModel::Shuffle>("MediaPlayListProxyModel::Shuffle");
    qmlRegisterTypesAndRevisions<Mpris2>("org.kde.elisa", 254);
    qmlRegisterTypesAndRevisions<MusicListenersManager>("org.kde.elisa", 254);
    qmlRegisterEnum<MusicListenersManager::CollectionScan>("MusicListenersManager::CollectionScan");
    qmlRegisterTypesAndRevisions<ProgressIndicator>("org.kde.elisa", 254);
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    qmlRegisterTypesAndRevisions<TrackContextMetaDataModel>("org.kde.elisa", 254);
    qmlRegisterTypesAndRevisions<TrackMetadataModel>("org.kde.elisa", 254);
    qmlRegisterEnum<TrackMetadataModel::ColumnRoles>("TrackMetadataModel::ColumnRoles");
    qmlRegisterEnum<TrackMetadataModel::ItemType>("TrackMetadataModel::ItemType");
    qmlRegisterTypesAndRevisions<TrackMetadataProxyModel>("org.kde.elisa", 254);
    qmlRegisterTypesAndRevisions<ViewConfigurationData>("org.kde.elisa", 254);
    qmlRegisterTypesAndRevisions<ViewManager>("org.kde.elisa", 254);
    qmlRegisterEnum<ViewManager::AlbumCardinality>("ViewManager::AlbumCardinality");
    qmlRegisterEnum<ViewManager::AlbumViewStyle>("ViewManager::AlbumViewStyle");
    qmlRegisterEnum<ViewManager::DelegateUseSecondaryText>("ViewManager::DelegateUseSecondaryText");
    qmlRegisterEnum<ViewManager::ViewCanBeRated>("ViewManager::ViewCanBeRated");
    qmlRegisterEnum<ViewManager::ViewPresentationType>("ViewManager::ViewPresentationType");
    qmlRegisterEnum<ViewManager::ModelType>("ViewManager::ModelType");
    qmlRegisterEnum<ViewManager::ViewStyle>("ViewManager::ViewStyle");
    qmlRegisterTypesAndRevisions<ViewsListData>("org.kde.elisa", 254);
    qmlRegisterTypesAndRevisions<ViewsModel>("org.kde.elisa", 254);
    qmlRegisterTypesAndRevisions<ViewsProxyModel>("org.kde.elisa", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.elisa", 254, 254);
}

static const QQmlModuleRegistration orgkdeelisaRegistration("org.kde.elisa", qml_register_types_org_kde_elisa);
