/****************************************************************************
** Meta object code from reading C++ file 'manageaudioplayer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/manageaudioplayer.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'manageaudioplayer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17ManageAudioPlayerE_t {};
} // unnamed namespace

template <> constexpr inline auto ManageAudioPlayer::qt_create_metaobjectdata<qt_meta_tag_ZN17ManageAudioPlayerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ManageAudioPlayer",
        "QML.Element",
        "auto",
        "currentTrackChanged",
        "",
        "playListModelChanged",
        "playerSourceChanged",
        "QUrl",
        "url",
        "urlRoleChanged",
        "isPlayingRoleChanged",
        "playerStatusChanged",
        "playerPlaybackStateChanged",
        "playerErrorChanged",
        "playerPlay",
        "playerPause",
        "playerStop",
        "skipNextTrack",
        "ElisaUtils::SkipReason",
        "reason",
        "skipPreviousTrack",
        "position",
        "audioDurationChanged",
        "playerIsSeekableChanged",
        "playerPositionChanged",
        "playControlPositionChanged",
        "persistentStateChanged",
        "seek",
        "saveUndoPositionInAudioWrapper",
        "restoreUndoPositionInAudioWrapper",
        "titleRoleChanged",
        "artistNameRoleChanged",
        "albumNameRoleChanged",
        "sourceInError",
        "source",
        "QMediaPlayer::Error",
        "playerError",
        "displayTrackError",
        "fileName",
        "startedPlayingTrack",
        "time",
        "finishedPlayingTrack",
        "updateData",
        "QPersistentModelIndex",
        "index",
        "QVariant",
        "value",
        "role",
        "setCurrentTrack",
        "currentTrack",
        "saveForUndoClearPlaylist",
        "restoreForUndoClearPlaylist",
        "setPlayListModel",
        "QAbstractItemModel*",
        "aPlayListModel",
        "setUrlRole",
        "setIsPlayingRole",
        "setPlayerStatus",
        "QMediaPlayer::MediaStatus",
        "playerStatus",
        "setPlayerPlaybackState",
        "QMediaPlayer::PlaybackState",
        "playerPlaybackState",
        "setPlayerError",
        "ensurePause",
        "ensurePlay",
        "requestPlay",
        "playPause",
        "stop",
        "setAudioDuration",
        "audioDuration",
        "setPlayerIsSeekable",
        "playerIsSeekable",
        "setPlayerPosition",
        "playerPosition",
        "setCurrentPlayingForRadios",
        "title",
        "nowPlaying",
        "setPlayControlPosition",
        "setPersistentState",
        "QVariantMap",
        "persistentStateValue",
        "playerSeek",
        "playListFinished",
        "tracksDataChanged",
        "QModelIndex",
        "topLeft",
        "bottomRight",
        "QList<int>",
        "roles",
        "setTitleRole",
        "titleRole",
        "setArtistNameRole",
        "artistNameRole",
        "setAlbumNameRole",
        "albumNameRole",
        "playListModel",
        "playerSource",
        "urlRole",
        "isPlayingRole",
        "playControlPosition",
        "persistentState"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentTrackChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playListModelChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playerSourceChanged'
        QtMocHelpers::SignalData<void(const QUrl &)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'urlRoleChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isPlayingRoleChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playerStatusChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playerPlaybackStateChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playerErrorChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playerPlay'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playerPause'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playerStop'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'skipNextTrack'
        QtMocHelpers::SignalData<void(ElisaUtils::SkipReason)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 19 },
        }}),
        // Signal 'skipNextTrack'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'skipPreviousTrack'
        QtMocHelpers::SignalData<void(qint64)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 21 },
        }}),
        // Signal 'audioDurationChanged'
        QtMocHelpers::SignalData<void()>(22, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playerIsSeekableChanged'
        QtMocHelpers::SignalData<void()>(23, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playerPositionChanged'
        QtMocHelpers::SignalData<void()>(24, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playControlPositionChanged'
        QtMocHelpers::SignalData<void()>(25, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'persistentStateChanged'
        QtMocHelpers::SignalData<void()>(26, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'seek'
        QtMocHelpers::SignalData<void(qint64)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 21 },
        }}),
        // Signal 'saveUndoPositionInAudioWrapper'
        QtMocHelpers::SignalData<void(qint64)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 21 },
        }}),
        // Signal 'restoreUndoPositionInAudioWrapper'
        QtMocHelpers::SignalData<void()>(29, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleRoleChanged'
        QtMocHelpers::SignalData<void()>(30, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'artistNameRoleChanged'
        QtMocHelpers::SignalData<void()>(31, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'albumNameRoleChanged'
        QtMocHelpers::SignalData<void()>(32, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceInError'
        QtMocHelpers::SignalData<void(const QUrl &, QMediaPlayer::Error)>(33, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 34 }, { 0x80000000 | 35, 36 },
        }}),
        // Signal 'displayTrackError'
        QtMocHelpers::SignalData<void(const QString &)>(37, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 38 },
        }}),
        // Signal 'startedPlayingTrack'
        QtMocHelpers::SignalData<void(const QUrl &, const QDateTime &)>(39, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 38 }, { QMetaType::QDateTime, 40 },
        }}),
        // Signal 'finishedPlayingTrack'
        QtMocHelpers::SignalData<void(const QUrl &, const QDateTime &)>(41, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 38 }, { QMetaType::QDateTime, 40 },
        }}),
        // Signal 'updateData'
        QtMocHelpers::SignalData<void(const QPersistentModelIndex &, const QVariant &, int)>(42, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 43, 44 }, { 0x80000000 | 45, 46 }, { QMetaType::Int, 47 },
        }}),
        // Slot 'setCurrentTrack'
        QtMocHelpers::SlotData<void(const QPersistentModelIndex &)>(48, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 43, 49 },
        }}),
        // Slot 'saveForUndoClearPlaylist'
        QtMocHelpers::SlotData<void()>(50, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'restoreForUndoClearPlaylist'
        QtMocHelpers::SlotData<void()>(51, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setPlayListModel'
        QtMocHelpers::SlotData<void(QAbstractItemModel *)>(52, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'setUrlRole'
        QtMocHelpers::SlotData<void(int)>(55, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 46 },
        }}),
        // Slot 'setIsPlayingRole'
        QtMocHelpers::SlotData<void(int)>(56, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 46 },
        }}),
        // Slot 'setPlayerStatus'
        QtMocHelpers::SlotData<void(QMediaPlayer::MediaStatus)>(57, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 58, 59 },
        }}),
        // Slot 'setPlayerPlaybackState'
        QtMocHelpers::SlotData<void(QMediaPlayer::PlaybackState)>(60, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 61, 62 },
        }}),
        // Slot 'setPlayerError'
        QtMocHelpers::SlotData<void(QMediaPlayer::Error)>(63, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Slot 'ensurePause'
        QtMocHelpers::SlotData<void()>(64, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ensurePlay'
        QtMocHelpers::SlotData<void()>(65, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'requestPlay'
        QtMocHelpers::SlotData<void()>(66, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'playPause'
        QtMocHelpers::SlotData<void()>(67, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(68, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setAudioDuration'
        QtMocHelpers::SlotData<void(qint64)>(69, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 70 },
        }}),
        // Slot 'setPlayerIsSeekable'
        QtMocHelpers::SlotData<void(bool)>(71, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 72 },
        }}),
        // Slot 'setPlayerPosition'
        QtMocHelpers::SlotData<void(qint64)>(73, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 74 },
        }}),
        // Slot 'setCurrentPlayingForRadios'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(75, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 76 }, { QMetaType::QString, 77 },
        }}),
        // Slot 'setPlayControlPosition'
        QtMocHelpers::SlotData<void(int)>(78, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 74 },
        }}),
        // Slot 'setPersistentState'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(79, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 80, 81 },
        }}),
        // Slot 'playerSeek'
        QtMocHelpers::SlotData<void(int)>(82, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Slot 'playListFinished'
        QtMocHelpers::SlotData<void()>(83, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'tracksDataChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &, const QList<int> &)>(84, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 85, 86 }, { 0x80000000 | 85, 87 }, { 0x80000000 | 88, 89 },
        }}),
        // Slot 'setTitleRole'
        QtMocHelpers::SlotData<void(int)>(90, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 91 },
        }}),
        // Slot 'setArtistNameRole'
        QtMocHelpers::SlotData<void(int)>(92, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 93 },
        }}),
        // Slot 'setAlbumNameRole'
        QtMocHelpers::SlotData<void(int)>(94, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 95 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'currentTrack'
        QtMocHelpers::PropertyData<QPersistentModelIndex>(49, 0x80000000 | 43, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'playListModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(96, 0x80000000 | 53, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'playerSource'
        QtMocHelpers::PropertyData<QUrl>(97, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'titleRole'
        QtMocHelpers::PropertyData<int>(91, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'artistNameRole'
        QtMocHelpers::PropertyData<int>(93, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'albumNameRole'
        QtMocHelpers::PropertyData<int>(95, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 24),
        // property 'urlRole'
        QtMocHelpers::PropertyData<int>(98, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isPlayingRole'
        QtMocHelpers::PropertyData<int>(99, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'playerStatus'
        QtMocHelpers::PropertyData<QMediaPlayer::MediaStatus>(59, 0x80000000 | 58, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'playerPlaybackState'
        QtMocHelpers::PropertyData<QMediaPlayer::PlaybackState>(62, 0x80000000 | 61, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'playerError'
        QtMocHelpers::PropertyData<QMediaPlayer::Error>(36, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'audioDuration'
        QtMocHelpers::PropertyData<qint64>(70, QMetaType::LongLong, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'playerIsSeekable'
        QtMocHelpers::PropertyData<bool>(72, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'playerPosition'
        QtMocHelpers::PropertyData<qint64>(74, QMetaType::LongLong, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'playControlPosition'
        QtMocHelpers::PropertyData<qint64>(100, QMetaType::LongLong, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'persistentState'
        QtMocHelpers::PropertyData<QVariantMap>(101, 0x80000000 | 80, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 18),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ManageAudioPlayer, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN17ManageAudioPlayerE[] = {
    QMetaObject::SuperData::link<QMediaPlayer::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject ManageAudioPlayer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ManageAudioPlayerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ManageAudioPlayerE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN17ManageAudioPlayerE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17ManageAudioPlayerE_t>.metaTypes,
    nullptr
} };

void ManageAudioPlayer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ManageAudioPlayer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentTrackChanged(); break;
        case 1: _t->playListModelChanged(); break;
        case 2: _t->playerSourceChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 3: _t->urlRoleChanged(); break;
        case 4: _t->isPlayingRoleChanged(); break;
        case 5: _t->playerStatusChanged(); break;
        case 6: _t->playerPlaybackStateChanged(); break;
        case 7: _t->playerErrorChanged(); break;
        case 8: _t->playerPlay(); break;
        case 9: _t->playerPause(); break;
        case 10: _t->playerStop(); break;
        case 11: _t->skipNextTrack((*reinterpret_cast<std::add_pointer_t<ElisaUtils::SkipReason>>(_a[1]))); break;
        case 12: _t->skipNextTrack(); break;
        case 13: _t->skipPreviousTrack((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 14: _t->audioDurationChanged(); break;
        case 15: _t->playerIsSeekableChanged(); break;
        case 16: _t->playerPositionChanged(); break;
        case 17: _t->playControlPositionChanged(); break;
        case 18: _t->persistentStateChanged(); break;
        case 19: _t->seek((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 20: _t->saveUndoPositionInAudioWrapper((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 21: _t->restoreUndoPositionInAudioWrapper(); break;
        case 22: _t->titleRoleChanged(); break;
        case 23: _t->artistNameRoleChanged(); break;
        case 24: _t->albumNameRoleChanged(); break;
        case 25: _t->sourceInError((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMediaPlayer::Error>>(_a[2]))); break;
        case 26: _t->displayTrackError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->startedPlayingTrack((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[2]))); break;
        case 28: _t->finishedPlayingTrack((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[2]))); break;
        case 29: _t->updateData((*reinterpret_cast<std::add_pointer_t<QPersistentModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 30: _t->setCurrentTrack((*reinterpret_cast<std::add_pointer_t<QPersistentModelIndex>>(_a[1]))); break;
        case 31: _t->saveForUndoClearPlaylist(); break;
        case 32: _t->restoreForUndoClearPlaylist(); break;
        case 33: _t->setPlayListModel((*reinterpret_cast<std::add_pointer_t<QAbstractItemModel*>>(_a[1]))); break;
        case 34: _t->setUrlRole((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 35: _t->setIsPlayingRole((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 36: _t->setPlayerStatus((*reinterpret_cast<std::add_pointer_t<QMediaPlayer::MediaStatus>>(_a[1]))); break;
        case 37: _t->setPlayerPlaybackState((*reinterpret_cast<std::add_pointer_t<QMediaPlayer::PlaybackState>>(_a[1]))); break;
        case 38: _t->setPlayerError((*reinterpret_cast<std::add_pointer_t<QMediaPlayer::Error>>(_a[1]))); break;
        case 39: _t->ensurePause(); break;
        case 40: _t->ensurePlay(); break;
        case 41: _t->requestPlay(); break;
        case 42: _t->playPause(); break;
        case 43: _t->stop(); break;
        case 44: _t->setAudioDuration((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 45: _t->setPlayerIsSeekable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 46: _t->setPlayerPosition((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 47: _t->setCurrentPlayingForRadios((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 48: _t->setPlayControlPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 49: _t->setPersistentState((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 50: _t->playerSeek((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 51: _t->playListFinished(); break;
        case 52: _t->tracksDataChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[3]))); break;
        case 53: _t->setTitleRole((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 54: _t->setArtistNameRole((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 55: _t->setAlbumNameRole((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractItemModel* >(); break;
            }
            break;
        case 52:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)()>(_a, &ManageAudioPlayer::currentTrackChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)()>(_a, &ManageAudioPlayer::playListModelChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)(const QUrl & )>(_a, &ManageAudioPlayer::playerSourceChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)()>(_a, &ManageAudioPlayer::urlRoleChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)()>(_a, &ManageAudioPlayer::isPlayingRoleChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)()>(_a, &ManageAudioPlayer::playerStatusChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)()>(_a, &ManageAudioPlayer::playerPlaybackStateChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)()>(_a, &ManageAudioPlayer::playerErrorChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)()>(_a, &ManageAudioPlayer::playerPlay, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)()>(_a, &ManageAudioPlayer::playerPause, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)()>(_a, &ManageAudioPlayer::playerStop, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)(ElisaUtils::SkipReason )>(_a, &ManageAudioPlayer::skipNextTrack, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)(qint64 )>(_a, &ManageAudioPlayer::skipPreviousTrack, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)()>(_a, &ManageAudioPlayer::audioDurationChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)()>(_a, &ManageAudioPlayer::playerIsSeekableChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)()>(_a, &ManageAudioPlayer::playerPositionChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)()>(_a, &ManageAudioPlayer::playControlPositionChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)()>(_a, &ManageAudioPlayer::persistentStateChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)(qint64 )>(_a, &ManageAudioPlayer::seek, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)(qint64 )>(_a, &ManageAudioPlayer::saveUndoPositionInAudioWrapper, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)()>(_a, &ManageAudioPlayer::restoreUndoPositionInAudioWrapper, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)()>(_a, &ManageAudioPlayer::titleRoleChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)()>(_a, &ManageAudioPlayer::artistNameRoleChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)()>(_a, &ManageAudioPlayer::albumNameRoleChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)(const QUrl & , QMediaPlayer::Error )>(_a, &ManageAudioPlayer::sourceInError, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)(const QString & )>(_a, &ManageAudioPlayer::displayTrackError, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)(const QUrl & , const QDateTime & )>(_a, &ManageAudioPlayer::startedPlayingTrack, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)(const QUrl & , const QDateTime & )>(_a, &ManageAudioPlayer::finishedPlayingTrack, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (ManageAudioPlayer::*)(const QPersistentModelIndex & , const QVariant & , int )>(_a, &ManageAudioPlayer::updateData, 29))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QPersistentModelIndex*>(_v) = _t->currentTrack(); break;
        case 1: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->playListModel(); break;
        case 2: *reinterpret_cast<QUrl*>(_v) = _t->playerSource(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->titleRole(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->artistNameRole(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->albumNameRole(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->urlRole(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->isPlayingRole(); break;
        case 8: *reinterpret_cast<QMediaPlayer::MediaStatus*>(_v) = _t->playerStatus(); break;
        case 9: *reinterpret_cast<QMediaPlayer::PlaybackState*>(_v) = _t->playerPlaybackState(); break;
        case 10: *reinterpret_cast<QMediaPlayer::Error*>(_v) = _t->playerError(); break;
        case 11: *reinterpret_cast<qint64*>(_v) = _t->audioDuration(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->playerIsSeekable(); break;
        case 13: *reinterpret_cast<qint64*>(_v) = _t->playerPosition(); break;
        case 14: *reinterpret_cast<qint64*>(_v) = _t->playControlPosition(); break;
        case 15: *reinterpret_cast<QVariantMap*>(_v) = _t->persistentState(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCurrentTrack(*reinterpret_cast<QPersistentModelIndex*>(_v)); break;
        case 1: _t->setPlayListModel(*reinterpret_cast<QAbstractItemModel**>(_v)); break;
        case 3: _t->setTitleRole(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setArtistNameRole(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setAlbumNameRole(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setUrlRole(*reinterpret_cast<int*>(_v)); break;
        case 7: _t->setIsPlayingRole(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setPlayerStatus(*reinterpret_cast<QMediaPlayer::MediaStatus*>(_v)); break;
        case 9: _t->setPlayerPlaybackState(*reinterpret_cast<QMediaPlayer::PlaybackState*>(_v)); break;
        case 10: _t->setPlayerError(*reinterpret_cast<QMediaPlayer::Error*>(_v)); break;
        case 11: _t->setAudioDuration(*reinterpret_cast<qint64*>(_v)); break;
        case 12: _t->setPlayerIsSeekable(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setPlayerPosition(*reinterpret_cast<qint64*>(_v)); break;
        case 14: _t->setPlayControlPosition(*reinterpret_cast<qint64*>(_v)); break;
        case 15: _t->setPersistentState(*reinterpret_cast<QVariantMap*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ManageAudioPlayer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ManageAudioPlayer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ManageAudioPlayerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ManageAudioPlayer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 56)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 56;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 56)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 56;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void ManageAudioPlayer::currentTrackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ManageAudioPlayer::playListModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ManageAudioPlayer::playerSourceChanged(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ManageAudioPlayer::urlRoleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ManageAudioPlayer::isPlayingRoleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ManageAudioPlayer::playerStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ManageAudioPlayer::playerPlaybackStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ManageAudioPlayer::playerErrorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ManageAudioPlayer::playerPlay()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ManageAudioPlayer::playerPause()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void ManageAudioPlayer::playerStop()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void ManageAudioPlayer::skipNextTrack(ElisaUtils::SkipReason _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 13
void ManageAudioPlayer::skipPreviousTrack(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void ManageAudioPlayer::audioDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void ManageAudioPlayer::playerIsSeekableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void ManageAudioPlayer::playerPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void ManageAudioPlayer::playControlPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void ManageAudioPlayer::persistentStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void ManageAudioPlayer::seek(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void ManageAudioPlayer::saveUndoPositionInAudioWrapper(qint64 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void ManageAudioPlayer::restoreUndoPositionInAudioWrapper()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void ManageAudioPlayer::titleRoleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void ManageAudioPlayer::artistNameRoleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void ManageAudioPlayer::albumNameRoleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void ManageAudioPlayer::sourceInError(const QUrl & _t1, QMediaPlayer::Error _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1, _t2);
}

// SIGNAL 26
void ManageAudioPlayer::displayTrackError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1);
}

// SIGNAL 27
void ManageAudioPlayer::startedPlayingTrack(const QUrl & _t1, const QDateTime & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1, _t2);
}

// SIGNAL 28
void ManageAudioPlayer::finishedPlayingTrack(const QUrl & _t1, const QDateTime & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 28, nullptr, _t1, _t2);
}

// SIGNAL 29
void ManageAudioPlayer::updateData(const QPersistentModelIndex & _t1, const QVariant & _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 29, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
