/****************************************************************************
** Meta object code from reading C++ file 'databaseinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/databaseinterface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'databaseinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17DatabaseInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto DatabaseInterface::qt_create_metaobjectdata<qt_meta_tag_ZN17DatabaseInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DatabaseInterface",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "",
        "tracksAdded",
        "DataTypes::ListTrackDataType",
        "allTracks",
        "radioAdded",
        "DataTypes::TrackDataType",
        "radio",
        "albumsAdded",
        "DataTypes::ListAlbumDataType",
        "newAlbums",
        "artistsAdded",
        "DataTypes::ListArtistDataType",
        "newArtists",
        "genresAdded",
        "DataTypes::ListGenreDataType",
        "NewGenres",
        "composersAdded",
        "newComposers",
        "lyricistsAdded",
        "newLyricists",
        "trackRemoved",
        "removedTrackId",
        "radioRemoved",
        "radioId",
        "albumRemoved",
        "removedAlbumId",
        "artistRemoved",
        "removedArtistId",
        "genreRemoved",
        "removedGenreId",
        "composerRemoved",
        "lyricistRemoved",
        "removedLyricistId",
        "trackModified",
        "modifiedTrack",
        "radioModified",
        "albumModified",
        "DataTypes::AlbumDataType",
        "modifiedAlbum",
        "modifiedAlbumId",
        "requestsInitDone",
        "databaseError",
        "restoredTracks",
        "QHash<QUrl,QDateTime>",
        "allFiles",
        "cleanedDatabase",
        "finishInsertingTracksList",
        "finishRemovingTracksList",
        "insertTracksList",
        "tracks",
        "removeTracksList",
        "QList<QUrl>",
        "removedTracks",
        "askRestoredTracks",
        "trackHasStartedPlaying",
        "QUrl",
        "fileName",
        "time",
        "trackHasFinishedPlaying",
        "clearData",
        "removeRadio",
        "init",
        "dbName",
        "databaseFileName"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'tracksAdded'
        QtMocHelpers::SignalData<void(const DataTypes::ListTrackDataType &)>(7, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'radioAdded'
        QtMocHelpers::SignalData<void(const DataTypes::TrackDataType &)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'albumsAdded'
        QtMocHelpers::SignalData<void(const DataTypes::ListAlbumDataType &)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'artistsAdded'
        QtMocHelpers::SignalData<void(const DataTypes::ListArtistDataType &)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Signal 'genresAdded'
        QtMocHelpers::SignalData<void(const DataTypes::ListGenreDataType &)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Signal 'composersAdded'
        QtMocHelpers::SignalData<void(const DataTypes::ListArtistDataType &)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 23 },
        }}),
        // Signal 'lyricistsAdded'
        QtMocHelpers::SignalData<void(const DataTypes::ListArtistDataType &)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 25 },
        }}),
        // Signal 'trackRemoved'
        QtMocHelpers::SignalData<void(qulonglong)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 27 },
        }}),
        // Signal 'radioRemoved'
        QtMocHelpers::SignalData<void(qulonglong)>(28, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 29 },
        }}),
        // Signal 'albumRemoved'
        QtMocHelpers::SignalData<void(qulonglong)>(30, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 31 },
        }}),
        // Signal 'artistRemoved'
        QtMocHelpers::SignalData<void(qulonglong)>(32, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 33 },
        }}),
        // Signal 'genreRemoved'
        QtMocHelpers::SignalData<void(qulonglong)>(34, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 35 },
        }}),
        // Signal 'composerRemoved'
        QtMocHelpers::SignalData<void(qulonglong)>(36, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 33 },
        }}),
        // Signal 'lyricistRemoved'
        QtMocHelpers::SignalData<void(qulonglong)>(37, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 38 },
        }}),
        // Signal 'trackModified'
        QtMocHelpers::SignalData<void(const DataTypes::TrackDataType &)>(39, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 40 },
        }}),
        // Signal 'radioModified'
        QtMocHelpers::SignalData<void(const DataTypes::TrackDataType &)>(41, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'albumModified'
        QtMocHelpers::SignalData<void(const DataTypes::AlbumDataType &, qulonglong)>(42, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 43, 44 }, { QMetaType::ULongLong, 45 },
        }}),
        // Signal 'requestsInitDone'
        QtMocHelpers::SignalData<void()>(46, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'databaseError'
        QtMocHelpers::SignalData<void()>(47, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'restoredTracks'
        QtMocHelpers::SignalData<void(const QHash<QUrl,QDateTime> &)>(48, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 49, 50 },
        }}),
        // Signal 'cleanedDatabase'
        QtMocHelpers::SignalData<void()>(51, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'finishInsertingTracksList'
        QtMocHelpers::SignalData<void()>(52, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'finishRemovingTracksList'
        QtMocHelpers::SignalData<void()>(53, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'insertTracksList'
        QtMocHelpers::SlotData<void(const DataTypes::ListTrackDataType &)>(54, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 55 },
        }}),
        // Slot 'removeTracksList'
        QtMocHelpers::SlotData<void(const QList<QUrl> &)>(56, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 57, 58 },
        }}),
        // Slot 'askRestoredTracks'
        QtMocHelpers::SlotData<void()>(59, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'trackHasStartedPlaying'
        QtMocHelpers::SlotData<void(const QUrl &, const QDateTime &)>(60, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 61, 62 }, { QMetaType::QDateTime, 63 },
        }}),
        // Slot 'trackHasFinishedPlaying'
        QtMocHelpers::SlotData<void(const QUrl &, const QDateTime &)>(64, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 61, 62 }, { QMetaType::QDateTime, 63 },
        }}),
        // Slot 'clearData'
        QtMocHelpers::SlotData<void()>(65, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeRadio'
        QtMocHelpers::SlotData<void(qulonglong)>(66, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 29 },
        }}),
        // Method 'init'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(67, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 68 }, { QMetaType::QString, 69 },
        }}),
        // Method 'init'
        QtMocHelpers::MethodData<void(const QString &)>(67, 6, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 68 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DatabaseInterface, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DatabaseInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DatabaseInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DatabaseInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17DatabaseInterfaceE_t>.metaTypes,
    nullptr
} };

void DatabaseInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DatabaseInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->tracksAdded((*reinterpret_cast<std::add_pointer_t<DataTypes::ListTrackDataType>>(_a[1]))); break;
        case 1: _t->radioAdded((*reinterpret_cast<std::add_pointer_t<DataTypes::TrackDataType>>(_a[1]))); break;
        case 2: _t->albumsAdded((*reinterpret_cast<std::add_pointer_t<DataTypes::ListAlbumDataType>>(_a[1]))); break;
        case 3: _t->artistsAdded((*reinterpret_cast<std::add_pointer_t<DataTypes::ListArtistDataType>>(_a[1]))); break;
        case 4: _t->genresAdded((*reinterpret_cast<std::add_pointer_t<DataTypes::ListGenreDataType>>(_a[1]))); break;
        case 5: _t->composersAdded((*reinterpret_cast<std::add_pointer_t<DataTypes::ListArtistDataType>>(_a[1]))); break;
        case 6: _t->lyricistsAdded((*reinterpret_cast<std::add_pointer_t<DataTypes::ListArtistDataType>>(_a[1]))); break;
        case 7: _t->trackRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 8: _t->radioRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 9: _t->albumRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 10: _t->artistRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 11: _t->genreRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 12: _t->composerRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 13: _t->lyricistRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 14: _t->trackModified((*reinterpret_cast<std::add_pointer_t<DataTypes::TrackDataType>>(_a[1]))); break;
        case 15: _t->radioModified((*reinterpret_cast<std::add_pointer_t<DataTypes::TrackDataType>>(_a[1]))); break;
        case 16: _t->albumModified((*reinterpret_cast<std::add_pointer_t<DataTypes::AlbumDataType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2]))); break;
        case 17: _t->requestsInitDone(); break;
        case 18: _t->databaseError(); break;
        case 19: _t->restoredTracks((*reinterpret_cast<std::add_pointer_t<QHash<QUrl,QDateTime>>>(_a[1]))); break;
        case 20: _t->cleanedDatabase(); break;
        case 21: _t->finishInsertingTracksList(); break;
        case 22: _t->finishRemovingTracksList(); break;
        case 23: _t->insertTracksList((*reinterpret_cast<std::add_pointer_t<DataTypes::ListTrackDataType>>(_a[1]))); break;
        case 24: _t->removeTracksList((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 25: _t->askRestoredTracks(); break;
        case 26: _t->trackHasStartedPlaying((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[2]))); break;
        case 27: _t->trackHasFinishedPlaying((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[2]))); break;
        case 28: _t->clearData(); break;
        case 29: _t->removeRadio((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 30: _t->init((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 31: _t->init((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::ListTrackDataType >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::TrackDataType >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::ListAlbumDataType >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::ListArtistDataType >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::ListGenreDataType >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::ListArtistDataType >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::ListArtistDataType >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::TrackDataType >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::TrackDataType >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::AlbumDataType >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::ListTrackDataType >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DatabaseInterface::*)(const DataTypes::ListTrackDataType & )>(_a, &DatabaseInterface::tracksAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseInterface::*)(const DataTypes::TrackDataType & )>(_a, &DatabaseInterface::radioAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseInterface::*)(const DataTypes::ListAlbumDataType & )>(_a, &DatabaseInterface::albumsAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseInterface::*)(const DataTypes::ListArtistDataType & )>(_a, &DatabaseInterface::artistsAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseInterface::*)(const DataTypes::ListGenreDataType & )>(_a, &DatabaseInterface::genresAdded, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseInterface::*)(const DataTypes::ListArtistDataType & )>(_a, &DatabaseInterface::composersAdded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseInterface::*)(const DataTypes::ListArtistDataType & )>(_a, &DatabaseInterface::lyricistsAdded, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseInterface::*)(qulonglong )>(_a, &DatabaseInterface::trackRemoved, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseInterface::*)(qulonglong )>(_a, &DatabaseInterface::radioRemoved, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseInterface::*)(qulonglong )>(_a, &DatabaseInterface::albumRemoved, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseInterface::*)(qulonglong )>(_a, &DatabaseInterface::artistRemoved, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseInterface::*)(qulonglong )>(_a, &DatabaseInterface::genreRemoved, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseInterface::*)(qulonglong )>(_a, &DatabaseInterface::composerRemoved, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseInterface::*)(qulonglong )>(_a, &DatabaseInterface::lyricistRemoved, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseInterface::*)(const DataTypes::TrackDataType & )>(_a, &DatabaseInterface::trackModified, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseInterface::*)(const DataTypes::TrackDataType & )>(_a, &DatabaseInterface::radioModified, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseInterface::*)(const DataTypes::AlbumDataType & , qulonglong )>(_a, &DatabaseInterface::albumModified, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseInterface::*)()>(_a, &DatabaseInterface::requestsInitDone, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseInterface::*)()>(_a, &DatabaseInterface::databaseError, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseInterface::*)(const QHash<QUrl,QDateTime> & )>(_a, &DatabaseInterface::restoredTracks, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseInterface::*)()>(_a, &DatabaseInterface::cleanedDatabase, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseInterface::*)()>(_a, &DatabaseInterface::finishInsertingTracksList, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseInterface::*)()>(_a, &DatabaseInterface::finishRemovingTracksList, 22))
            return;
    }
}

const QMetaObject *DatabaseInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DatabaseInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17DatabaseInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DatabaseInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    return _id;
}

// SIGNAL 0
void DatabaseInterface::tracksAdded(const DataTypes::ListTrackDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DatabaseInterface::radioAdded(const DataTypes::TrackDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DatabaseInterface::albumsAdded(const DataTypes::ListAlbumDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DatabaseInterface::artistsAdded(const DataTypes::ListArtistDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DatabaseInterface::genresAdded(const DataTypes::ListGenreDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DatabaseInterface::composersAdded(const DataTypes::ListArtistDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DatabaseInterface::lyricistsAdded(const DataTypes::ListArtistDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void DatabaseInterface::trackRemoved(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void DatabaseInterface::radioRemoved(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void DatabaseInterface::albumRemoved(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void DatabaseInterface::artistRemoved(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void DatabaseInterface::genreRemoved(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void DatabaseInterface::composerRemoved(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void DatabaseInterface::lyricistRemoved(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void DatabaseInterface::trackModified(const DataTypes::TrackDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void DatabaseInterface::radioModified(const DataTypes::TrackDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void DatabaseInterface::albumModified(const DataTypes::AlbumDataType & _t1, qulonglong _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1, _t2);
}

// SIGNAL 17
void DatabaseInterface::requestsInitDone()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void DatabaseInterface::databaseError()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void DatabaseInterface::restoredTracks(const QHash<QUrl,QDateTime> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void DatabaseInterface::cleanedDatabase()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void DatabaseInterface::finishInsertingTracksList()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void DatabaseInterface::finishRemovingTracksList()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}
QT_WARNING_POP
