/****************************************************************************
** Meta object code from reading C++ file 'elisaapplication.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/elisaapplication.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'elisaapplication.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16ElisaApplicationE_t {};
} // unnamed namespace

template <> constexpr inline auto ElisaApplication::qt_create_metaobjectdata<qt_meta_tag_ZN16ElisaApplicationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ElisaApplication",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "musicManagerChanged",
        "",
        "mediaPlayListChanged",
        "mediaPlayListProxyModelChanged",
        "audioPlayerChanged",
        "audioControlChanged",
        "playerControlChanged",
        "manageHeaderBarChanged",
        "enqueue",
        "DataTypes::EntryDataList",
        "newEntries",
        "ElisaUtils::PlayListEnqueueMode",
        "enqueueMode",
        "ElisaUtils::PlayListEnqueueTriggerPlay",
        "triggerPlay",
        "initializationDone",
        "showNowPlayingBackgroundChanged",
        "showProgressOnTaskBarChanged",
        "showSystemTrayIconChanged",
        "useFavoriteStyleRatingsChanged",
        "commitDataRequest",
        "embeddedViewChanged",
        "initialViewIndexChanged",
        "initialFilesViewPathChanged",
        "activeColorSchemeNameChanged",
        "raisePlayer",
        "openAboutAppPage",
        "openAboutKDEPage",
        "configureElisa",
        "goBack",
        "togglePlaylist",
        "seek",
        "scrub",
        "nextTrack",
        "previousTrack",
        "playPause",
        "find",
        "togglePartyMode",
        "reportBug",
        "configureShortcuts",
        "openFiles",
        "QList<QUrl>",
        "files",
        "workingDirectory",
        "activateActionRequested",
        "actionName",
        "QVariant",
        "parameter",
        "activateRequested",
        "arguments",
        "openRequested",
        "uris",
        "initialize",
        "configChanged",
        "action",
        "QAction*",
        "name",
        "showInFolder",
        "QUrl",
        "filePath",
        "embeddedView",
        "ElisaUtils::PlayListEntryType",
        "musicManager",
        "MusicListenersManager*",
        "mediaPlayList",
        "MediaPlayList*",
        "mediaPlayListProxyModel",
        "MediaPlayListProxyModel*",
        "audioPlayer",
        "AudioWrapper*",
        "audioControl",
        "ManageAudioPlayer*",
        "playerControl",
        "ManageMediaPlayerControl*",
        "manageHeaderBar",
        "ManageHeaderBar*",
        "showNowPlayingBackground",
        "showProgressOnTaskBar",
        "showSystemTrayIcon",
        "useFavoriteStyleRatings",
        "colorSchemesModel",
        "QAbstractItemModel*",
        "activeColorSchemeName",
        "initialViewIndex",
        "initialFilesViewPath"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'musicManagerChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mediaPlayListChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mediaPlayListProxyModelChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audioPlayerChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audioControlChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playerControlChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'manageHeaderBarChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enqueue'
        QtMocHelpers::SignalData<void(const DataTypes::EntryDataList &, ElisaUtils::PlayListEnqueueMode, ElisaUtils::PlayListEnqueueTriggerPlay)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { 0x80000000 | 16, 17 }, { 0x80000000 | 18, 19 },
        }}),
        // Signal 'initializationDone'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showNowPlayingBackgroundChanged'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showProgressOnTaskBarChanged'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showSystemTrayIconChanged'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'useFavoriteStyleRatingsChanged'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'commitDataRequest'
        QtMocHelpers::SignalData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'embeddedViewChanged'
        QtMocHelpers::SignalData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'initialViewIndexChanged'
        QtMocHelpers::SignalData<void()>(27, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'initialFilesViewPathChanged'
        QtMocHelpers::SignalData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeColorSchemeNameChanged'
        QtMocHelpers::SignalData<void()>(29, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'raisePlayer'
        QtMocHelpers::SignalData<void()>(30, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openAboutAppPage'
        QtMocHelpers::SignalData<void()>(31, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openAboutKDEPage'
        QtMocHelpers::SignalData<void()>(32, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'configureElisa'
        QtMocHelpers::SignalData<void()>(33, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'goBack'
        QtMocHelpers::SignalData<void()>(34, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'togglePlaylist'
        QtMocHelpers::SignalData<void()>(35, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'seek'
        QtMocHelpers::SignalData<void()>(36, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scrub'
        QtMocHelpers::SignalData<void()>(37, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nextTrack'
        QtMocHelpers::SignalData<void()>(38, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previousTrack'
        QtMocHelpers::SignalData<void()>(39, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playPause'
        QtMocHelpers::SignalData<void()>(40, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'find'
        QtMocHelpers::SignalData<void()>(41, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'togglePartyMode'
        QtMocHelpers::SignalData<void()>(42, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reportBug'
        QtMocHelpers::SlotData<void()>(43, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'configureShortcuts'
        QtMocHelpers::SlotData<void()>(44, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openFiles'
        QtMocHelpers::SlotData<bool(const QList<QUrl> &)>(45, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 46, 47 },
        }}),
        // Slot 'openFiles'
        QtMocHelpers::SlotData<bool(const QList<QUrl> &, const QString &)>(45, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 46, 47 }, { QMetaType::QString, 48 },
        }}),
        // Slot 'activateActionRequested'
        QtMocHelpers::SlotData<void(const QString &, const QVariant &)>(49, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 50 }, { 0x80000000 | 51, 52 },
        }}),
        // Slot 'activateRequested'
        QtMocHelpers::SlotData<void(const QStringList &, const QString &)>(53, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 54 }, { QMetaType::QString, 48 },
        }}),
        // Slot 'openRequested'
        QtMocHelpers::SlotData<void(const QList<QUrl> &)>(55, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 46, 56 },
        }}),
        // Slot 'initialize'
        QtMocHelpers::SlotData<void()>(57, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'configChanged'
        QtMocHelpers::SlotData<void()>(58, 6, QMC::AccessPrivate, QMetaType::Void),
        // Method 'action'
        QtMocHelpers::MethodData<QAction *(const QString &)>(59, 6, QMC::AccessPublic, 0x80000000 | 60, {{
            { QMetaType::QString, 61 },
        }}),
        // Method 'showInFolder'
        QtMocHelpers::MethodData<void(const QUrl &)>(62, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 63, 64 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'embeddedView'
        QtMocHelpers::PropertyData<ElisaUtils::PlayListEntryType>(65, 0x80000000 | 66, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 14),
        // property 'musicManager'
        QtMocHelpers::PropertyData<MusicListenersManager*>(67, 0x80000000 | 68, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'mediaPlayList'
        QtMocHelpers::PropertyData<MediaPlayList*>(69, 0x80000000 | 70, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'mediaPlayListProxyModel'
        QtMocHelpers::PropertyData<MediaPlayListProxyModel*>(71, 0x80000000 | 72, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'audioPlayer'
        QtMocHelpers::PropertyData<AudioWrapper*>(73, 0x80000000 | 74, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'audioControl'
        QtMocHelpers::PropertyData<ManageAudioPlayer*>(75, 0x80000000 | 76, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'playerControl'
        QtMocHelpers::PropertyData<ManageMediaPlayerControl*>(77, 0x80000000 | 78, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'manageHeaderBar'
        QtMocHelpers::PropertyData<ManageHeaderBar*>(79, 0x80000000 | 80, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6),
        // property 'showNowPlayingBackground'
        QtMocHelpers::PropertyData<bool>(81, QMetaType::Bool, QMC::DefaultPropertyFlags, 9),
        // property 'showProgressOnTaskBar'
        QtMocHelpers::PropertyData<bool>(82, QMetaType::Bool, QMC::DefaultPropertyFlags, 10),
        // property 'showSystemTrayIcon'
        QtMocHelpers::PropertyData<bool>(83, QMetaType::Bool, QMC::DefaultPropertyFlags, 11),
        // property 'useFavoriteStyleRatings'
        QtMocHelpers::PropertyData<bool>(84, QMetaType::Bool, QMC::DefaultPropertyFlags, 12),
        // property 'colorSchemesModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(85, 0x80000000 | 86, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'activeColorSchemeName'
        QtMocHelpers::PropertyData<QString>(87, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'initialViewIndex'
        QtMocHelpers::PropertyData<int>(88, QMetaType::Int, QMC::DefaultPropertyFlags, 15),
        // property 'initialFilesViewPath'
        QtMocHelpers::PropertyData<QString>(89, QMetaType::QString, QMC::DefaultPropertyFlags, 16),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<ElisaApplication, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN16ElisaApplicationE[] = {
    QMetaObject::SuperData::link<ElisaUtils::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject ElisaApplication::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ElisaApplicationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ElisaApplicationE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN16ElisaApplicationE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16ElisaApplicationE_t>.metaTypes,
    nullptr
} };

void ElisaApplication::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ElisaApplication *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->musicManagerChanged(); break;
        case 1: _t->mediaPlayListChanged(); break;
        case 2: _t->mediaPlayListProxyModelChanged(); break;
        case 3: _t->audioPlayerChanged(); break;
        case 4: _t->audioControlChanged(); break;
        case 5: _t->playerControlChanged(); break;
        case 6: _t->manageHeaderBarChanged(); break;
        case 7: _t->enqueue((*reinterpret_cast<std::add_pointer_t<DataTypes::EntryDataList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEnqueueMode>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEnqueueTriggerPlay>>(_a[3]))); break;
        case 8: _t->initializationDone(); break;
        case 9: _t->showNowPlayingBackgroundChanged(); break;
        case 10: _t->showProgressOnTaskBarChanged(); break;
        case 11: _t->showSystemTrayIconChanged(); break;
        case 12: _t->useFavoriteStyleRatingsChanged(); break;
        case 13: _t->commitDataRequest(); break;
        case 14: _t->embeddedViewChanged(); break;
        case 15: _t->initialViewIndexChanged(); break;
        case 16: _t->initialFilesViewPathChanged(); break;
        case 17: _t->activeColorSchemeNameChanged(); break;
        case 18: _t->raisePlayer(); break;
        case 19: _t->openAboutAppPage(); break;
        case 20: _t->openAboutKDEPage(); break;
        case 21: _t->configureElisa(); break;
        case 22: _t->goBack(); break;
        case 23: _t->togglePlaylist(); break;
        case 24: _t->seek(); break;
        case 25: _t->scrub(); break;
        case 26: _t->nextTrack(); break;
        case 27: _t->previousTrack(); break;
        case 28: _t->playPause(); break;
        case 29: _t->find(); break;
        case 30: _t->togglePartyMode(); break;
        case 31: _t->reportBug(); break;
        case 32: _t->configureShortcuts(); break;
        case 33: { bool _r = _t->openFiles((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 34: { bool _r = _t->openFiles((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 35: _t->activateActionRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 36: _t->activateRequested((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 37: _t->openRequested((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 38: _t->initialize(); break;
        case 39: _t->configChanged(); break;
        case 40: { QAction* _r = _t->action((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QAction**>(_a[0]) = std::move(_r); }  break;
        case 41: _t->showInFolder((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< DataTypes::EntryDataList >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::musicManagerChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::mediaPlayListChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::mediaPlayListProxyModelChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::audioPlayerChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::audioControlChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::playerControlChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::manageHeaderBarChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)(const DataTypes::EntryDataList & , ElisaUtils::PlayListEnqueueMode , ElisaUtils::PlayListEnqueueTriggerPlay )>(_a, &ElisaApplication::enqueue, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::initializationDone, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::showNowPlayingBackgroundChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::showProgressOnTaskBarChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::showSystemTrayIconChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::useFavoriteStyleRatingsChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::commitDataRequest, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::embeddedViewChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::initialViewIndexChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::initialFilesViewPathChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::activeColorSchemeNameChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::raisePlayer, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::openAboutAppPage, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::openAboutKDEPage, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::configureElisa, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::goBack, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::togglePlaylist, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::seek, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::scrub, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::nextTrack, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::previousTrack, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::playPause, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::find, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (ElisaApplication::*)()>(_a, &ElisaApplication::togglePartyMode, 30))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<ElisaUtils::PlayListEntryType*>(_v) = _t->embeddedView(); break;
        case 1: *reinterpret_cast<MusicListenersManager**>(_v) = _t->musicManager(); break;
        case 2: *reinterpret_cast<MediaPlayList**>(_v) = _t->mediaPlayList(); break;
        case 3: *reinterpret_cast<MediaPlayListProxyModel**>(_v) = _t->mediaPlayListProxyModel(); break;
        case 4: *reinterpret_cast<AudioWrapper**>(_v) = _t->audioPlayer(); break;
        case 5: *reinterpret_cast<ManageAudioPlayer**>(_v) = _t->audioControl(); break;
        case 6: *reinterpret_cast<ManageMediaPlayerControl**>(_v) = _t->playerControl(); break;
        case 7: *reinterpret_cast<ManageHeaderBar**>(_v) = _t->manageHeaderBar(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->showNowPlayingBackground(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->showProgressOnTaskBar(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->showSystemTrayIcon(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->useFavoriteStyleRatings(); break;
        case 12: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->colorSchemesModel(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->activeColorSchemeName(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->initialViewIndex(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->initialFilesViewPath(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 13: _t->setActiveColorSchemeName(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ElisaApplication::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ElisaApplication::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ElisaApplicationE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ElisaApplication::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 42)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 42;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 42)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 42;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void ElisaApplication::musicManagerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ElisaApplication::mediaPlayListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ElisaApplication::mediaPlayListProxyModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ElisaApplication::audioPlayerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ElisaApplication::audioControlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ElisaApplication::playerControlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ElisaApplication::manageHeaderBarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ElisaApplication::enqueue(const DataTypes::EntryDataList & _t1, ElisaUtils::PlayListEnqueueMode _t2, ElisaUtils::PlayListEnqueueTriggerPlay _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3);
}

// SIGNAL 8
void ElisaApplication::initializationDone()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ElisaApplication::showNowPlayingBackgroundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void ElisaApplication::showProgressOnTaskBarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void ElisaApplication::showSystemTrayIconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void ElisaApplication::useFavoriteStyleRatingsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void ElisaApplication::commitDataRequest()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void ElisaApplication::embeddedViewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void ElisaApplication::initialViewIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void ElisaApplication::initialFilesViewPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void ElisaApplication::activeColorSchemeNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void ElisaApplication::raisePlayer()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void ElisaApplication::openAboutAppPage()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void ElisaApplication::openAboutKDEPage()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void ElisaApplication::configureElisa()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void ElisaApplication::goBack()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void ElisaApplication::togglePlaylist()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void ElisaApplication::seek()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void ElisaApplication::scrub()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void ElisaApplication::nextTrack()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void ElisaApplication::previousTrack()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void ElisaApplication::playPause()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void ElisaApplication::find()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void ElisaApplication::togglePartyMode()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}
QT_WARNING_POP
