/****************************************************************************
** Meta object code from reading C++ file 'trackslistener.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../elisa-26.07.90/src/trackslistener.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'trackslistener.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14TracksListenerE_t {};
} // unnamed namespace

template <> constexpr inline auto TracksListener::qt_create_metaobjectdata<qt_meta_tag_ZN14TracksListenerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TracksListener",
        "trackHasChanged",
        "",
        "TracksListener::TrackDataType",
        "audioTrack",
        "trackHasBeenRemoved",
        "id",
        "tracksListAdded",
        "newDatabaseId",
        "entryTitle",
        "ElisaUtils::PlayListEntryType",
        "databaseIdType",
        "TracksListener::ListTrackDataType",
        "tracks",
        "tracksAdded",
        "allTracks",
        "trackRemoved",
        "trackModified",
        "modifiedTrack",
        "trackByNameInList",
        "QVariant",
        "title",
        "artist",
        "album",
        "trackNumber",
        "discNumber",
        "newEntryInList",
        "trackByFileNameInList",
        "type",
        "QUrl",
        "fileName",
        "newUrlInList",
        "entryUrl",
        "updateSingleFileMetaData",
        "url",
        "DataTypes::ColumnsRoles",
        "role",
        "data"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'trackHasChanged'
        QtMocHelpers::SignalData<void(const TracksListener::TrackDataType &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'trackHasBeenRemoved'
        QtMocHelpers::SignalData<void(qulonglong)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 6 },
        }}),
        // Signal 'tracksListAdded'
        QtMocHelpers::SignalData<void(qulonglong, const QString &, ElisaUtils::PlayListEntryType, const TracksListener::ListTrackDataType &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 8 }, { QMetaType::QString, 9 }, { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'tracksAdded'
        QtMocHelpers::SlotData<void(const TracksListener::ListTrackDataType &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 15 },
        }}),
        // Slot 'trackRemoved'
        QtMocHelpers::SlotData<void(qulonglong)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 6 },
        }}),
        // Slot 'trackModified'
        QtMocHelpers::SlotData<void(const TracksListener::TrackDataType &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 18 },
        }}),
        // Slot 'trackByNameInList'
        QtMocHelpers::SlotData<void(const QVariant &, const QVariant &, const QVariant &, const QVariant &, const QVariant &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { 0x80000000 | 20, 22 }, { 0x80000000 | 20, 23 }, { 0x80000000 | 20, 24 },
            { 0x80000000 | 20, 25 },
        }}),
        // Slot 'newEntryInList'
        QtMocHelpers::SlotData<void(qulonglong, const QString &, ElisaUtils::PlayListEntryType)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::ULongLong, 8 }, { QMetaType::QString, 9 }, { 0x80000000 | 10, 11 },
        }}),
        // Slot 'trackByFileNameInList'
        QtMocHelpers::SlotData<void(ElisaUtils::PlayListEntryType, const QUrl &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 28 }, { 0x80000000 | 29, 30 },
        }}),
        // Slot 'newUrlInList'
        QtMocHelpers::SlotData<void(const QUrl &, ElisaUtils::PlayListEntryType)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 32 }, { 0x80000000 | 10, 11 },
        }}),
        // Slot 'updateSingleFileMetaData'
        QtMocHelpers::SlotData<void(const QUrl &, DataTypes::ColumnsRoles, const QVariant &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 34 }, { 0x80000000 | 35, 36 }, { 0x80000000 | 20, 37 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TracksListener, qt_meta_tag_ZN14TracksListenerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TracksListener::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14TracksListenerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14TracksListenerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14TracksListenerE_t>.metaTypes,
    nullptr
} };

void TracksListener::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TracksListener *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->trackHasChanged((*reinterpret_cast<std::add_pointer_t<TracksListener::TrackDataType>>(_a[1]))); break;
        case 1: _t->trackHasBeenRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 2: _t->tracksListAdded((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<TracksListener::ListTrackDataType>>(_a[4]))); break;
        case 3: _t->tracksAdded((*reinterpret_cast<std::add_pointer_t<TracksListener::ListTrackDataType>>(_a[1]))); break;
        case 4: _t->trackRemoved((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1]))); break;
        case 5: _t->trackModified((*reinterpret_cast<std::add_pointer_t<TracksListener::TrackDataType>>(_a[1]))); break;
        case 6: _t->trackByNameInList((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[5]))); break;
        case 7: _t->newEntryInList((*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[3]))); break;
        case 8: _t->trackByFileNameInList((*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 9: _t->newUrlInList((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ElisaUtils::PlayListEntryType>>(_a[2]))); break;
        case 10: _t->updateSingleFileMetaData((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<DataTypes::ColumnsRoles>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TracksListener::*)(const TracksListener::TrackDataType & )>(_a, &TracksListener::trackHasChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TracksListener::*)(qulonglong )>(_a, &TracksListener::trackHasBeenRemoved, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TracksListener::*)(qulonglong , const QString & , ElisaUtils::PlayListEntryType , const TracksListener::ListTrackDataType & )>(_a, &TracksListener::tracksListAdded, 2))
            return;
    }
}

const QMetaObject *TracksListener::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TracksListener::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14TracksListenerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int TracksListener::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void TracksListener::trackHasChanged(const TracksListener::TrackDataType & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void TracksListener::trackHasBeenRemoved(qulonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void TracksListener::tracksListAdded(qulonglong _t1, const QString & _t2, ElisaUtils::PlayListEntryType _t3, const TracksListener::ListTrackDataType & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3, _t4);
}
QT_WARNING_POP
